@@ -12,11 +12,21 @@ package java.lang;
 
 import java.io.InputStream;
 
-public class Class {
+public class Class<T> {
 	public String getName() {
 		return null;
 	}
 	public InputStream getResourceAsStream(String s) {
 		return null;
 	}
+	
+    public native Class<? super T> getSuperclass();
+    
+    public T newInstance() throws InstantiationException, IllegalAccessException {
+    	return null;
+    }
+    
+    public static Class<?> forName(String className) throws ClassNotFoundException {
+    	return null;
+    }
 }
