@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2005, 2007 BEA Systems, Inc. 
+ * Copyright (c) 2005, 2007 BEA Systems, Inc.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -10,7 +10,7 @@
  *
  * Contributors:
  *    mkaufman@bea.com - initial API and implementation
- *    
+ *
  *******************************************************************************/
 
 package org.eclipse.jdt.apt.tests.annotations.helloworld;
@@ -27,18 +27,19 @@ import com.sun.mirror.apt.AnnotationProcessorEnvironment;
 import com.sun.mirror.declaration.AnnotationTypeDeclaration;
 
 public class HelloWorldAnnotationProcessorFactory extends BaseFactory {
-	
+
 	public HelloWorldAnnotationProcessorFactory() {
 		super(HelloWorldAnnotation.class.getName());
 	}
 
 	public AnnotationProcessor getProcessorFor(
 			Set<AnnotationTypeDeclaration> atds,
-			AnnotationProcessorEnvironment env) 
+			AnnotationProcessorEnvironment env)
 	{
 		return new HelloWorldAnnotationProcessor( env );
 	}
-	
+
+	@Override
 	public Collection<String> supportedOptions() {
 		return Collections.singletonList(AptPreferenceConstants.RTTG_ENABLED_OPTION);
 	}
