@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2005, 2007 BEA Systems, Inc. 
+ * Copyright (c) 2005, 2007 BEA Systems, Inc.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -10,7 +10,7 @@
  *
  * Contributors:
  *    jgarms@bea.com - initial API and implementation
- *    
+ *
  *******************************************************************************/
 package org.eclipse.jdt.apt.tests.annotations.helloworld;
 
@@ -18,17 +18,18 @@ import java.util.Collection;
 import java.util.Collections;
 
 /**
- * Processor factory that claims annotations with a wildcard 
+ * Processor factory that claims annotations with a wildcard
  * ("org.eclipse.jdt.apt.tests.annotations.helloworld.*")
  */
 public class HelloWorldWildcardAnnotationProcessorFactory extends
 		HelloWorldAnnotationProcessorFactory {
-	
+
 	public static volatile boolean CLAIM_ALL_ANNOTATIONS;
 
-	
+
+	@Override
 	public Collection<String> supportedAnnotationTypes() {
-		
+
 		// We need to swap behavior because always claiming "*" will cause
 		// other processors normally called after us to be prevented from running,
 		// as we have claimed everything
