@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2018 Walter Harley and others. 
+ * Copyright (c) 2009, 2018 Walter Harley and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -10,7 +10,7 @@
  *
  * Contributors:
  *    Walter Harley - initial API and implementation
- *    
+ *
  *******************************************************************************/
 
 package org.eclipse.jdt.apt.tests;
@@ -48,10 +48,11 @@ public class StarProcessorTests extends APTTestBase
 		return new TestSuite( StarProcessorTests.class );
 	}
 
+	@Override
 	public void setUp() throws Exception
 	{
 		super.setUp();
-		
+
 		//
 		// project will be deleted by super-class's tearDown() method
 		// create a project with a src directory as the project root directory
@@ -66,14 +67,14 @@ public class StarProcessorTests extends APTTestBase
 		IJavaProject jproj = env.getJavaProject( projectPath );
 		AptConfig.setEnabled( jproj, true );
 		TestUtil.createAndAddAnnotationJar( jproj );
-		
+
 	}
 
 	public static String getProjectName_ProjectRootAsSrcDir()
 	{
 		return StarProcessorTests.class.getName() + "NoSrcProject"; //$NON-NLS-1$
 	}
-	
+
 	public IPath getSourcePath( String projectName )
 	{
 		if ( getProjectName_ProjectRootAsSrcDir().equals( projectName) )
@@ -90,7 +91,7 @@ public class StarProcessorTests extends APTTestBase
 	{
 		_testGeneratedFileInBuilder0( getProjectName() );
 	}
-	
+
 	/**
 	 *  Regresses Buzilla 103745 & 95661
 	 */
@@ -99,16 +100,16 @@ public class StarProcessorTests extends APTTestBase
 	{
 		_testGeneratedFileInBuilder0( getProjectName_ProjectRootAsSrcDir() );
 	}
-	
-	
+
+
 	public void testGeneratedFileInBuilder1() throws Exception{
 		_testGeneratedFileInBuilder1( getProjectName() );
 	}
-	
+
 	private void _testGeneratedFileInBuilder0(String projectName){
 		IProject project = env.getProject( projectName );
 		IPath srcRoot = getSourcePath( projectName );
-		
+
 		String code = "package p1;\n"
 			+ "//import org.eclipse.jdt.apt.tests.annotations.helloworld.HelloWorldAnnotation;"
 			+ "\n" + "public class A " + "\n" + "{"
@@ -117,7 +118,7 @@ public class StarProcessorTests extends APTTestBase
 			+ "\n"
 			+ "        generatedfilepackage.GeneratedFileTest.helloWorld();"
 			+ "\n" + "    }" + "\n" + "}" + "\n";
-	
+
 		IPath p1aPath = env.addClass( srcRoot, "p1", "A", //$NON-NLS-1$ //$NON-NLS-2$
 			code );
 
@@ -125,7 +126,7 @@ public class StarProcessorTests extends APTTestBase
 
 		expectingOnlyProblemsFor( p1aPath );
 		expectingOnlySpecificProblemFor( p1aPath, new ExpectedProblem(
-			"A", "generatedfilepackage cannot be resolved", p1aPath ) ); //$NON-NLS-1$ //$NON-NLS-2$	
+			"A", "generatedfilepackage cannot be resolved", p1aPath ) ); //$NON-NLS-1$ //$NON-NLS-2$
 
 		code = "package p1;\n"
 			+ "import org.eclipse.jdt.apt.tests.annotations.helloworld.HelloWorldAnnotation;"
@@ -143,14 +144,14 @@ public class StarProcessorTests extends APTTestBase
 	}
 
 	/**
-	 *  slight variation to _testGeneratedFileInBuilder0. 
-	 *  Difference: 
-	 *   The method invocation is not fully qualified and an import is added. 
+	 *  slight variation to _testGeneratedFileInBuilder0.
+	 *  Difference:
+	 *   The method invocation is not fully qualified and an import is added.
 	 */
 	private void _testGeneratedFileInBuilder1( String projectName )
 	{
 		IProject project = env.getProject( projectName );
-		IPath srcRoot = getSourcePath( projectName );	
+		IPath srcRoot = getSourcePath( projectName );
 
 		String code = "package p1;\n"
 			+ "import org.eclipse.jdt.apt.tests.annotations.helloworld.HelloWorldAnnotation;"
@@ -167,16 +168,16 @@ public class StarProcessorTests extends APTTestBase
 
 		expectingOnlyProblemsFor( new IPath[0] );
 	}
-	
+
 	/**
-	 *  Try generating a bogus type name; expect exception 
+	 *  Try generating a bogus type name; expect exception
 	 */
 	public void testGeneratingIllegalTypeName()
 	{
 		String projectName = getProjectName();
 		clearProcessorResult(HelloWorldAnnotationProcessor.class);
 		IProject project = env.getProject( projectName );
-		IPath srcRoot = getSourcePath( projectName );	
+		IPath srcRoot = getSourcePath( projectName );
 
 		String code = "package p1;\n"
 			+ "import org.eclipse.jdt.apt.tests.annotations.helloworld.HelloWorldAnnotation;"
@@ -208,7 +209,7 @@ public class StarProcessorTests extends APTTestBase
 		fullBuild( project.getFullPath() );
 		expectingNoProblems();
 	}
-	
+
 	/**
 	 *  Try running two processors on the same file, and look for interactions.
 	 *  Regression for https://bugs.eclipse.org/bugs/show_bug.cgi?id=175794
@@ -219,7 +220,7 @@ public class StarProcessorTests extends APTTestBase
 		clearProcessorResult(HelloWorldAnnotationProcessor.class);
 		clearProcessorResult(MessagerAnnotationProcessor.class);
 		IProject project = env.getProject( projectName );
-		IPath srcRoot = getSourcePath( projectName );	
+		IPath srcRoot = getSourcePath( projectName );
 
 		String codeMessageFirst = "package p1;\n"
 			+ "import org.eclipse.jdt.apt.tests.annotations.helloworld.HelloWorldAnnotation;\n"
@@ -238,11 +239,11 @@ public class StarProcessorTests extends APTTestBase
 		checkProcessorResult(HelloWorldAnnotationProcessor.class);
 		checkProcessorResult(MessagerAnnotationProcessor.class);
 		expectingOnlySpecificProblemFor( p1aPath, new ExpectedProblem(
-			"A", MessagerAnnotationProcessor.PROBLEM_TEXT_ERROR, p1aPath ) ); //$NON-NLS-1$ //$NON-NLS-2$	
+			"A", MessagerAnnotationProcessor.PROBLEM_TEXT_ERROR, p1aPath ) ); //$NON-NLS-1$ //$NON-NLS-2$
 	}
-	
 
-	
+
+
 	/**
 	 *  This test makes sure we run apt on generated files during build
 	 */
@@ -251,7 +252,7 @@ public class StarProcessorTests extends APTTestBase
 	{
 		IProject project = env.getProject( getProjectName() );
 		IPath srcRoot = getSourcePath( getProjectName() );
-		
+
 		String code = "package p1;\n"
 			+ "//import org.eclipse.jdt.apt.tests.annotations.nestedhelloworld.NestedHelloWorldAnnotation;"
 			+ "import generatedfilepackage.GeneratedFileTest;"
@@ -262,7 +263,7 @@ public class StarProcessorTests extends APTTestBase
 			+ "        GeneratedFileTest.helloWorld();"
 			+ "\n" + "    }" + "\n" + "}" + "\n";
 
-		
+
 		IPath p1aPath = env.addClass( srcRoot, "p1", "A", //$NON-NLS-1$ //$NON-NLS-2$
 			code );
 
@@ -270,7 +271,7 @@ public class StarProcessorTests extends APTTestBase
 
 		expectingOnlyProblemsFor( p1aPath );
 		expectingOnlySpecificProblemFor( p1aPath, new ExpectedProblem(
-			"A", "GeneratedFileTest cannot be resolved", p1aPath ) ); //$NON-NLS-1$ //$NON-NLS-2$	
+			"A", "GeneratedFileTest cannot be resolved", p1aPath ) ); //$NON-NLS-1$ //$NON-NLS-2$
 
 		code = "package p1;\n"
 			+ "import org.eclipse.jdt.apt.tests.annotations.nestedhelloworld.NestedHelloWorldAnnotation;\n"
@@ -287,11 +288,11 @@ public class StarProcessorTests extends APTTestBase
 
 		expectingOnlyProblemsFor( new IPath[0] );
 	}
-		
-	
+
+
 	/**
-	 *   This test makes sure that our extra-dependency stuff is hooked up in the build.  
-	 *   Specifically, we test to make sure that Extra dependencies only appear when 
+	 *   This test makes sure that our extra-dependency stuff is hooked up in the build.
+	 *   Specifically, we test to make sure that Extra dependencies only appear when
 	 *   an annotation processor looks up a type by name.  We also test that expected
 	 *   build output is there because of the dependency.
 	 */
@@ -300,113 +301,113 @@ public class StarProcessorTests extends APTTestBase
 	{
 		String codeA = "package p1.p2.p3.p4;\n"
 			+  "public class A { B b; }";
-		
+
 		String codeB1 = "package p1.p2.p3.p4;\n"
 			+  "public class B { }";
-		
+
 		String codeB2 = "package p1.p2.p3.p4;\n"
 			+  "public class B { public static void main( String[] argv ) {} }";
-		
+
 		String codeC = "package p1.p2.p3.p4;\n"
 			+  "public class C { }";
-		
+
 		String codeC2 = "package p1.p2.p3.p4;\n"
 			+  "public class C { public int foo; }";
-		
+
 		String codeD = "package p1.p2.p3.p4;\n"
 			+  "public class D { }";
-		 
+
 		String codeE = "package p1.p2.p3.p4;\n"
 			+  "public class E { }";
-		
+
 		IProject project = env.getProject( getProjectName() );
 		IPath srcRoot = getSourcePath( getProjectName() );
-		
+
 		env.addClass( srcRoot, "p1.p2.p3.p4", "A", //$NON-NLS-1$ //$NON-NLS-2$
 			codeA );
-		
+
 		env.addClass( srcRoot, "p1.p2.p3.p4", "B", //$NON-NLS-1$ //$NON-NLS-2$
 			codeB1 );
-		
+
 		env.addClass( srcRoot, "p1.p2.p3.p4", "C", //$NON-NLS-1$ //$NON-NLS-2$
 			codeC );
-		
+
 		env.addClass( srcRoot, "p1.p2.p3.p4", "D", //$NON-NLS-1$ //$NON-NLS-2$
 			codeD );
-		
+
 		env.addClass( srcRoot, "p1.p2.p3.p4", "E", //$NON-NLS-1$ //$NON-NLS-2$
 			codeE );
-		
+
 		fullBuild( project.getFullPath() );
 		expectingNoProblems();
-		
+
 		// touch B - make sure its public shape changes.
 		env.addClass( srcRoot, "p1.p2.p3.p4", "B", //$NON-NLS-1$ //$NON-NLS-2$
 			codeB2 );
-		
+
 		incrementalBuild( project.getFullPath() );
 		expectingNoProblems();
 		expectingCompiledClasses(new String[]{"p1.p2.p3.p4.B", "p1.p2.p3.p4.A"}); //$NON-NLS-1$ //$NON-NLS-2$
 		expectingCompilingOrder(new String[]{"p1.p2.p3.p4.B", "p1.p2.p3.p4.A"}); //$NON-NLS-1$ //$NON-NLS-2$
 
 		//
-		//  Now have p1.p2.p3.p4.A w/ an anontation whose processor looks up p1.p2.p3.p4.C by name 
+		//  Now have p1.p2.p3.p4.A w/ an anontation whose processor looks up p1.p2.p3.p4.C by name
 		//
-		
+
 		// new code for A with an annotation processor that should introduce a dep on C
 		codeA = "package p1.p2.p3.p4;\n"
-			+  "import org.eclipse.jdt.apt.tests.annotations.extradependency.ExtraDependencyAnnotation;" + "\n" 
-			+  "@ExtraDependencyAnnotation" + "\n" 
+			+  "import org.eclipse.jdt.apt.tests.annotations.extradependency.ExtraDependencyAnnotation;" + "\n"
+			+  "@ExtraDependencyAnnotation" + "\n"
 			+  "public class A {  }";
-		
+
 		env.addClass( srcRoot, "p1.p2.p3.p4", "A", //$NON-NLS-1$ //$NON-NLS-2$
 			codeA );
-		
+
 		fullBuild( project.getFullPath() );
 		expectingNoProblems();
-		
+
 		// touch C
 		env.addClass( srcRoot, "p1.p2.p3.p4", "C", //$NON-NLS-1$ //$NON-NLS-2$
 			codeC2 );
-		
+
 		incrementalBuild( project.getFullPath() );
 		expectingNoProblems();
-		
+
 		//
-		// Note that p1.p2.p3.p4.A is showing up twice because it has annotations, and we need to 
-		// parse the source, parsing runs through the compiler, and this registers the 
-		// file a second time with the Compiler#DebugRequestor 
+		// Note that p1.p2.p3.p4.A is showing up twice because it has annotations, and we need to
+		// parse the source, parsing runs through the compiler, and this registers the
+		// file a second time with the Compiler#DebugRequestor
 		//
 		expectingCompiledClasses(new String[]{"p1.p2.p3.p4.C", "p1.p2.p3.p4.A", "p1.p2.p3.p4.A"}); //$NON-NLS-1$ //$NON-NLS-2$
 		expectingCompilingOrder(new String[]{"p1.p2.p3.p4.C", "p1.p2.p3.p4.A", "p1.p2.p3.p4.A"}); //$NON-NLS-1$ //$NON-NLS-2$
-		
+
 		//
 		// now make sure that p1.p2.p3.p4.C is not compiled when A uses NoOp Annotation
 		//
-		
+
 		// new code for A with an annotation processor that should remove a dep on C
 		codeA = "package p1.p2.p3.p4;\n"
-			+  "import org.eclipse.jdt.apt.tests.annotations.noop.NoOpAnnotation;" + "\n" 
-			+  "@NoOpAnnotation" + "\n" 
+			+  "import org.eclipse.jdt.apt.tests.annotations.noop.NoOpAnnotation;" + "\n"
+			+  "@NoOpAnnotation" + "\n"
 			+  "public class A { B b; D d; }";
-		
+
 		env.addClass( srcRoot, "p1.p2.p3.p4", "A", //$NON-NLS-1$ //$NON-NLS-2$
 			codeA );
-		
+
 		fullBuild( project.getFullPath() );
 		expectingNoProblems();
-		
+
 		// touch C
 		env.addClass( srcRoot, "p1.p2.p3.p4", "C", //$NON-NLS-1$ //$NON-NLS-2$
 			codeC2 );
-		
+
 		incrementalBuild( project.getFullPath() );
 		expectingNoProblems();
-		
+
 		//
-		// Note that p1.p2.p3.p4.A is showing up twice because it has annotations, and we need to 
-		// parse the source, parsing runs through the compiler, and this registers the 
-		// file a second time with the Compiler#DebugRequestor 
+		// Note that p1.p2.p3.p4.A is showing up twice because it has annotations, and we need to
+		// parse the source, parsing runs through the compiler, and this registers the
+		// file a second time with the Compiler#DebugRequestor
 		//
 		expectingCompiledClasses(new String[]{"p1.p2.p3.p4.C" }); //$NON-NLS-1$ //$NON-NLS-2$
 		expectingCompilingOrder(new String[]{"p1.p2.p3.p4.C" }); //$NON-NLS-1$ //$NON-NLS-2$
@@ -425,11 +426,11 @@ public class StarProcessorTests extends APTTestBase
 			+ "    @HelloWorldAnnotation" + "\n"
 			+ "    public static void main( String[] argv )" + "\n" + "    {"
 			+ "\n"
-			+ "    }" 
-			+ "\n" 
-			+ "}" 
+			+ "    }"
+			+ "\n"
+			+ "}"
 			+ "\n";
-		
+
 		String modifiedCode = "package p1;\n"
 			+ "import org.eclipse.jdt.apt.tests.annotations.helloworld.HelloWorldAnnotation;"
 			+ "\n" + "public class A " + "\n" + "{"
@@ -437,25 +438,25 @@ public class StarProcessorTests extends APTTestBase
 			+ "    public static void main( String[] argv )" + "\n" + "    {"
 			+ "\n"
 			+ "        "
-			+ "\n" 
-			+ "    }" 
-			+ "\n" 
+			+ "\n"
+			+ "    }"
+			+ "\n"
 			+ "    public static void otherMethod()" + "\n" + "    {"
 			+ "        System.out.println();\n"
 			+ "    }"
-			+ "}" 
+			+ "}"
 			+ "\n";
-		
+
 		IProject project = env.getProject( getProjectName() );
 		IPath srcRoot = getSourcePath( getProjectName() );
-		
+
 		env.addClass( srcRoot, "p1", "A", //$NON-NLS-1$ //$NON-NLS-2$
 			code );
-		
+
 		fullBuild( project.getFullPath() );
 		expectingNoProblems();
 		expectingCompiledClasses(new String[] {"p1.A", "p1.A", "generatedfilepackage.GeneratedFileTest"}); //$NON-NLS-1 //$NON_NLS-2$
-		
+
 		// touch A - make sure its public shape changes.
 		env.addClass( srcRoot, "p1", "A", //$NON-NLS-1$ //$NON-NLS-2$
 			modifiedCode );
@@ -465,7 +466,7 @@ public class StarProcessorTests extends APTTestBase
 	}
 
 	/**
-	 * This test makes sure that we delete generated files when the parent file 
+	 * This test makes sure that we delete generated files when the parent file
 	 * is deleted.  We also make sure that multi-parent support is working.
 	 */
 
@@ -491,20 +492,20 @@ public class StarProcessorTests extends APTTestBase
 			a2Code );
 		IPath p1bPath = env.addClass( srcRoot, "p1", "B", //$NON-NLS-1$ //$NON-NLS-2$
 			bCode );
-		
+
 		fullBuild( project.getFullPath() );
 		expectingNoProblems();
-		
+
 		// now delete file A1 and make sure we still have no problems
 		TestUtil.deleteFile(p1a1Path);
-		
+
 		// sleep to let the resource-change event fire
 		sleep( 1000 );
-		
+
 		incrementalBuild( project.getFullPath() );
-		
+
 		expectingNoProblems();
-		
+
 		// now delete file A2 and make sure we have a problem on B
 		TestUtil.deleteFile( p1a2Path );
 
@@ -515,9 +516,9 @@ public class StarProcessorTests extends APTTestBase
 		incrementalBuild( project.getFullPath() );
 		expectingOnlyProblemsFor( p1bPath );
 		expectingOnlySpecificProblemFor( p1bPath, new ExpectedProblem(
-			"B", "generatedfilepackage cannot be resolved to a type", p1bPath ) ); //$NON-NLS-1$ //$NON-NLS-2$	
+			"B", "generatedfilepackage cannot be resolved to a type", p1bPath ) ); //$NON-NLS-1$ //$NON-NLS-2$
 	}
-	
+
 	public void testStopGeneratingFileInBuilder_FullBuild()
 	{
 		internalTestStopGeneratingFileInBuilder( true );
@@ -527,12 +528,12 @@ public class StarProcessorTests extends APTTestBase
 	{
 		internalTestStopGeneratingFileInBuilder( false );
 	}
-	
+
 	private void internalTestStopGeneratingFileInBuilder( boolean fullBuild )
 	{
 		IProject project = env.getProject( getProjectName() );
 		IPath srcRoot = getSourcePath( getProjectName() );
-		
+
 		String code = "package p1;\n"
 			+ "//import org.eclipse.jdt.apt.tests.annotations.helloworld.HelloWorldAnnotation;\n"
 			+ "import generatedfilepackage.GeneratedFileTest;"
@@ -543,7 +544,7 @@ public class StarProcessorTests extends APTTestBase
 			+ "        GeneratedFileTest.helloWorld();"
 			+ "\n" + "    }" + "\n" + "}" + "\n";
 
-		
+
 		IPath p1aPath = env.addClass( srcRoot, "p1", "A", //$NON-NLS-1$ //$NON-NLS-2$
 			code );
 
@@ -551,13 +552,13 @@ public class StarProcessorTests extends APTTestBase
 			fullBuild( project.getFullPath() );
 		else
 			incrementalBuild( project.getFullPath() );
-		
+
 
 		expectingOnlyProblemsFor( p1aPath );
-		expectingOnlySpecificProblemsFor( p1aPath, new ExpectedProblem[]{ 
+		expectingOnlySpecificProblemsFor( p1aPath, new ExpectedProblem[]{
 				new ExpectedProblem( "A", "The import generatedfilepackage cannot be resolved", p1aPath ),
 				new ExpectedProblem( "A", "GeneratedFileTest cannot be resolved", p1aPath ) }
-				); //$NON-NLS-1$ //$NON-NLS-2$	
+				); //$NON-NLS-1$ //$NON-NLS-2$
 
 		code = "package p1;\n"
 			+ "import org.eclipse.jdt.apt.tests.annotations.helloworld.HelloWorldAnnotation;"
@@ -574,7 +575,7 @@ public class StarProcessorTests extends APTTestBase
 			fullBuild( project.getFullPath() );
 		else
 			incrementalBuild( project.getFullPath() );
-		
+
 		expectingOnlyProblemsFor( new IPath[0] );
 
 		// do a full build again.  This is necessary because generating the file
@@ -582,7 +583,7 @@ public class StarProcessorTests extends APTTestBase
 		// a full build because of the classpath change
 		if ( ! fullBuild )
 			fullBuild( project.getFullPath() );
-		
+
 		// now remove the annotation.  The generated file should go away
 		// and we should see errors again
 		code = "package p1;\n"
@@ -596,48 +597,48 @@ public class StarProcessorTests extends APTTestBase
 			+ "\n" + "    }" + "\n" + "}" + "\n";
 
 		env.addClass( srcRoot, "p1", "A", code );
-		
+
 		if ( fullBuild )
 			fullBuild( project.getFullPath() );
 		else
 			incrementalBuild( project.getFullPath() );
-		
+
 		expectingOnlyProblemsFor( p1aPath );
-		
-		expectingOnlySpecificProblemFor( p1aPath, 
-					new ExpectedProblem( "A", "GeneratedFileTest cannot be resolved", p1aPath ) ); //$NON-NLS-1$ 
+
+		expectingOnlySpecificProblemFor( p1aPath,
+					new ExpectedProblem( "A", "GeneratedFileTest cannot be resolved", p1aPath ) ); //$NON-NLS-1$
 	}
-	
+
 	public void testAPTRounding()
 	{
 		IProject project = env.getProject( getProjectName() );
 		IPath srcRoot = getSourcePath( getProjectName()  );
-		
+
 		String codeX = "package p1;\n"
 			+ "\n import org.eclipse.jdt.apt.tests.annotations.aptrounding.*;"
 			+ "\n@GenBean\n"
 			+ "public class X {}\n";
-		
+
 		env.addClass( srcRoot, "p1", "X", codeX );
-		
+
 		String codeY = "package p1;\n"
 			+ "\n import org.eclipse.jdt.apt.tests.annotations.aptrounding.*;"
 			+ "public class Y { @GenBean2 test.Bean _bean = null; }\n";
-		
+
 		env.addClass( srcRoot, "p1", "Y", codeY );
 
 		fullBuild( project.getFullPath() );
-		
+
 		expectingNoProblems();
 	}
-	
+
 	public void testConfigMarker() throws Exception{
-		final String projectName = "ConfigMarkerTestProject";	
+		final String projectName = "ConfigMarkerTestProject";
 		final IJavaProject javaProj = createJavaProject( projectName );
 		// apt is currently disabled save off the cp before configuration
-		final IClasspathEntry[] cp = javaProj.getRawClasspath();		
+		final IClasspathEntry[] cp = javaProj.getRawClasspath();
 		IProject project = env.getProject( projectName );
-		IPath srcRoot = getSourcePath( projectName );		
+		IPath srcRoot = getSourcePath( projectName );
 		// this will cause a type generation.
 		String code = "package pkg;\n"
 			+ "import org.eclipse.jdt.apt.tests.annotations.helloworld.HelloWorldAnnotation;"
@@ -645,44 +646,44 @@ public class StarProcessorTests extends APTTestBase
 			+ "    @HelloWorldAnnotation\n"
 			+ "    public static void main( String[] argv ){}"
 			+ "\n}";
-		
+
 		env.addClass( srcRoot, "pkg", "Foo", code );
-		
+
 		AptConfig.setEnabled(javaProj, true);
 		fullBuild( project.getFullPath() );
 		expectingNoProblems();
 		expectingNoMarkers();
-		
+
 		// wipe out the source folder from the classpath.
 		javaProj.setRawClasspath(cp, null);
 		fullBuild( project.getFullPath() );
 		expectingNoProblems();
 		// make sure we post the marker about the incorrect classpath
-		expectingMarkers(new String[]{"Generated source folder '" + 
-				AptPreferenceConstants.DEFAULT_GENERATED_SOURCE_FOLDER_NAME + 
+		expectingMarkers(new String[]{"Generated source folder '" +
+				AptPreferenceConstants.DEFAULT_GENERATED_SOURCE_FOLDER_NAME +
 				"' is missing from classpath"} );
-		
+
 		// take out the annotation and no type generation will occur.
 		code = "package pkg;\n"
-			+ "\npublic class Foo{\n"			
+			+ "\npublic class Foo{\n"
 			+ "    public static void main( String[] argv ){}"
 			+ "\n}";
-		
+
 		env.addClass( srcRoot, "pkg", "Foo", code );
-		fullBuild( project.getFullPath() );		
+		fullBuild( project.getFullPath() );
 		expectingNoProblems();
 		// Make sure we cleaned out config marker from previous build
-		// We don't need to generate types, hence we should not register the config marker 
+		// We don't need to generate types, hence we should not register the config marker
 		expectingNoMarkers();
 	}
-	
+
 	public void testDeletedGeneratedSourceFolder()
 		throws Exception
 	{
-		final String projectName = "DeleteGenSourceFolderTestProject";	
+		final String projectName = "DeleteGenSourceFolderTestProject";
 		final IJavaProject javaProj = createJavaProject( projectName );
 		IProject project = env.getProject( projectName );
-		IPath srcRoot = getSourcePath( projectName );		
+		IPath srcRoot = getSourcePath( projectName );
 		// this will cause a type generation.
 		String code = "package pkg;\n"
 			+ "import org.eclipse.jdt.apt.tests.annotations.helloworld.HelloWorldAnnotation;"
@@ -690,24 +691,24 @@ public class StarProcessorTests extends APTTestBase
 			+ "    @HelloWorldAnnotation\n"
 			+ "    public static void main( String[] argv ){}"
 			+ "\n}";
-		
+
 		env.addClass( srcRoot, "pkg", "Foo", code );
 		AptConfig.setEnabled(javaProj, true);
 		fullBuild( project.getFullPath() );
 		expectingNoProblems();
 		expectingNoMarkers();
-		
+
 		GeneratedSourceFolderManager mgr = AptPlugin.getAptProject(javaProj).getGeneratedSourceFolderManager(false);
 		IFolder srcFolder = mgr.getFolder();
 		assertEquals(true, srcFolder.exists());
 		// delete the gen source folder
 		Util.delete(srcFolder);
 		assertEquals(false, srcFolder.exists());
-		
+
 		// we would have re-created the folder on the next build
 		fullBuild( project.getFullPath() );
 		expectingNoProblems();
 		expectingNoMarkers();
 	}
-	
+
 }
