@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2020, 2022 IBM Corporation.
+ * Copyright (c) 2020, 2023 IBM Corporation.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -132,7 +132,8 @@ public class RecordElementProcessor extends BaseElementProcessor {
 			assertTrue("Preview flag not seen as enabled", preview);
 		}
 		SourceVersion sourceVersion = this.processingEnv.getSourceVersion();
-		assertEquals("Should support the latest compliance", sourceVersion, SourceVersion.RELEASE_6);
+		SourceVersion expected = SourceVersion.valueOf("RELEASE_" + Runtime.version().feature());
+		assertEquals("Should support the latest compliance", expected, sourceVersion);
 	}
 	/*
 	 * Basic test for record element and kind
@@ -281,6 +282,8 @@ public class RecordElementProcessor extends BaseElementProcessor {
 		assertNotNull("TypeElement for record should not be null", record);
 		verifyAnnotations(record, new String[]{"@Deprecated()"});
 
+		assertEquals("incorrect no of record components", 6, record.getRecordComponents().size());
+
 		List<? extends Element> enclosedElements = record.getEnclosedElements();
 		assertNotNull("enclosedElements for record should not be null", enclosedElements);
 		List<RecordComponentElement> recordComponentsIn = ElementFilter.recordComponentsIn(enclosedElements);
@@ -590,4 +593,33 @@ public class RecordElementProcessor extends BaseElementProcessor {
 		assertEquals("component name incorrect", "i", var.getSimpleName().toString());
 		verifyAnnotations(var, new String[]{"@Marker4()"});
 	}
+	public void testRecordsConstructors() {
+		Set<? extends Element> elements = roundEnv.getRootElements();
+		TypeElement record = find(elements, "Record2");
+		assertNotNull("TypeElement for record should not be null", record);
+		List<? extends Element> enclosedElements = record.getEnclosedElements();
+		List<ExecutableElement> methods = ElementFilter.constructorsIn(enclosedElements);
+		assertEquals("Incorrect no of constructors", 1, methods.size());
+		ExecutableElement constr = methods.get(0);
+		if (isBinaryMode) {
+			assertFalse("Should not be canonical constructor", _elementUtils.isCanonicalConstructor(constr));
+			assertFalse("Should not be compact constructor", _elementUtils.isCompactConstructor(constr));
+		} else {
+			assertTrue("Should be canonical constructor", _elementUtils.isCanonicalConstructor(constr));
+			assertFalse("Should not be compact constructor", _elementUtils.isCompactConstructor(constr));
+		}
+		record = find(elements, "Record3");
+		assertNotNull("TypeElement for record should not be null", record);
+		enclosedElements = record.getEnclosedElements();
+		methods = ElementFilter.constructorsIn(enclosedElements);
+		assertEquals("Incorrect no of constructors", 1, methods.size());
+		constr = methods.get(0);
+		if (isBinaryMode) {
+			assertFalse("Should not be canonical constructor", _elementUtils.isCanonicalConstructor(constr));
+			assertFalse("Should not be compact constructor", _elementUtils.isCompactConstructor(constr));
+		} else {
+			assertTrue("Should not be canonical constructor", _elementUtils.isCanonicalConstructor(constr));
+			assertTrue("Should be a compact constructor", _elementUtils.isCompactConstructor(constr));
+		}
+	}
 }
