@@ -8,5 +8,9 @@ public strictfp record Record2(int x, BigInteger i, Record3 r, Test t) {
 	public static double d;
 	protected static Character c;
 }
-record Record3 () {}
+record Record3 (int x, int y) {
+	Record3 {
+		x = y;
+	}
+}
 class Test{}
\ No newline at end of file
