@@ -480,10 +480,6 @@ public class AbstractSyntaxTreeTest extends AbstractCompilerTest implements IDoc
 	public void exitType(int declarationEnd) {
 
 
-	}
-	@Override
-	public void exitRecordComponent(int declarationEnd, int declarationSourceEnd) {
-
 	}
 
 }
\ No newline at end of file
