@@ -43,7 +43,7 @@ public SourceField(
 	this.source = source;
 }
 public String displayModifiers() {
-	StringBuffer buffer = new StringBuffer();
+	StringBuilder buffer = new StringBuilder();
 
 	if (this.modifiers == 0)
 		return null;
@@ -66,7 +66,7 @@ public String displayModifiers() {
 	return buffer.toString();
 }
 public String getActualName() {
-	StringBuffer buffer = new StringBuffer();
+	StringBuilder buffer = new StringBuilder();
 	buffer.append(this.source, this.nameSourceStart, this.nameSourceEnd - this.nameSourceStart + 1);
 	return buffer.toString();
 }
@@ -110,7 +110,7 @@ public String toString() {
 	return toString(0);
 }
 public String toString(int tab) {
-	StringBuffer buffer = new StringBuffer();
+	StringBuilder buffer = new StringBuilder();
 	buffer.append(tabString(tab));
 	String displayModifiers = displayModifiers();
 	if (displayModifiers != null) {
