@@ -17,6 +17,8 @@ import java.io.File;
 import java.io.IOException;
 
 import org.eclipse.jdt.core.tests.util.Util;
+import org.eclipse.jdt.internal.compiler.batch.ClasspathJrt;
+import org.eclipse.jdt.internal.compiler.impl.CompilerOptions;
 
 import junit.framework.Test;
 
@@ -129,6 +131,14 @@ public class NullAnnotationBatchCompilerTest extends AbstractBatchCompilerTest {
 		Util.delete(OUTPUT_DIR);
 	}
 
+	/** Call this to discard eea-superimposed JRE classes from the JRT cache. */
+	public void clearJrtCache(String releaseVersion) {
+		String[] javaClassLibs = Util.getJavaClassLibs();
+		if (javaClassLibs.length == 1 && javaClassLibs[0].endsWith("/lib/jrt-fs.jar")) {
+			ClasspathJrt.clearCache(javaClassLibs[0], releaseVersion);
+		}
+	}
+
 	// https://bugs.eclipse.org/bugs/show_bug.cgi?id=325342
 	// -err option - regression tests to check option nullAnnot
 	// Null warnings because of annotations, null spec violations plus one specific problem configured as errors
@@ -829,9 +839,14 @@ public class NullAnnotationBatchCompilerTest extends AbstractBatchCompilerTest {
 					"1. WARNING in ---OUTPUT_DIR_PLACEHOLDER---/test1/Test1.java (at line 13)\n" +
 					"	public boolean equals(@NonNull Object other) { return false; }\n" +
 					"	                      ^^^^^^^^^^^^^^^\n" +
+					"The nullness annotation is redundant with a default that applies to this location\n" +
+					"----------\n" +
+					"2. WARNING in ---OUTPUT_DIR_PLACEHOLDER---/test1/Test1.java (at line 13)\n" +
+					"	public boolean equals(@NonNull Object other) { return false; }\n" +
+					"	                      ^^^^^^^^^^^^^^^\n" +
 					"Illegal redefinition of parameter other, inherited method from Object declares this parameter as @Nullable\n" +
 					"----------\n" +
-					"1 problem (1 warning)\n";
+					"2 problems (2 warnings)\n";
 		try {
 			if (isSuccess)
 				this.runConformTest(testFiles, commandLine, "", expectedCompilerMessage, true);
@@ -943,9 +958,14 @@ public class NullAnnotationBatchCompilerTest extends AbstractBatchCompilerTest {
 				"3. WARNING in ---OUTPUT_DIR_PLACEHOLDER---/test1/Test1.java (at line 13)\n" +
 				"	public boolean equals(@NonNull Object other) { return false; }\n" +
 				"	                      ^^^^^^^^^^^^^^^\n" +
+				"The nullness annotation is redundant with a default that applies to this location\n" +
+				"----------\n" +
+				"4. WARNING in ---OUTPUT_DIR_PLACEHOLDER---/test1/Test1.java (at line 13)\n" +
+				"	public boolean equals(@NonNull Object other) { return false; }\n" +
+				"	                      ^^^^^^^^^^^^^^^\n" +
 				"Illegal redefinition of parameter other, inherited method from Object declares this parameter as @Nullable\n" +
 				"----------\n" +
-				"3 problems (3 warnings)\n",
+				"4 problems (4 warnings)\n",
 				true);
 	}
 
@@ -980,9 +1000,14 @@ public class NullAnnotationBatchCompilerTest extends AbstractBatchCompilerTest {
 				"3. WARNING in ---OUTPUT_DIR_PLACEHOLDER---/test1/Test1.java (at line 13)\n" +
 				"	public boolean equals(@NonNull Object other) { return false; }\n" +
 				"	                      ^^^^^^^^^^^^^^^\n" +
+				"The nullness annotation is redundant with a default that applies to this location\n" +
+				"----------\n" +
+				"4. WARNING in ---OUTPUT_DIR_PLACEHOLDER---/test1/Test1.java (at line 13)\n" +
+				"	public boolean equals(@NonNull Object other) { return false; }\n" +
+				"	                      ^^^^^^^^^^^^^^^\n" +
 				"Illegal redefinition of parameter other, inherited method from Object declares this parameter as @Nullable\n" +
 				"----------\n" +
-				"3 problems (3 warnings)\n",
+				"4 problems (4 warnings)\n",
 				true);
 	}
 
@@ -1017,9 +1042,14 @@ public class NullAnnotationBatchCompilerTest extends AbstractBatchCompilerTest {
 				"3. WARNING in ---OUTPUT_DIR_PLACEHOLDER---/test1/Test1.java (at line 13)\n" +
 				"	public boolean equals(@NonNull Object other) { return false; }\n" +
 				"	                      ^^^^^^^^^^^^^^^\n" +
+				"The nullness annotation is redundant with a default that applies to this location\n" +
+				"----------\n" +
+				"4. WARNING in ---OUTPUT_DIR_PLACEHOLDER---/test1/Test1.java (at line 13)\n" +
+				"	public boolean equals(@NonNull Object other) { return false; }\n" +
+				"	                      ^^^^^^^^^^^^^^^\n" +
 				"Illegal redefinition of parameter other, inherited method from Object declares this parameter as @Nullable\n" +
 				"----------\n" +
-				"3 problems (3 warnings)\n",
+				"4 problems (4 warnings)\n",
 				true);
 	}
 	public void testBug571055_explicit() throws IOException {
@@ -1116,4 +1146,81 @@ public class NullAnnotationBatchCompilerTest extends AbstractBatchCompilerTest {
 				"2 problems (1 error, 1 warning)\n";
 		this.runNegativeTest(testFiles, commandLine, "", expectedCompilerMessage, false);
 	}
+
+	public void testGHTycho1641() throws IOException {
+		try {
+			// tests external annotations with --release option
+			String annotDir = OUTPUT_DIR + File.separator + "eea";
+			String annotJavaUtilDir = annotDir + "/java/util".replace('/', File.separatorChar);
+			new File(annotJavaUtilDir).mkdirs();
+			Util.createFile(annotJavaUtilDir + File.separatorChar + "Objects.eea",
+					"class java/util/Objects\n" +
+					"requireNonNull\n" +
+					" <T:Ljava/lang/Object;>(TT;)TT;\n" +
+					" <T:Ljava/lang/Object;>(TT;)T1T;\n");
+			runConformTest(
+				new String[] {
+					"org/eclipse/jdt/annotation/NonNull.java",
+					NONNULL_ANNOTATION_18_CONTENT,
+					"org/eclipse/jdt/annotation/Nullable.java",
+					NULLABLE_ANNOTATION_18_CONTENT,
+					"collectiontest/TestClass.java",
+					"package collectiontest;\n" +
+					"import java.util.Objects;\n" +
+					"import org.eclipse.jdt.annotation.Nullable;\n" +
+					"public class TestClass {\n" +
+					"\n" +
+					"    @Nullable String test;\n" +
+					"\n" +
+					"    public void concat(String suffix) {\n" +
+					"        test = Objects.requireNonNull(test).concat(suffix);\n" +
+					"    }\n" +
+					"}\n"
+				},
+				"--release 11 "+
+				" -sourcepath \"" + OUTPUT_DIR + "\"" +
+				" -annotationpath \""+annotDir+ "\"" +
+				" -err:+nullAnnot -err:+null -proc:none -d \"" + OUTPUT_DIR + "\"" +
+				" \"" + OUTPUT_DIR +  File.separator + "collectiontest" + File.separator + "TestClass.java\"",
+				"",
+				"",
+				false);
+		} finally {
+			clearJrtCache("11");
+		}
+	}
+
+	public void testGH703() {
+		// replicates NullTypeAnnotationTest.testBug456584() but with --release option
+		runConformTest(
+			new String[] {
+				"p/Test.java",
+				"package p;\n" +
+				"import java.util.*;\n" +
+				"import java.util.function.*;\n" +
+				"import org.eclipse.jdt.annotation.*;\n" +
+				"\n" +
+				"@NonNullByDefault\n" +
+				"public class Test {\n" +
+				"\n" +
+				"  public static final <T,R> @NonNull R applyRequired(final T input, final Function<? super T,? extends R> function) { // Warning on '@NonNull R': \"The nullness annotation is redundant with a default that applies to this location\"\n" +
+				"    return Objects.requireNonNull(function.apply(input));\n" +
+				"  }\n" +
+				"\n" +
+				"}\n",
+				"org/eclipse/jdt/annotation/NonNull.java",
+				NONNULL_ANNOTATION_18_CONTENT,
+				"org/eclipse/jdt/annotation/Nullable.java",
+				NULLABLE_ANNOTATION_18_CONTENT,
+				"org/eclipse/jdt/annotation/NonNullByDefault.java",
+				NONNULL_BY_DEFAULT_ANNOTATION_CONTENT
+			},
+			"\"" + OUTPUT_DIR +  File.separator + "p" + File.separator + "Test.java\"" +
+					" --release " + CompilerOptions.VERSION_9 + " " +
+					" -sourcepath \"" + OUTPUT_DIR + "\"" +
+					" -warn:+nullAnnot -warn:+null ",
+					"",
+					"",
+					true);
+	}
 }
