@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2021, 2022 GK Software SE, and others.
+ * Copyright (c) 2021, 2023 GK Software SE, and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -19,6 +19,7 @@ import java.io.File;
 import java.io.IOException;
 import java.util.Map;
 
+import org.eclipse.jdt.core.JavaCore;
 import org.eclipse.jdt.core.tests.util.Util;
 import org.eclipse.jdt.internal.compiler.impl.CompilerOptions;
 
@@ -37,7 +38,7 @@ public class NullAnnotationTests18 extends AbstractNullAnnotationTest {
 	}
 
 	public static Test suite() {
-		return buildMinimalComplianceTestSuite(testClass(), F_19);
+		return buildMinimalComplianceTestSuite(testClass(), F_20);
 	}
 
 	public static Class<?> testClass() {
@@ -128,7 +129,7 @@ public class NullAnnotationTests18 extends AbstractNullAnnotationTest {
 		Runner runner = new Runner();
 		runner.classLibraries = this.LIBS;
 		Map<String,String> opts = getCompilerOptions();
-		opts.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_19);
+		opts.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_20);
 		opts.put(CompilerOptions.OPTION_EnablePreviews, CompilerOptions.ENABLED);
 		opts.put(CompilerOptions.OPTION_ReportPreviewFeatures, CompilerOptions.IGNORE);
 		runner.customOptions = opts;
@@ -165,7 +166,7 @@ public class NullAnnotationTests18 extends AbstractNullAnnotationTest {
 		runner.runConformTest();
 	}
 
-	public void test_totalTypePatternAdmitsNull() {
+	public void test_totalTypePatternDoesNotAdmitNull() {
 		Runner runner = getDefaultRunner();
 		runner.testFiles = new String[] {
 				"X.java",
@@ -200,7 +201,8 @@ public class NullAnnotationTests18 extends AbstractNullAnnotationTest {
 				"	                                ^^\n" +
 				"Null type safety (type annotations): The expression of type \'Number\' needs unchecked conversion to conform to \'@NonNull Number\'\n" +
 				"----------\n";
-		runner.expectedOutputString = "Cannot invoke \"Object.toString()\" because \"n\" is null";
+//		runner.expectedOutputString = "Cannot invoke \"Object.toString()\" because \"n\" is null";
+		runner.expectedOutputString = "null";
 		runner.runConformTest();
 	}
 
@@ -345,7 +347,8 @@ public class NullAnnotationTests18 extends AbstractNullAnnotationTest {
 		runner.runConformTest();
 	}
 
-	public void test_switchNullInSameCase() {
+	// null cannot be in the same case with pattern as per the 432+433 jep
+	public void _test_switchNullInSameCase() {
 		Runner runner = getDefaultRunner();
 		runner.customOptions.put(CompilerOptions.OPTION_ReportRedundantNullCheck, CompilerOptions.WARNING);
 		runner.testFiles = new String[] {
@@ -449,8 +452,8 @@ public class NullAnnotationTests18 extends AbstractNullAnnotationTest {
 				  "	void foo(@Nullable Object o) {\n" +
 				  "		switch (o) {\n" +
 				  "			case Integer i -> consumeInt(i);\n" +
-				  "			default -> System.out.println(o.toString());\n" +
 				  "			case null -> System.out.print(\"null\");\n" +
+				  "			default -> System.out.println(o.toString());\n" +
 				  "		};\n" +
 				  "	}\n" +
 				  "	void consumeInt(@NonNull Integer i) {\n" +
@@ -476,8 +479,8 @@ public class NullAnnotationTests18 extends AbstractNullAnnotationTest {
 				  "	void foo() {\n" +
 				  "		switch (this.o) {\n" +
 				  "			case Integer i -> consumeInt(i);\n" +
-				  "			default -> System.out.println(this.o.toString());\n" +
 				  "			case null -> System.out.print(\"null\");\n" +
+				  "			default -> System.out.println(this.o.toString());\n" +
 				  "		};\n" +
 				  "	}\n" +
 				  "	void consumeInt(@NonNull Integer i) {\n" +
@@ -503,8 +506,8 @@ public class NullAnnotationTests18 extends AbstractNullAnnotationTest {
 				  "	void foo(X x) {\n" +
 				  "		switch (x.o) {\n" +
 				  "			case Integer i -> consumeInt(i);\n" +
-				  "			default -> System.out.println(x.o.toString());\n" +
 				  "			case null -> System.out.print(\"null\");\n" +
+				  "			default -> System.out.println(x.o.toString());\n" +
 				  "		};\n" +
 				  "	}\n" +
 				  "	void consumeInt(@NonNull Integer i) {\n" +
@@ -628,4 +631,253 @@ public class NullAnnotationTests18 extends AbstractNullAnnotationTest {
 				"----------\n";
 		runner.runNegativeTest();
 	}
+	public void _testGH629_01() {
+		Map<String, String> options = getCompilerOptions();
+		options.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_18);
+		options.put(JavaCore.COMPILER_NONNULL_ANNOTATION_NAME, "test.NonNull");
+		options.put(JavaCore.COMPILER_NULLABLE_ANNOTATION_NAME, "test.Nullable");
+		options.put(JavaCore.COMPILER_ANNOTATION_NULL_ANALYSIS, JavaCore.ENABLED);
+
+		runNegativeTestWithLibs(
+				new String[] {
+						"Configuration.java",
+						"public interface Configuration {\n" +
+								"}\n",
+						"Init.java",
+						"public interface Init<C extends Configuration> {\n" +
+								"}\n",
+						"Annot.java",
+						"public @interface Annot {\n" +
+								"    Class<? extends Init<? extends Configuration>>[] inits(); \n" +
+								"}\n",
+						"App.java",
+						"interface I<T> {}\n" +
+						"@Annot(inits = {App.MyInit.class})\n" +
+								"public class App {\n" +
+								"    static class MyInit implements I<String>, Init<Configuration> {}\n" +
+								"}\n"
+				},
+				options,
+				"");
+	}
+	public void _testGH629_02() {
+		Map<String, String> options = getCompilerOptions();
+		options.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_18);
+		options.put(JavaCore.COMPILER_NONNULL_ANNOTATION_NAME, "test.NonNull");
+		options.put(JavaCore.COMPILER_NULLABLE_ANNOTATION_NAME, "test.Nullable");
+		options.put(JavaCore.COMPILER_ANNOTATION_NULL_ANALYSIS, JavaCore.ENABLED);
+
+		runNegativeTestWithLibs(
+				new String[] {
+						"Annot.java",
+						"public @interface Annot {\n" +
+								"    Class<? extends Init<? extends Configuration>>[] inits(); \n" +
+								"}\n",
+						"App.java",
+						"@Annot(inits = {App.MyInit.class})\n" +
+						"public class App {\n" +
+						"    static class MyInit implements Init<Configuration> {}\n" +
+						"}\n",
+						"Configuration.java",
+						"public interface Configuration {\n" +
+								"}\n",
+						"Init.java",
+						"public interface Init<C extends Configuration> {\n" +
+								"}\n"
+				},
+				options,
+				"");
+	}
+	public void testBug572361() {
+		runConformTestWithLibs(
+			new String[] {
+				"NonNullByDefaultAndRecords.java",
+				"import org.eclipse.jdt.annotation.NonNullByDefault;\n" +
+				"\n" +
+				"@NonNullByDefault\n" +
+				"public record NonNullByDefaultAndRecords () { }\n"
+			},
+			getCompilerOptions(),
+			"");
+	}
+
+	public void testIssue233_ok() throws Exception {
+		Runner runner = getDefaultRunner();
+		runner.customOptions = getCompilerOptions();
+		runner.customOptions.put(JavaCore.COMPILER_PB_REDUNDANT_NULL_ANNOTATION, JavaCore.IGNORE);
+		runner.testFiles = new String[] {
+				"X.java",
+				"import org.eclipse.jdt.annotation.*;\n" +
+				"record A1(@NonNull String ca1, String ca2) {}\n" +
+				"record B1(@Nullable String cb1, String cb2) {}\n" +
+				"@NonNullByDefault\n" +
+				"public class X {\n" +
+				"	record A2(@NonNull String ca1, String ca2) {}\n" +
+				"	record B2(@Nullable String cb1, String cb2) {}\n" +
+				"\n" +
+				"	public static @NonNull String workWithA(A1 a, boolean f) {\n" +
+				"		return f ? a.ca1() : a.ca2();\n" +
+				"	}\n" +
+				"	public static @NonNull String workWithA(A2 a, boolean f) {\n" +
+				"		return f ? a.ca1() : a.ca2();\n" +
+				"	}\n" +
+				"	public static String workWithB(B1 b, boolean f) {\n" +
+				"		if (f) {\n" +
+				"			String c = b.cb1();\n" +
+				"			return c != null ? c : \"default \";\n" +
+				"		}\n" +
+				"		return b.cb2();\n" +
+				"	}\n" +
+				"	public static String workWithB(B2 b, boolean f) {\n" +
+				"		if (f) {\n" +
+				"			String c = b.cb1();\n" +
+				"			return c != null ? c : \"default \";\n" +
+				"		}\n" +
+				"		return b.cb2();\n" +
+				"	}\n" +
+				"	public static void main(String... args) {\n" +
+				"		@NonNull String sa11 = workWithA(new A1(\"hello \", \"A11 \"), true);\n" +
+				"		@NonNull String sa12 = workWithA(new A1(\"hello \", \"A12 \"), false);\n" +
+				"		@NonNull String sb11 = workWithB(new B1(null, \"B11 \"), true);\n" +
+				"		@NonNull String sb12 = workWithB(new B1(null, \"B12 \"), false);\n" +
+				"		@NonNull String sa21 = workWithA(new A2(\"hello \", \"A21 \"), true);\n" +
+				"		@NonNull String sa22 = workWithA(new A2(\"hello \", \"A22 \"), false);\n" +
+				"		@NonNull String sb21 = workWithB(new B2(null, \"B21\"), true);\n" +
+				"		@NonNull String sb22 = workWithB(new B2(null, \"B22\"), false);\n" +
+				"		System.out.println(sa11+sa12+sb11+sb12+sa21+sa22+sb21+sb22);\n" +
+				"	}\n" +
+				"}\n"
+			};
+		runner.expectedOutputString = "hello A12 default B12 hello A22 default B22";
+		runner.runConformTest();
+	}
+	public void testIssue233_nok() throws Exception {
+		// like testIssue233_ok - but annotations on record components ca1 / cb1 swapped (twice)
+		Runner runner = getDefaultRunner();
+		runner.customOptions = getCompilerOptions();
+		runner.customOptions.put(JavaCore.COMPILER_PB_REDUNDANT_NULL_ANNOTATION, JavaCore.IGNORE);
+		runner.testFiles = new String[] {
+				"X.java",
+				"import org.eclipse.jdt.annotation.*;\n" +
+				"record A1(@Nullable String ca1, String ca2) {}\n" +
+				"record B1(@NonNull String cb1, String cb2) {}\n" +
+				"@NonNullByDefault\n" +
+				"public class X {\n" +
+				"	record A2(@Nullable String ca1, String ca2) {}\n" +
+				"	record B2(@NonNull String cb1, String cb2) {}\n" +
+				"\n" +
+				"	public static @NonNull String workWithA(A1 a, boolean f) {\n" +
+				"		return f ? a.ca1() : a.ca2();\n" +
+				"	}\n" +
+				"	public static @NonNull String workWithA(A2 a, boolean f) {\n" +
+				"		return f ? a.ca1() : a.ca2();\n" +
+				"	}\n" +
+				"	public static String workWithB(B1 b, boolean f) {\n" +
+				"		if (f) {\n" +
+				"			String c = b.cb1();\n" +
+				"			return c != null ? c : \"default \";\n" +
+				"		}\n" +
+				"		return b.cb2();\n" +
+				"	}\n" +
+				"	public static String workWithB(B2 b, boolean f) {\n" +
+				"		if (f) {\n" +
+				"			String c = b.cb1();\n" +
+				"			return c != null ? c : \"default \";\n" +
+				"		}\n" +
+				"		return b.cb2();\n" +
+				"	}\n" +
+				"	public static void main(String... args) {\n" +
+				"		@NonNull String sa11 = workWithA(new A1(\"hello \", \"A11 \"), true);\n" +
+				"		@NonNull String sa12 = workWithA(new A1(\"hello \", \"A12 \"), false);\n" +
+				"		@NonNull String sb11 = workWithB(new B1(null, \"B11 \"), true);\n" +
+				"		@NonNull String sb12 = workWithB(new B1(null, \"B12 \"), false);\n" +
+				"		@NonNull String sa21 = workWithA(new A2(\"hello \", \"A21 \"), true);\n" +
+				"		@NonNull String sa22 = workWithA(new A2(\"hello \", \"A22 \"), false);\n" +
+				"		@NonNull String sb21 = workWithB(new B2(null, \"B21\"), true);\n" +
+				"		@NonNull String sb22 = workWithB(new B2(null, \"B22\"), false);\n" +
+				"		System.out.println(sa11+sa12+sb11+sb12+sa21+sa22+sb21+sb22);\n" +
+				"	}\n" +
+				"}\n"
+			};
+		runner.expectedCompilerLog =
+				"----------\n" +
+				"1. ERROR in X.java (at line 10)\n" +
+				"	return f ? a.ca1() : a.ca2();\n" +
+				"	           ^^^^^^^\n" +
+				"Null type mismatch (type annotations): required \'@NonNull String\' but this expression has type \'@Nullable String\'\n" +
+				"----------\n" +
+				"2. WARNING in X.java (at line 10)\n" +
+				"	return f ? a.ca1() : a.ca2();\n" +
+				"	                     ^^^^^^^\n" +
+				"Null type safety (type annotations): The expression of type \'String\' needs unchecked conversion to conform to \'@NonNull String\'\n" +
+				"----------\n" +
+				"3. ERROR in X.java (at line 13)\n" +
+				"	return f ? a.ca1() : a.ca2();\n" +
+				"	           ^^^^^^^\n" +
+				"Null type mismatch (type annotations): required \'@NonNull String\' but this expression has type \'@Nullable String\'\n" +
+				"----------\n" +
+				"4. ERROR in X.java (at line 18)\n" +
+				"	return c != null ? c : \"default \";\n" +
+				"	       ^\n" +
+				"Redundant null check: The variable c cannot be null at this location\n" +
+				"----------\n" +
+				"5. WARNING in X.java (at line 20)\n" +
+				"	return b.cb2();\n" +
+				"	       ^^^^^^^\n" +
+				"Null type safety (type annotations): The expression of type \'String\' needs unchecked conversion to conform to \'@NonNull String\'\n" +
+				"----------\n" +
+				"6. ERROR in X.java (at line 25)\n" +
+				"	return c != null ? c : \"default \";\n" +
+				"	       ^\n" +
+				"Redundant null check: The variable c cannot be null at this location\n" +
+				"----------\n" +
+				"7. ERROR in X.java (at line 32)\n" +
+				"	@NonNull String sb11 = workWithB(new B1(null, \"B11 \"), true);\n" +
+				"	                                        ^^^^\n" +
+				"Null type mismatch: required \'@NonNull String\' but the provided value is null\n" +
+				"----------\n" +
+				"8. ERROR in X.java (at line 33)\n" +
+				"	@NonNull String sb12 = workWithB(new B1(null, \"B12 \"), false);\n" +
+				"	                                        ^^^^\n" +
+				"Null type mismatch: required \'@NonNull String\' but the provided value is null\n" +
+				"----------\n" +
+				"9. ERROR in X.java (at line 36)\n" +
+				"	@NonNull String sb21 = workWithB(new B2(null, \"B21\"), true);\n" +
+				"	                                        ^^^^\n" +
+				"Null type mismatch: required \'@NonNull String\' but the provided value is null\n" +
+				"----------\n" +
+				"10. ERROR in X.java (at line 37)\n" +
+				"	@NonNull String sb22 = workWithB(new B2(null, \"B22\"), false);\n" +
+				"	                                        ^^^^\n" +
+				"Null type mismatch: required \'@NonNull String\' but the provided value is null\n" +
+				"----------\n";
+		runner.expectedOutputString = "hellodefault";
+		runner.runNegativeTest();
+	}
+	public void testIssue233_npeWitness() throws Exception {
+		Runner runner = getDefaultRunner();
+		runner.testFiles = new String[] {
+				"X.java",
+				"import org.eclipse.jdt.annotation.*;\n" +
+				"public record X(@NonNull String ca1, String ca2, @Nullable String ca2) {}\n"
+			};
+		runner.expectedCompilerLog =
+				"----------\n" +
+				"1. ERROR in X.java (at line 2)\n" +
+				"	public record X(@NonNull String ca1, String ca2, @Nullable String ca2) {}\n" +
+				"	                                            ^^^\n" +
+				"Duplicate component ca2 in record\n" +
+				"----------\n" +
+				"2. ERROR in X.java (at line 2)\n" +
+				"	public record X(@NonNull String ca1, String ca2, @Nullable String ca2) {}\n" +
+				"	                                                                  ^^^\n" +
+				"Duplicate component ca2 in record\n" +
+				"----------\n" +
+				"3. ERROR in X.java (at line 2)\n" +
+				"	public record X(@NonNull String ca1, String ca2, @Nullable String ca2) {}\n" +
+				"	                                                                  ^^^\n" +
+				"Duplicate parameter ca2\n" +
+				"----------\n";
+		runner.runNegativeTest();
+	}
 }
