@@ -46,6 +46,7 @@ public static Test suite() {
 public static Class testClass() {
 	return SerialVersionUIDTests.class;
 }
+@Override
 protected Map getCompilerOptions() {
 	Map options = super.getCompilerOptions();
 	options.put(CompilerOptions.OPTION_ReportMissingSerialVersion, CompilerOptions.ERROR);
@@ -224,11 +225,11 @@ public void test011() {
 			"	private static final long serialVersionUID = 1L;\n" +
 			"}"
 		},
-		"----------\n" + 
-		"1. ERROR in X.java (at line 2)\n" + 
-		"	private static final long serialVersionUID = 1L;\n" + 
-		"	                          ^^^^^^^^^^^^^^^^\n" + 
-		"The value of the field X.serialVersionUID is not used\n" + 
+		"----------\n" +
+		"1. ERROR in X.java (at line 2)\n" +
+		"	private static final long serialVersionUID = 1L;\n" +
+		"	                          ^^^^^^^^^^^^^^^^\n" +
+		"The value of the field X.serialVersionUID is not used\n" +
 		"----------\n",
 		null,
 		true,
@@ -247,11 +248,11 @@ public void test012() {
 			"	private static final long serialVersionUID = 1L;\n" +
 			"}"
 		},
-		"----------\n" + 
-		"1. ERROR in X.java (at line 2)\n" + 
-		"	private static final long serialVersionUID = 1L;\n" + 
-		"	                          ^^^^^^^^^^^^^^^^\n" + 
-		"The value of the field X<T>.serialVersionUID is not used\n" + 
+		"----------\n" +
+		"1. ERROR in X.java (at line 2)\n" +
+		"	private static final long serialVersionUID = 1L;\n" +
+		"	                          ^^^^^^^^^^^^^^^^\n" +
+		"The value of the field X<T>.serialVersionUID is not used\n" +
 		"----------\n",
 		null,
 		true,
@@ -270,11 +271,11 @@ public void test013() {
 			"	private static final long serialPersistentFields = 1L;\n" +
 			"}"
 		},
-		"----------\n" + 
-		"1. ERROR in X.java (at line 2)\n" + 
-		"	private static final long serialPersistentFields = 1L;\n" + 
-		"	                          ^^^^^^^^^^^^^^^^^^^^^^\n" + 
-		"The value of the field X<T>.serialPersistentFields is not used\n" + 
+		"----------\n" +
+		"1. ERROR in X.java (at line 2)\n" +
+		"	private static final long serialPersistentFields = 1L;\n" +
+		"	                          ^^^^^^^^^^^^^^^^^^^^^^\n" +
+		"The value of the field X<T>.serialPersistentFields is not used\n" +
 		"----------\n",
 		null,
 		true,
@@ -292,11 +293,11 @@ public void test014() {
 			"	private static final long serialPersistentFields = 1L;\n" +
 			"}"
 		},
-		"----------\n" + 
-		"1. ERROR in X.java (at line 2)\n" + 
-		"	private static final long serialPersistentFields = 1L;\n" + 
-		"	                          ^^^^^^^^^^^^^^^^^^^^^^\n" + 
-		"The value of the field X.serialPersistentFields is not used\n" + 
+		"----------\n" +
+		"1. ERROR in X.java (at line 2)\n" +
+		"	private static final long serialPersistentFields = 1L;\n" +
+		"	                          ^^^^^^^^^^^^^^^^^^^^^^\n" +
+		"The value of the field X.serialPersistentFields is not used\n" +
 		"----------\n",
 		null,
 		true,
@@ -318,11 +319,11 @@ public void test015() {
 			"	private int i;\n" +
 			"}"
 		},
-		"----------\n" + 
-		"1. ERROR in X.java (at line 5)\n" + 
-		"	private int i;\n" + 
-		"	            ^\n" + 
-		"The value of the field X<T>.i is not used\n" + 
+		"----------\n" +
+		"1. ERROR in X.java (at line 5)\n" +
+		"	private int i;\n" +
+		"	            ^\n" +
+		"The value of the field X<T>.i is not used\n" +
 		"----------\n",
 		null,
 		true,
@@ -343,11 +344,11 @@ public void test016() {
 			"	private int i;\n" +
 			"}"
 		},
-		"----------\n" + 
-		"1. ERROR in X.java (at line 5)\n" + 
-		"	private int i;\n" + 
-		"	            ^\n" + 
-		"The value of the field X.i is not used\n" + 
+		"----------\n" +
+		"1. ERROR in X.java (at line 5)\n" +
+		"	private int i;\n" +
+		"	            ^\n" +
+		"The value of the field X.i is not used\n" +
 		"----------\n",
 		null,
 		true,
