@@ -2306,6 +2306,55 @@ public class SerializableLambdaTest extends AbstractRegressionTest {
 		String data = printLambdaMethods(OUTPUT_DIR + File.separator + "OuterClass.class");
 		checkExpected(expectedOutput,data);
 	}
+	public void testbugGH155() {
+		// before resolution, $deserializeLambda$ expects java.lang.Object return type
+		// while SerializedLambda advertises java.lang.Comparable return type
+		// deserialization fails as $deserializeLambda$ cannot find appropriate deserializer.
+		this.runConformTest(new String[] {
+				"TestSerializableLambda.java",
+				"import java.io.*;\n"+
+				"import java.util.function.Function;\n"+
+				"\n"+
+				"public class TestSerializableLambda {\n"+
+				"	private static Object serializeDeserialize(Object obj) throws IOException, ClassNotFoundException {\n" +
+				"		try (\n" +
+				"			ByteArrayOutputStream buffer = new ByteArrayOutputStream(); //\n" +
+				"			ObjectOutputStream output = new ObjectOutputStream(buffer)) {\n" +
+				"			output.writeObject(obj);\n" +
+				"			try (ObjectInputStream input = new ObjectInputStream(new ByteArrayInputStream(buffer.toByteArray()))) {\n" +
+				"				return input.readObject();\n" +
+				"			}\n" +
+				"		}\n" +
+				"	}\n" +
+				"	public static void main(String[] args) {\n" +
+				"		try {\n" +
+				"			SerializableHolder<LambdaProvider<Long>> r = new SerializableHolder<>();\n" +
+				"			serializeDeserialize(r);\n" +
+				"			System.out.println(\"OK\");\n" +
+				"		} catch (ClassNotFoundException | IOException e) {\n" +
+				"			// TODO Auto-generated catch block\n" +
+				"			e.printStackTrace();\n" +
+				"		}\n" +
+				"	}\n" +
+				"	\n"+
+				"	public static class SerializableHolder<E extends LambdaProvider<?>> implements Serializable {\n"+
+				"		private static final long serialVersionUID = -2775595600924717218L;\n"+
+				"		private Function<E, ?> idExpression;\n"+
+				"\n"+
+				"		public SerializableHolder() {\n"+
+				"			this.idExpression = (Serializable & Function<E, ?>) LambdaProvider::getId;\n"+
+				"		}\n"+
+				"	}\n"+
+				"\n"+
+				"	public static class LambdaProvider<I extends Comparable<I>> {\n"+
+				"		public I getId() {\n"+
+				"			return null;\n"+
+				"		}\n"+
+				"	}\n"+
+				"}"
+				},
+				"OK");
+	}
 	// ---
 
 	private void checkExpected(String expected, String actual) {
