@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2020, 2021 IBM Corporation and others.
+ * Copyright (c) 2020, 2023 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -31,6 +31,7 @@ import org.eclipse.jdt.core.dom.ASTVisitor;
 import org.eclipse.jdt.core.dom.AbstractTypeDeclaration;
 import org.eclipse.jdt.core.dom.CompilationUnit;
 import org.eclipse.jdt.core.dom.Expression;
+import org.eclipse.jdt.core.dom.FieldDeclaration;
 import org.eclipse.jdt.core.dom.IBinding;
 import org.eclipse.jdt.core.dom.IMethodBinding;
 import org.eclipse.jdt.core.dom.ITypeBinding;
@@ -69,7 +70,6 @@ public class ASTConverter_16Test extends ConverterTestSetup {
 	public ASTConverter_16Test(String name) {
 		super(name);
 	}
-
 	public static Test suite() {
 		return buildModelTestSuite(ASTConverter_16Test.class);
 	}
@@ -556,8 +556,7 @@ public class ASTConverter_16Test extends ConverterTestSetup {
 		assertEquals("Restricter identifier position for interface' is not -1", startPos, -1);
 	}
 
-
-
+	@SuppressWarnings("deprecation")
 	public void testPatternInstanceOfExpression001() throws JavaModelException {
 		if (!isJRE16) {
 			System.err.println("Test "+getName()+" requires a JRE 16");
@@ -655,6 +654,7 @@ public class ASTConverter_16Test extends ConverterTestSetup {
 		checkSourceRange(expression, "o instanceof String s", contents);
 		assertEquals("Not an instanceof expression", ASTNode.PATTERN_INSTANCEOF_EXPRESSION, expression.getNodeType());
 		PatternInstanceofExpression instanceofExpression = (PatternInstanceofExpression) expression;
+		@SuppressWarnings("deprecation")
 		SingleVariableDeclaration var = instanceofExpression.getRightOperand();
 		checkSourceRange(var, "String s", contents);
 		String instanceofExpressionString = instanceofExpression.toString();
@@ -815,4 +815,36 @@ public class ASTConverter_16Test extends ConverterTestSetup {
 	      }
 	    });
 	}
+	@SuppressWarnings("rawtypes")
+	public void test_RecordSemicolon() throws JavaModelException {
+		if (!isJRE16) {
+			System.err.println("Test "+getName()+" requires a JRE 16");
+			return;
+		}
+		String contents =
+		        "record Point(int x, int y) {\n" +
+		        "    private static final int staticField = 16;\n"+
+		        "}";
+		    this.workingCopy = getWorkingCopy("/Converter_16/src/ASTtree.java", true/*resolve*/);
+		    ASTNode node = buildAST(
+		    		contents,
+		    		this.workingCopy);
+		    assertEquals("Not a compilation unit", ASTNode.COMPILATION_UNIT, node.getNodeType());
+		    CompilationUnit unit = (CompilationUnit) node;
+		    assertProblemsSize(unit, 0);
+		    node = getASTNode(unit, 0);
+		    assertEquals("Not a record declaration", ASTNode.RECORD_DECLARATION, node.getNodeType());
+		    RecordDeclaration recordDeclaration = (RecordDeclaration) node;
+		    final List bodyDeclarations = recordDeclaration.bodyDeclarations();
+		    assertEquals("Wrong size", 1, bodyDeclarations.size());
+		    FieldDeclaration fieldDeclaration = (FieldDeclaration) bodyDeclarations.get(0);
+		    final List fragments = fieldDeclaration.fragments();
+		    assertEquals("Wrong size", 1, fragments.size());
+		    VariableDeclarationFragment fragment = (VariableDeclarationFragment)fragments.get(0);
+		    final Expression initializer = fragment.getInitializer();
+		    assertEquals("Not a number literal", ASTNode.NUMBER_LITERAL, initializer.getNodeType());
+		    checkSourceRange(initializer, "16", contents);
+
+
+	}
 }
