@@ -181,7 +181,9 @@ protected void setUp() throws Exception {
 }
 @Override
 public void tearDownSuite() throws Exception {
-	JavaCore.setOptions(this.oldOptions);
+	if (this.oldOptions != null) {
+		JavaCore.setOptions(this.oldOptions);
+	}
 	this.oldOptions = null;
 	if (COMPLETION_SUITES == null) {
 		deleteProject("Completion");
@@ -217,4 +219,25 @@ protected void assertResults(String expected, String actual) {
 		throw c;
 	}
 }
+
+protected void assertContains(String message, String expected, String containsIn) {
+	if (!containsIn.contains(expected)) {
+		StringBuilder formatted = new StringBuilder();
+		if (message != null) {
+			formatted.append(message).append('.');
+		}
+		final String expectedWithLineSeparators = showLineSeparators(expected);
+		final String actualWithLineSeparators = showLineSeparators(containsIn);
+		formatted.append("\n----------- Expected to contain ------------\n"); //$NON-NLS-1$
+		formatted.append(expectedWithLineSeparators);
+		formatted.append("\n------------ but was ------------\n"); //$NON-NLS-1$
+		formatted.append(actualWithLineSeparators);
+		formatted.append("\n--------- Difference is ----------\n"); //$NON-NLS-1$
+		throw new ComparisonFailure(formatted.toString(), expectedWithLineSeparators, actualWithLineSeparators);
+	}
+}
+
+protected void assertContains(String expected, String containsIn) {
+	assertContains(null, expected, containsIn);
+}
 }
