@@ -64,14 +64,16 @@ public class ResolveTests9 extends AbstractJavaModelTests {
 	public ResolveTests9(String name) {
 		super(name);
 	}
+	@Override
 	public ICompilationUnit getWorkingCopy(String path, String source) throws JavaModelException {
 		return super.getWorkingCopy(path, source, this.wcOwner);
 	}
+	@Override
 	public void setUpSuite() throws Exception {
 		super.setUpSuite();
-	
+
 		IJavaProject project = setUpJavaProject("Resolve", "9", true);
-	
+
 		String bootModPath = System.getProperty("java.home") + File.separator +"jrt-fs.jar";
 		IClasspathEntry jrtEntry = JavaCore.newLibraryEntry(new Path(bootModPath), null, null, null, null, false);
 		IClasspathEntry[] old = project.getRawClasspath();
@@ -79,20 +81,23 @@ public class ResolveTests9 extends AbstractJavaModelTests {
 		System.arraycopy(old, 0, newPath, 0, old.length);
 		newPath[old.length] = jrtEntry;
 		project.setRawClasspath(newPath, null);
-	
+
 		waitUntilIndexesReady();
 	}
-	
+
+	@Override
 	protected void setUp() throws Exception {
 		super.setUp();
 		this.wcOwner = new WorkingCopyOwner(){};
 	}
+	@Override
 	public void tearDownSuite() throws Exception {
 		deleteProject("Resolve");
-	
+
 		super.tearDownSuite();
 	}
-	
+
+	@Override
 	protected void tearDown() throws Exception {
 		if (this.wc != null) {
 			this.wc.discardWorkingCopy();
@@ -116,7 +121,7 @@ public class ResolveTests9 extends AbstractJavaModelTests {
 	}
 	void addTestSrc(IJavaProject prj) throws CoreException {
 		IPath path = prj.getProject().getFullPath();
-		IClasspathEntry testSrc = JavaCore.newSourceEntry(path.append(new Path("src-test")), 
+		IClasspathEntry testSrc = JavaCore.newSourceEntry(path.append(new Path("src-test")),
 				null, null, path.append(new Path("bin-test")),
 				new IClasspathAttribute[] {JavaCore.newClasspathAttribute(IClasspathAttribute.TEST, "true")});
 		addClasspathEntry(prj, testSrc);
@@ -132,18 +137,18 @@ public class ResolveTests9 extends AbstractJavaModelTests {
 			getWorkingCopy(
 					"/Resolve/src/test/TestClass.java",
 					"public class TestClass implements ITest {}\n");
-		
+
 			this.wc = getWorkingCopy(
 					"/Resolve/src/module-info.java",
 					"module com.test {\n" +
 					"  provides p1.Y with ResolveInterface;\n" +
 					"}\n");
-		
+
 			String str = this.wc.getSource();
 			String selection = "ResolveInterface";
 			int start = str.indexOf(selection);
 			int length = selection.length();
-		
+
 			IJavaElement[] elements = this.wc.codeSelect(start, length);
 			assertElementsEqual(
 				"Unexpected elements",
@@ -167,18 +172,18 @@ public class ResolveTests9 extends AbstractJavaModelTests {
 			createFile(
 					"/Resolve/src/test/TestClass.java",
 					"public class TestClass implements ITest {}\n");
-		
+
 			this.wc = getWorkingCopy(
 					"/Resolve/src/module-info.java",
 					"module com.test {\n" +
 					"  provides test.ITest with test.TestClass;\n" +
 					"}\n");
-		
+
 			String str = this.wc.getSource();
 			String selection = "ITest";
 			int start = str.indexOf(selection);
 			int length = selection.length();
-		
+
 			IJavaElement[] elements = this.wc.codeSelect(start, length);
 			assertElementsEqual(
 				"Unexpected elements",
@@ -226,7 +231,7 @@ public class ResolveTests9 extends AbstractJavaModelTests {
 			String selection = "ITest";
 			int start = str.indexOf(selection);
 			int length = selection.length();
-		
+
 			// still, if we get here before indexes are ready,
 			// then OperationCanceledException will send us into SearchableEnvironment.findTypes(String, ISearchRequestor, int),
 			// which succeeds:
@@ -255,18 +260,18 @@ public class ResolveTests9 extends AbstractJavaModelTests {
 			createFile(
 					"/Resolve/src/test/TestClass.java",
 					"public class TestClass implements ITest {}\n");
-		
+
 			this.wc = getWorkingCopy(
 					"/Resolve/src/module-info.java",
 					"module com.test {\n" +
 					"  provides test.ITest with test.TestClass;\n" +
 					"}\n");
-		
+
 			String str = this.wc.getSource();
 			String selection = "ITest";
 			int start = str.indexOf(selection);
 			int length = selection.length();
-			
+
 			waitUntilIndexesReady();
 			// even after indexes are built we meanwhile (after bug 540541) find the selected type
 			IJavaElement[] elements = this.wc.codeSelect(start, length);
@@ -292,18 +297,18 @@ public class ResolveTests9 extends AbstractJavaModelTests {
 			getWorkingCopy(
 					"/Resolve/src/test/TestClass.java",
 					"public class TestClass implements ITest {}\n");
-		
+
 			this.wc = getWorkingCopy(
 					"/Resolve/src/module-info.java",
 					"module com.test {\n" +
 					"  provides p1.Y with ResolveInterface;\n" +
 					"}\n");
-		
+
 			String str = this.wc.getSource();
 			String selection = "provides";
 			int start = str.indexOf(selection);
 			int length = selection.length();
-		
+
 			IJavaElement[] elements = this.wc.codeSelect(start, length);
 			assertElementsEqual(
 				"Unexpected elements",
@@ -326,18 +331,18 @@ public class ResolveTests9 extends AbstractJavaModelTests {
 			getWorkingCopy(
 					"/Resolve/src/test/TestClass.java",
 					"public class TestClass implements ITest {}\n");
-		
+
 			this.wc = getWorkingCopy(
 					"/Resolve/src/module-info.java",
-					"module com.test {\n" + 
-					"  provides p1.Y with provides;\n" + 
+					"module com.test {\n" +
+					"  provides p1.Y with provides;\n" +
 					"}\n");
-		
+
 			String str = this.wc.getSource();
 			String selection = "provides";
 			int start = str.lastIndexOf(selection);
 			int length = selection.length();
-		
+
 			IJavaElement[] elements = this.wc.codeSelect(start, length);
 			assertElementsEqual(
 				"Unexpected elements",
@@ -406,8 +411,8 @@ public class ResolveTests9 extends AbstractJavaModelTests {
 			IMarker[] markers = test.getProject().findMarkers(IJavaModelMarker.JAVA_MODEL_PROBLEM_MARKER, true, IResource.DEPTH_INFINITE);
 			sortMarkers(markers);
 			assertMarkers("Unexpected markers",
-					"The package p1.p2 conflicts with a package accessible from another module: mod\n" + 
-					"The package p1.p2 is accessible from more than one module: <unnamed>, mod\n" + 
+					"The package p1.p2 conflicts with a package accessible from another module: mod\n" +
+					"The package p1.p2 is accessible from more than one module: <unnamed>, mod\n" +
 					"The package p1.p2 is accessible from more than one module: <unnamed>, mod",
 					markers);
 
@@ -518,7 +523,7 @@ public class ResolveTests9 extends AbstractJavaModelTests {
 			gui = createJava9ProjectWithJREAttributes("com.igorion.gui", new String[] {"src"}, attributes(MODULE));
 			addTestSrc(gui);
 			createFolder("com.igorion.gui/src/com/igorion/gui");
-			String source = 
+			String source =
 					"package com.igorion.gui;\n" +
 					"import com.igorion.model.IModel;\n" +
 					"import com.igorion.model.define.Model;\n" +
@@ -593,7 +598,7 @@ public class ResolveTests9 extends AbstractJavaModelTests {
 			// ... and observe javax.xml.bind unobservable:
 			prj.getProject().build(IncrementalProjectBuilder.FULL_BUILD, null);
 			markers = prj.getProject().findMarkers(null, true, IResource.DEPTH_INFINITE);
-			assertMarkers("unexpected markers", 
+			assertMarkers("unexpected markers",
 					"javax.xml.bind cannot be resolved to a type", markers);
 		} finally {
 			deleteProject(prj);
