@@ -1,9 +1,12 @@
 /*******************************************************************************
  * Copyright (c) 2000, 2008 IBM Corporation and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ *
+ * This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
@@ -341,7 +344,8 @@ public void testCopySourceFolder5() throws CoreException {
 			"		p\n" +
 			"			X.java\n" +
 			"	L/P2/.classpath\n" +
-			"	L/P2/.project",
+			"	L/P2/.project\n" +
+			"	F/P2/.settings",
 			p2);
 	} finally {
 		stopDeltas();
@@ -390,7 +394,8 @@ public void testCopySourceFolder6() throws CoreException {
 			"		p\n" +
 			"			X.java\n" +
 			"	L/P/.classpath\n" +
-			"	L/P/.project",
+			"	L/P/.project\n" +
+			"	F/P/.settings",
 			project);
 	} finally {
 		stopDeltas();
@@ -467,7 +472,8 @@ public void testDeleteJarFile1() throws CoreException {
 			"	src\n" +
 			"		<default>\n" +
 			"	L/P/.classpath\n" +
-			"	L/P/.project",
+			"	L/P/.project\n" +
+			"	F/P/.settings",
 			project);
 	} finally {
 		stopDeltas();
@@ -497,7 +503,8 @@ public void testDeleteJarFile3() throws CoreException {
 			"	src\n" +
 			"		<default>\n" +
 			"	L/P/.classpath\n" +
-			"	L/P/.project",
+			"	L/P/.project\n" +
+			"	F/P/.settings",
 			project);
 	} finally {
 		stopDeltas();
@@ -531,14 +538,16 @@ public void testDeleteJarFile2() throws CoreException {
 			"	src\n" +
 			"		<default>\n" +
 			"	L/P1/.classpath\n" +
-			"	L/P1/.project",
+			"	L/P1/.project\n" +
+			"	F/P1/.settings",
 			p1);
 		assertJavaProject(
 			"P2\n" +
 			"	src\n" +
 			"		<default>\n" +
 			"	L/P2/.classpath\n" +
-			"	L/P2/.project",
+			"	L/P2/.project\n" +
+			"	F/P2/.settings",
 			p2);
 	} finally {
 		stopDeltas();
@@ -572,7 +581,8 @@ public void testDeleteSourceFolder1() throws CoreException {
 		assertJavaProject(
 			"P\n" +
 			"	L/P/.classpath\n" +
-			"	L/P/.project",
+			"	L/P/.project\n" +
+			"	F/P/.settings",
 			project);
 	} finally {
 		stopDeltas();
@@ -622,6 +632,7 @@ public void testDeleteSourceFolder2() throws CoreException {
 			"			Y.java\n" +
 			"	L/P/.classpath\n" +
 			"	L/P/.project\n" +
+			"	F/P/.settings\n" +
 			"	F/P/src1",
 			project);
 
@@ -662,7 +673,8 @@ public void testMoveSourceFolder1() throws CoreException {
 		assertJavaProject(
 			"P1\n" +
 			"	L/P1/.classpath\n" +
-			"	L/P1/.project",
+			"	L/P1/.project\n" +
+			"	F/P1/.settings",
 			p1);
 		assertJavaProject(
 			"P2\n" +
@@ -671,7 +683,8 @@ public void testMoveSourceFolder1() throws CoreException {
 			"		p\n" +
 			"			X.java\n" +
 			"	L/P2/.classpath\n" +
-			"	L/P2/.project",
+			"	L/P2/.project\n" +
+			"	F/P2/.settings",
 			p2);
 	} finally {
 		stopDeltas();
@@ -711,7 +724,8 @@ public void testMoveSourceFolder2() throws CoreException {
 		assertJavaProject(
 			"P1\n" +
 			"	L/P1/.classpath\n" +
-			"	L/P1/.project",
+			"	L/P1/.project\n" +
+			"	F/P1/.settings",
 			p1);
 		assertJavaProject(
 			"P2\n" +
@@ -720,7 +734,8 @@ public void testMoveSourceFolder2() throws CoreException {
 			"		p\n" +
 			"			X.java\n" +
 			"	L/P2/.classpath\n" +
-			"	L/P2/.project",
+			"	L/P2/.project\n" +
+			"	F/P2/.settings",
 			p2);
 	} finally {
 		stopDeltas();
@@ -775,6 +790,7 @@ public void testMoveSourceFolder3() throws CoreException {
 			"			Y.java\n" +
 			"	L/P1/.classpath\n" +
 			"	L/P1/.project\n" +
+			"	F/P1/.settings\n" +
 			"	F/P1/src1",
 			p1);
 		assertJavaProject(
@@ -784,7 +800,8 @@ public void testMoveSourceFolder3() throws CoreException {
 			"		p\n" +
 			"			X.java\n" +
 			"	L/P2/.classpath\n" +
-			"	L/P2/.project",
+			"	L/P2/.project\n" +
+			"	F/P2/.settings",
 			p2);
 	} finally {
 		stopDeltas();
@@ -820,7 +837,8 @@ public void testMoveSourceFolder4() throws CoreException {
 		assertJavaProject(
 			"P1\n" +
 			"	L/P1/.classpath\n" +
-			"	L/P1/.project",
+			"	L/P1/.project\n" +
+			"	F/P1/.settings",
 			p1);
 		assertJavaProject(
 			"P2\n" +
@@ -831,7 +849,8 @@ public void testMoveSourceFolder4() throws CoreException {
 			"	src2\n" +
 			"		<default>\n" +
 			"	L/P2/.classpath\n" +
-			"	L/P2/.project",
+			"	L/P2/.project\n" +
+			"	F/P2/.settings",
 			p2);
 	} finally {
 		stopDeltas();
@@ -866,7 +885,8 @@ public void testMoveSourceFolder5() throws CoreException {
 		assertJavaProject(
 			"P1\n" +
 			"	L/P1/.classpath\n" +
-			"	L/P1/.project",
+			"	L/P1/.project\n" +
+			"	F/P1/.settings",
 			p1);
 		assertJavaProject(
 			"P2\n" +
@@ -877,7 +897,8 @@ public void testMoveSourceFolder5() throws CoreException {
 			"	src2\n" +
 			"		<default>\n" +
 			"	L/P2/.classpath\n" +
-			"	L/P2/.project",
+			"	L/P2/.project\n" +
+			"	F/P2/.settings",
 			p2);
 	} finally {
 		stopDeltas();
@@ -910,7 +931,8 @@ public void testMoveSourceFolder6() throws CoreException {
 		assertJavaProject(
 			"P1\n" +
 			"	L/P1/.classpath\n" +
-			"	L/P1/.project",
+			"	L/P1/.project\n" +
+			"	F/P1/.settings",
 			p1);
 		assertJavaProject(
 			"P2\n" +
@@ -921,7 +943,8 @@ public void testMoveSourceFolder6() throws CoreException {
 			"	src\n" +
 			"		<default>\n" +
 			"	L/P2/.classpath\n" +
-			"	L/P2/.project",
+			"	L/P2/.project\n" +
+			"	F/P2/.settings",
 			p2);
 	} finally {
 		stopDeltas();
@@ -960,7 +983,8 @@ public void testRenameSourceFolder1() throws CoreException {
 			"		p\n" +
 			"			X.java\n" +
 			"	L/P/.classpath\n" +
-			"	L/P/.project",
+			"	L/P/.project\n" +
+			"	F/P/.settings",
 			project);
 	} finally {
 		stopDeltas();
@@ -1058,7 +1082,8 @@ public void testRenameSourceFolder2() throws CoreException {
 			"	src3\n" +
 			"		<default>\n" +
 			"	L/P/.classpath\n" +
-			"	L/P/.project",
+			"	L/P/.project\n" +
+			"	F/P/.settings",
 			project);
 
 		// rename src2
@@ -1081,7 +1106,8 @@ public void testRenameSourceFolder2() throws CoreException {
 			"	src3\n" +
 			"		<default>\n" +
 			"	L/P/.classpath\n" +
-			"	L/P/.project",
+			"	L/P/.project\n" +
+			"	F/P/.settings",
 			project);
 
 		// rename src3
@@ -1104,7 +1130,8 @@ public void testRenameSourceFolder2() throws CoreException {
 			"	src6\n" +
 			"		<default>\n" +
 			"	L/P/.classpath\n" +
-			"	L/P/.project",
+			"	L/P/.project\n" +
+			"	F/P/.settings",
 			project);
 	} finally {
 		stopDeltas();
@@ -1136,7 +1163,8 @@ public void testRenameJarFile1() throws CoreException {
 			"		<default>\n" +
 			"	myLib2.jar\n" +
 			"	L/P/.classpath\n" +
-			"	L/P/.project",
+			"	L/P/.project\n" +
+			"	F/P/.settings",
 			project);
 	} finally {
 		stopDeltas();
@@ -1173,7 +1201,8 @@ public void testRenameJarFile2() throws CoreException {
 			"		<default>\n" +
 			"	myLib2.jar\n" +
 			"	L/P1/.classpath\n" +
-			"	L/P1/.project",
+			"	L/P1/.project\n" +
+			"	F/P1/.settings",
 			p1);
 		assertJavaProject(
 			"P2\n" +
@@ -1181,7 +1210,8 @@ public void testRenameJarFile2() throws CoreException {
 			"		<default>\n" +
 			"	/P1/myLib2.jar\n" +
 			"	L/P2/.classpath\n" +
-			"	L/P2/.project",
+			"	L/P2/.project\n" +
+			"	F/P2/.settings",
 			p2);
 	} finally {
 		stopDeltas();
@@ -1222,7 +1252,8 @@ public void testRenameJarFile3() throws CoreException {
 			"		<default>\n" +
 			"	myLib2.jar\n" +
 			"	L/P/.classpath\n" +
-			"	L/P/.project",
+			"	L/P/.project\n" +
+			"	F/P/.settings",
 			project);
 	} finally {
 		stopDeltas();
