@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2015, 2019 Gábor Kövesdán and others.
+ * Copyright (c) 2015, 2020 Gábor Kövesdán and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -7,17 +7,18 @@
  * https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- * 
+ *
  * Contributors:
  *     Gábor Kövesdán - initial version
  *******************************************************************************/
 package org.eclipse.jdt.core.tests.model;
 
-import java.util.Hashtable;
+import java.util.function.Predicate;
 
+import org.eclipse.jdt.core.CompletionProposal;
 import org.eclipse.jdt.core.ICompilationUnit;
-import org.eclipse.jdt.core.JavaCore;
 import org.eclipse.jdt.core.JavaModelException;
+import org.eclipse.jdt.internal.codeassist.impl.AssistOptions;
 
 import junit.framework.Test;
 
@@ -29,6 +30,7 @@ public static Test suite() {
 public SubstringCompletionTests(String name) {
 	super(name);
 }
+@Override
 public void setUpSuite() throws Exception {
 	if (COMPLETION_PROJECT == null)  {
 		COMPLETION_PROJECT = setUpJavaProject("Completion", "1.8", true);
@@ -36,10 +38,9 @@ public void setUpSuite() throws Exception {
 		setUpProjectCompliance(COMPLETION_PROJECT, "1.8", true);
 	}
 	super.setUpSuite();
-	Hashtable<String, String> options = new Hashtable<>(this.oldOptions);
-	options.put(JavaCore.CODEASSIST_SUBSTRING_MATCH, JavaCore.ENABLED);
-	JavaCore.setOptions(options);
+	System.setProperty(AssistOptions.PROPERTY_SubstringMatch, "true");
 }
+@Override
 public void tearDownSuite() throws Exception {
 	if (COMPLETION_SUITES == null) {
 		deleteProject("Completion");
@@ -55,7 +56,12 @@ public void tearDownSuite() throws Exception {
 	}
 	super.tearDownSuite();
 }
-
+private CompletionTestsRequestor2 createFilteredRequestor() {
+	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	Predicate<CompletionProposal> javaTypeRef = p -> p.getKind() == CompletionProposal.TYPE_REF && new String(p.getSignature()).startsWith("Ljava.");
+	requestor.setProposalFilter(javaTypeRef.negate());
+	return requestor;
+}
 public void testQualifiedNonStaticMethod() throws JavaModelException {
 	this.workingCopies = new ICompilationUnit[1];
 	this.workingCopies[0] = getWorkingCopy(
@@ -70,7 +76,7 @@ public void testQualifiedNonStaticMethod() throws JavaModelException {
 		"  }\n" +
 		"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "this.bar";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -97,7 +103,7 @@ public void testUnqualifiedNonStaticMethod() throws JavaModelException {
 		"  }\n" +
 		"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "bar";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -123,7 +129,7 @@ public void testQualifiedStaticMethod() throws JavaModelException {
 		"  }\n" +
 		"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "Test.bar";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -148,7 +154,7 @@ public void testUnqualifiedStaticMethod() throws JavaModelException {
 		"  }\n" +
 		"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "Bar";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -174,7 +180,7 @@ public void testQualifiedNonStaticField() throws JavaModelException {
 		"  }\n" +
 		"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "this.item";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -201,7 +207,7 @@ public void testUnqualifiedNonStaticField() throws JavaModelException {
 			"  }\n" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "item";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -227,7 +233,7 @@ public void testQualifiedStaticField() throws JavaModelException {
 			"  }\n" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "Test.item";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -252,7 +258,7 @@ public void testUnqualifiedStaticField() throws JavaModelException {
 			"  }\n" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "item";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -279,7 +285,7 @@ public void testLocalVariable() throws JavaModelException {
 			"  }\n" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "item";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -306,7 +312,7 @@ public void testMethodParamVariable() throws JavaModelException {
 			"  }\n" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "item";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -320,48 +326,54 @@ public void testMethodParamVariable() throws JavaModelException {
 			requestor.getResults());
 }
 public void testClassTypeInstantiation() throws JavaModelException {
-	this.workingCopies = new ICompilationUnit[1];
-	this.workingCopies[0] = getWorkingCopy(
-			"/Completion/src/test/Test.java",
-			"package test;"+
+	this.workingCopies = new ICompilationUnit[2];
+	this.workingCopies[1] = getWorkingCopy(
+			"/Completion/src/test/Foobar.java",
+			"package test;\n"+
 			"interface Foobar {}\n" +
 			"class SpecificFooBar implements Foobar {}\n" +
 			"class EvenMoreSpecificFooBar extends SpecificFooBar {}\n" +
 			"interface Foobaz {}\n" +
-			"class SpecificFooBaz implements Foobaz {}\n" +
+			"class SpecificFooBaz implements Foobaz {}\n");
+	this.workingCopies[0] = getWorkingCopy(
+			"/Completion/src/test/Test.java",
+			"package test;"+
 			"public class Test {\n" +
 			"  {\n" +
 			"    Foobar f = new bar\n" +
 			"  }\n" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "new bar";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
 	this.workingCopies[0].codeComplete(cursorLocation, requestor, this.wcOwner);
 
 	assertResults(
-			"EvenMoreSpecificFooBar[TYPE_REF]{EvenMoreSpecificFooBar, test, Ltest.EvenMoreSpecificFooBar;, null, null, " + (R_DEFAULT + R_RESOLVED + R_INTERESTING + R_EXPECTED_TYPE + R_UNQUALIFIED + R_NON_RESTRICTED + R_SUBSTRING) + "}\n" +
-			"SpecificFooBar[TYPE_REF]{SpecificFooBar, test, Ltest.SpecificFooBar;, null, null, " + (R_DEFAULT + R_RESOLVED + R_INTERESTING + R_EXPECTED_TYPE + R_UNQUALIFIED + R_NON_RESTRICTED + R_SUBSTRING) + "}\n" +
+			"EvenMoreSpecificFooBar[TYPE_REF]{EvenMoreSpecificFooBar, test, Ltest.EvenMoreSpecificFooBar;, null, null, " + (R_DEFAULT + R_RESOLVED + R_INTERESTING + R_UNQUALIFIED + R_NON_RESTRICTED + R_SUBSTRING) + "}\n" +
+			"SpecificFooBar[TYPE_REF]{SpecificFooBar, test, Ltest.SpecificFooBar;, null, null, " + (R_DEFAULT + R_RESOLVED + R_INTERESTING + R_UNQUALIFIED + R_NON_RESTRICTED + R_SUBSTRING) + "}\n" +
 			"Foobar[TYPE_REF]{Foobar, test, Ltest.Foobar;, null, null, " + (R_DEFAULT + R_RESOLVED + R_INTERESTING + R_EXACT_EXPECTED_TYPE + R_UNQUALIFIED + R_NON_RESTRICTED + R_SUBSTRING) + "}",
 			requestor.getResults());
 }
 public void testClassTypeFieldDeclaration() throws JavaModelException {
-	this.workingCopies = new ICompilationUnit[1];
-	this.workingCopies[0] = getWorkingCopy(
-			"/Completion/src/test/Test.java",
-			"package test;"+
+	this.workingCopies = new ICompilationUnit[2];
+	this.workingCopies[1] = getWorkingCopy(
+			"/Completion/src/test/Foobar.java",
+			"package test;\n"+
 			"interface Foobar {}\n" +
 			"class SpecificFooBar implements Foobar {}\n" +
 			"class EvenMoreSpecificFooBar extends SpecificFooBar {}\n" +
 			"interface Foobaz {}\n" +
-			"class SpecificFooBaz implements Foobaz {}\n" +
+			"class SpecificFooBaz implements Foobaz {}\n");
+	this.workingCopies[0] = getWorkingCopy(
+			"/Completion/src/test/Test.java",
+			"package test;"+
 			"public class Test {\n" +
 			"  public bar\n" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "public bar";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -374,20 +386,23 @@ public void testClassTypeFieldDeclaration() throws JavaModelException {
 			requestor.getResults());
 }
 public void testClassTypeParamDeclaration() throws JavaModelException {
-	this.workingCopies = new ICompilationUnit[1];
-	this.workingCopies[0] = getWorkingCopy(
-			"/Completion/src/test/Test.java",
-			"package test;"+
+	this.workingCopies = new ICompilationUnit[2];
+	this.workingCopies[1] = getWorkingCopy(
+			"/Completion/src/test/Foobar.java",
+			"package test;\n"+
 			"interface Foobar {}\n" +
 			"class SpecificFooBar implements Foobar {}\n" +
 			"class EvenMoreSpecificFooBar extends SpecificFooBar {}\n" +
 			"interface Foobaz {}\n" +
-			"class SpecificFooBaz implements Foobaz {}\n" +
+			"class SpecificFooBaz implements Foobaz {}\n");
+	this.workingCopies[0] = getWorkingCopy(
+			"/Completion/src/test/Test.java",
+			"package test;"+
 			"public class Test {\n" +
 			"  void setFoo(bar\n" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "void setFoo(bar";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -400,22 +415,25 @@ public void testClassTypeParamDeclaration() throws JavaModelException {
 			requestor.getResults());
 }
 public void testClassTypeLocalVarDeclaration() throws JavaModelException {
-	this.workingCopies = new ICompilationUnit[1];
-	this.workingCopies[0] = getWorkingCopy(
-			"/Completion/src/test/Test.java",
-			"package test;"+
+	this.workingCopies = new ICompilationUnit[2];
+	this.workingCopies[1] = getWorkingCopy(
+			"/Completion/src/test/Foobar.java",
+			"package test;\n"+
 			"interface Foobar {}\n" +
 			"class SpecificFooBar implements Foobar {}\n" +
 			"class EvenMoreSpecificFooBar extends SpecificFooBar {}\n" +
 			"interface Foobaz {}\n" +
-			"class SpecificFooBaz implements Foobaz {}\n" +
+			"class SpecificFooBaz implements Foobaz {}\n");
+	this.workingCopies[0] = getWorkingCopy(
+			"/Completion/src/test/Test.java",
+			"package test;"+
 			"public class Test {\n" +
 			"  void foo() {\n" +
 			"    final bar" +
 			"  }" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "final bar";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -428,21 +446,24 @@ public void testClassTypeLocalVarDeclaration() throws JavaModelException {
 			requestor.getResults());
 }
 public void testClassTypeThrowsDeclaration() throws JavaModelException {
-	this.workingCopies = new ICompilationUnit[1];
+	this.workingCopies = new ICompilationUnit[2];
+	this.workingCopies[1] = getWorkingCopy(
+			"/Completion/src/test/Foobar.java",
+			"package test;\n"+
+			"interface Foobar {}\n" +
+			"class SpecificFooBar implements Foobar {}\n" +
+			"class EvenMoreSpecificFooBar extends SpecificFooBar {}\n" +
+			"interface Foobaz {}\n" +
+			"class SpecificFooBaz implements Foobaz {}\n");
 	this.workingCopies[0] = getWorkingCopy(
 			"/Completion/src/test/Test.java",
 			"package test;"+
-			"interface Foobar {}\n" +
-			"class SpecificFooBar implements Foobar extends Exception {}\n" +
-			"class EvenMoreSpecificFooBar extends SpecificFooBar {}\n" +
-			"interface Foobaz {}\n" +
-			"class SpecificFooBaz implements Foobaz extends Exception {}\n" +
 			"public class Test {\n" +
 			"  void foo() throws bar {\n" +
 			"  }" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "void foo() throws bar";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -454,20 +475,23 @@ public void testClassTypeThrowsDeclaration() throws JavaModelException {
 			requestor.getResults());
 }
 public void testClassTypeExtends() throws JavaModelException {
-	this.workingCopies = new ICompilationUnit[1];
-	this.workingCopies[0] = getWorkingCopy(
-			"/Completion/src/test/Test.java",
-			"package test;"+
+	this.workingCopies = new ICompilationUnit[2];
+	this.workingCopies[1] = getWorkingCopy(
+			"/Completion/src/test/Foobar.java",
+			"package test;\n"+
 			"interface Foobar {}\n" +
 			"class SpecificFooBar implements Foobar {}\n" +
 			"class EvenMoreSpecificFooBar extends SpecificFooBar {}\n" +
 			"interface Foobaz {}\n" +
-			"class SpecificFooBaz implements Foobaz {}\n" +
+			"class SpecificFooBaz implements Foobaz {}\n");
+	this.workingCopies[0] = getWorkingCopy(
+			"/Completion/src/test/Test.java",
+			"package test;"+
 			"public class Test extends bar {\n" +
 			"  }" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "public class Test extends bar";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -479,21 +503,24 @@ public void testClassTypeExtends() throws JavaModelException {
 			requestor.getResults());
 }
 public void testClassTypeImplements() throws JavaModelException {
-	this.workingCopies = new ICompilationUnit[1];
-	this.workingCopies[0] = getWorkingCopy(
-			"/Completion/src/test/Test.java",
-			"package test;"+
+	this.workingCopies = new ICompilationUnit[2];
+	this.workingCopies[1] = getWorkingCopy(
+			"/Completion/src/test/Foobar.java",
+			"package test;\n"+
 			"interface Foobar {}\n" +
 			"interface FoobarExtension extends Foobar {}\n" +
 			"class SpecificFooBar implements Foobar {}\n" +
 			"class EvenMoreSpecificFooBar extends SpecificFooBar {}\n" +
 			"interface Foobaz {}\n" +
-			"class SpecificFooBaz implements Foobaz {}\n" +
+			"class SpecificFooBaz implements Foobaz {}\n");
+	this.workingCopies[0] = getWorkingCopy(
+			"/Completion/src/test/Test.java",
+			"package test;"+
 			"public class Test implements bar {\n" +
 			"  }" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "public class Test implements bar";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -517,7 +544,7 @@ public void testInnerClassTypeInstantiation() throws JavaModelException {
 			"  }\n" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "t.new bar";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -537,7 +564,7 @@ public void testInnerClassTypeFieldDeclaration() throws JavaModelException {
 			"  public bar\n" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "public bar";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -557,7 +584,7 @@ public void testInnerClassTypeParamDeclaration() throws JavaModelException {
 			"  void foo(bar\n" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "void foo(bar";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -579,7 +606,7 @@ public void testInnerClassTypeLocalVarDeclaration() throws JavaModelException {
 			"  }\n" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "final bar";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -599,7 +626,7 @@ public void testInnerClassTypeThrowsDeclaration() throws JavaModelException {
 			"  void foo() throws bar" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "void foo() throws bar";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -619,7 +646,7 @@ public void testInnerClassTypeExtends() throws JavaModelException {
 			"  class SpecificFooBar extends bar\n" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "SpecificFooBar extends bar";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -639,7 +666,7 @@ public void testInnerClassTypeImplements() throws JavaModelException {
 			"  class SpecificFooBar implements bar\n" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "class SpecificFooBar implements bar";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -661,7 +688,7 @@ public void testStaticNestedClassTypeInstantiation() throws JavaModelException {
 			"  }\n" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "new bar";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -681,7 +708,7 @@ public void testStaticNestedClassTypeFieldDeclaration() throws JavaModelExceptio
 			"  public bar\n" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "public bar";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -701,7 +728,7 @@ public void testStaticNestedClassTypeParamDeclaration() throws JavaModelExceptio
 			"  void foo(bar\n" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "void foo(bar";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -723,7 +750,7 @@ public void testStaticNestedClassTypeLocalVarDeclaration() throws JavaModelExcep
 			"  }\n" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "final bar";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -743,7 +770,7 @@ public void testStaticNestedClassTypeThrowsDeclaration() throws JavaModelExcepti
 			"  void foo() throws bar" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "void foo() throws bar";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -763,7 +790,7 @@ public void testStaticNestedClassTypeExtends() throws JavaModelException {
 			"  class SpecificFooBar extends bar\n" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "SpecificFooBar extends bar";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -783,7 +810,7 @@ public void testStaticNestedClassTypeImplements() throws JavaModelException {
 			"  class SpecificFooBar implements bar\n" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "class SpecificFooBar implements bar";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -805,7 +832,7 @@ public void testLocalClassTypeInstantiation() throws JavaModelException {
 			"  }\n" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "new bar";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -827,7 +854,7 @@ public void testLocalClassTypeLocalVarDeclaration() throws JavaModelException {
 			"  }\n" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "final bar";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -849,7 +876,7 @@ public void testLocalClassTypeExtends() throws JavaModelException {
 			"  }\n" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = "class SpecificFooBar extends bar";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -870,7 +897,7 @@ public void testBug488441_1() throws JavaModelException {
 	this.workingCopies[0] = getWorkingCopy(
 			"/Completion/src/test/Test.java",
 			content);
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = ".st";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -900,7 +927,7 @@ public void testBug488441_2() throws JavaModelException {
 			"/Completion/src/test/Test.java",
 			content);
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = ".st";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -930,7 +957,7 @@ public void testBug488441_3() throws JavaModelException {
 			"/Completion/src/test/Test.java",
 			content);
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = ".st";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -960,7 +987,7 @@ public void testBug488441_4() throws JavaModelException {
 			"/Completion/src/test/Test.java",
 			content);
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = ".st";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -992,7 +1019,7 @@ public void testBug488441_5() throws JavaModelException {
 			"	}\n" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = ".as";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -1025,7 +1052,7 @@ public void testBug488441_6() throws JavaModelException {
 			"	}\n" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = ".aS";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -1058,7 +1085,7 @@ public void testBug488441_7() throws JavaModelException {
 			"	}\n" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = ".as";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
@@ -1091,7 +1118,7 @@ public void testBug488441_8() throws JavaModelException {
 			"	}\n" +
 			"}\n");
 
-	CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+	CompletionTestsRequestor2 requestor = createFilteredRequestor();
 	String str = this.workingCopies[0].getSource();
 	String completeBehind = ".as";
 	int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
