@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2022 IBM Corporation and others.
+ * Copyright (c) 2000, 2023 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -8,6 +8,7 @@
  *
  * SPDX-License-Identifier: EPL-2.0
  *
+ * Contributors:
  *     IBM Corporation - initial API and implementation
  *******************************************************************************/
 package org.eclipse.jdt.core.tests.rewrite.describing;
@@ -98,9 +99,12 @@ public class ASTRewritingTest extends AbstractJavaModelTests {
 	/** @deprecated using deprecated code */
 	private final static int JLS18_INTERNAL = AST.JLS18;
 
+	/** @deprecated using deprecated code */
 	private final static int JLS19_INTERNAL = AST.JLS19;
 
-	private final static int[] JLS_LEVELS = { JLS2_INTERNAL, JLS3_INTERNAL, JLS4_INTERNAL, JLS8_INTERNAL, JLS9_INTERNAL, JLS10_INTERNAL, JLS14_INTERNAL, JLS15_INTERNAL, JLS16_INTERNAL, JLS17_INTERNAL, JLS18_INTERNAL, JLS19_INTERNAL};
+	private final static int JLS20_INTERNAL = AST.JLS20;
+
+	private final static int[] JLS_LEVELS = { JLS2_INTERNAL, JLS3_INTERNAL, JLS4_INTERNAL, JLS8_INTERNAL, JLS9_INTERNAL, JLS10_INTERNAL, JLS14_INTERNAL, JLS15_INTERNAL, JLS16_INTERNAL, JLS17_INTERNAL, JLS18_INTERNAL, JLS19_INTERNAL, JLS20_INTERNAL};
 
 	private static final String ONLY_AST_STRING = "_only";
 	private static final String SINCE_AST_STRING = "_since";
@@ -285,12 +289,21 @@ public class ASTRewritingTest extends AbstractJavaModelTests {
 		}
 		setUpProjectAbove19();
 	}
+	@SuppressWarnings("deprecation")
 	protected void setUpProjectAbove19() throws Exception {
 		if (this.apiLevel == AST_INTERNAL_JLS19 ) {
 			this.project1.setOption(JavaCore.COMPILER_COMPLIANCE, JavaCore.VERSION_19);
 			this.project1.setOption(JavaCore.COMPILER_SOURCE, JavaCore.VERSION_19);
 			this.project1.setOption(JavaCore.COMPILER_CODEGEN_TARGET_PLATFORM, JavaCore.VERSION_19);
 		}
+		setUpProjectAbove20();
+	}
+	protected void setUpProjectAbove20() throws Exception {
+		if (this.apiLevel == AST_INTERNAL_JLS20) {
+			this.project1.setOption(JavaCore.COMPILER_COMPLIANCE, JavaCore.VERSION_20);
+			this.project1.setOption(JavaCore.COMPILER_SOURCE, JavaCore.VERSION_20);
+			this.project1.setOption(JavaCore.COMPILER_CODEGEN_TARGET_PLATFORM, JavaCore.VERSION_20);
+		}
 	}
 
 	protected IJavaProject createProject(String projectName, String complianceVersion) throws CoreException {
