@@ -128,7 +128,7 @@ public class StringAsserts {
 				assertEqualString((String) list1.get(0), (String) list2.get(0));
 			}
 
-			StringBuffer buf= new StringBuffer();
+			StringBuilder buf= new StringBuilder();
 			for (int i= 0; i < n1; i++) {
 				String s1= (String) list1.get(i);
 				if (s1 != null) {
@@ -138,7 +138,7 @@ public class StringAsserts {
 			}
 			String actual= buf.toString();
 
-			buf= new StringBuffer();
+			buf= new StringBuilder();
 			for (int i= 0; i < n2; i++) {
 				String s2= (String) list2.get(i);
 				if (s2 != null) {
