@@ -44,7 +44,8 @@ public class X {
 
 	@OnMember
 	public void bar(@OnParameter("unused value")
-	final int i, @OnParameter("unused value") String s) {
+	final int i, @OnParameter("unused value")
+	String s) {
 		@OnLocalVariable @Retention String localString = "string";
 	}
 }
