@@ -43,7 +43,8 @@ public class AllPerformanceTests extends junit.framework.TestCase {
 			FullSourceWorkspaceModelTests.class,
 			FullSourceWorkspaceCompletionTests.class,
 			FullSourceWorkspaceFormatterTests.class,
-			RegionPerformanceTests.class
+			RegionPerformanceTests.class,
+			PTBKeyHashCalculationTest.class
 		};
 	}
 
