@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2021 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -166,6 +166,10 @@ public class CompletionNodeDetector extends ASTVisitor {
 		endVisit(fieldReference);
 	}
 	@Override
+	public void endVisit(GuardedPattern guardedPattern, BlockScope scope) {
+		endVisit(guardedPattern);
+	}
+	@Override
 	public void endVisit(IfStatement ifStatement, BlockScope scope) {
 		this.interestingEnclosings.pop();
 	}
@@ -262,6 +266,10 @@ public class CompletionNodeDetector extends ASTVisitor {
 		endVisit(switchStatement);
 	}
 	@Override
+	public void endVisit(SwitchExpression switchExpression, BlockScope scope) {
+		endVisit(switchExpression);
+	}
+	@Override
 	public void endVisit(ThisReference thisReference, BlockScope scope) {
 		endVisit(thisReference);
 	}
@@ -360,6 +368,10 @@ public class CompletionNodeDetector extends ASTVisitor {
 		return this.visit(fieldReference);
 	}
 	@Override
+	public boolean visit(GuardedPattern guardedPattern, BlockScope scope) {
+		return this.visit(guardedPattern);
+	}
+	@Override
 	public boolean visit(IfStatement ifStatement, BlockScope scope) {
 		this.interestingEnclosings.push(ifStatement);
 		return true;
@@ -461,6 +473,10 @@ public class CompletionNodeDetector extends ASTVisitor {
 		return this.visit(switchStatement);
 	}
 	@Override
+	public boolean visit(SwitchExpression switchExpression, BlockScope blockScope) {
+		return this.visit(switchExpression);
+	}
+	@Override
 	public boolean visit(ThisReference thisReference, BlockScope scope) {
 		return this.visit(thisReference);
 	}
