@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2009 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -16,6 +16,7 @@ package org.eclipse.jdt.internal.codeassist.complete;
 import org.eclipse.jdt.core.compiler.CharOperation;
 import org.eclipse.jdt.internal.compiler.ast.CompilationUnitDeclaration;
 import org.eclipse.jdt.internal.compiler.ast.JavadocSingleNameReference;
+import org.eclipse.jdt.internal.compiler.ast.TypeDeclaration;
 import org.eclipse.jdt.internal.compiler.classfmt.ClassFileConstants;
 import org.eclipse.jdt.internal.compiler.lookup.ClassScope;
 import org.eclipse.jdt.internal.compiler.lookup.MethodScope;
@@ -74,6 +75,19 @@ public class CompletionOnJavadocTag extends JavadocSingleNameReference implement
 				output.append('\n');
 			}
 		}
+		// Print snippet tags
+		char[][] snipTags = this.possibleTags[SNIPPET_IDX];
+		if (snipTags != null) {
+			int length=snipTags.length;
+			if (length > 0) {
+				output.append("\npossible snippet tags:"); //$NON-NLS-1$
+				for (int i=0; i<length; i++) {
+					output.append("\n	- "); //$NON-NLS-1$
+					output.append(snipTags[i]);
+				}
+				output.append('\n');
+			}
+		}
 		return output.append('>');
 	}
 
@@ -86,7 +100,7 @@ public class CompletionOnJavadocTag extends JavadocSingleNameReference implement
 		switch (kind) {
 			case Scope.COMPILATION_UNIT_SCOPE:
 				// bug https://bugs.eclipse.org/bugs/show_bug.cgi?id=255752
-				// Check for FAKE_TYPE_NAME to allow proposals (@see CompletionParser#consumeCompilationUnit)		
+				// Check for FAKE_TYPE_NAME to allow proposals (@see CompletionParser#consumeCompilationUnit)
 				CompilationUnitDeclaration compilationUnit = scope.referenceCompilationUnit();
 				if(compilationUnit != null && compilationUnit.isModuleInfo() ) {
 					specifiedTags = MODULE_TAGS;
@@ -131,7 +145,9 @@ public class CompletionOnJavadocTag extends JavadocSingleNameReference implement
 							switch (scope.kind) {
 								case Scope.CLASS_SCOPE:
 									if (scope.compilerOptions().sourceLevel >= ClassFileConstants.JDK1_5) {
-										if (((ClassScope)scope).referenceContext.binding.isGenericType()) {
+										TypeDeclaration typeDecl = ((ClassScope)scope).referenceContext;
+										boolean isRecordWithComponent = typeDecl.isRecord() && typeDecl.nRecordComponents >0 ;
+										if (((ClassScope)scope).referenceContext.binding.isGenericType() || isRecordWithComponent) {
 											filteredTags[size++] = possibleTag;
 										}
 									}
@@ -175,4 +191,7 @@ public class CompletionOnJavadocTag extends JavadocSingleNameReference implement
 	public char[][] getPossibleInlineTags() {
 		return this.possibleTags[INLINE_IDX];
 	}
+	public char[][] getPossibleInSnippetTags() {
+		return this.possibleTags[SNIPPET_IDX];
+	}
 }
