@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2021 IBM Corporation and others.
+ * Copyright (c) 2000, 2023 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,6 +13,7 @@
  *******************************************************************************/
 package org.eclipse.jdt.internal.codeassist.impl;
 
+import java.util.ArrayList;
 import java.util.Arrays;
 
 /*
@@ -21,8 +22,10 @@ import java.util.Arrays;
  */
 
 import java.util.HashSet;
+import java.util.List;
 
 import org.eclipse.jdt.core.compiler.InvalidInputException;
+import org.eclipse.jdt.internal.compiler.ASTVisitor;
 import org.eclipse.jdt.internal.compiler.CompilationResult;
 import org.eclipse.jdt.internal.compiler.ast.ASTNode;
 import org.eclipse.jdt.internal.compiler.ast.AbstractMethodDeclaration;
@@ -32,6 +35,7 @@ import org.eclipse.jdt.internal.compiler.ast.Block;
 import org.eclipse.jdt.internal.compiler.ast.CaseStatement;
 import org.eclipse.jdt.internal.compiler.ast.CompilationUnitDeclaration;
 import org.eclipse.jdt.internal.compiler.ast.ConstructorDeclaration;
+import org.eclipse.jdt.internal.compiler.ast.EmptyStatement;
 import org.eclipse.jdt.internal.compiler.ast.ExplicitConstructorCall;
 import org.eclipse.jdt.internal.compiler.ast.Expression;
 import org.eclipse.jdt.internal.compiler.ast.FieldDeclaration;
@@ -46,13 +50,16 @@ import org.eclipse.jdt.internal.compiler.ast.MethodDeclaration;
 import org.eclipse.jdt.internal.compiler.ast.ModuleDeclaration;
 import org.eclipse.jdt.internal.compiler.ast.ModuleReference;
 import org.eclipse.jdt.internal.compiler.ast.NameReference;
+import org.eclipse.jdt.internal.compiler.ast.RecordPattern;
 import org.eclipse.jdt.internal.compiler.ast.RequiresStatement;
 import org.eclipse.jdt.internal.compiler.ast.Statement;
 import org.eclipse.jdt.internal.compiler.ast.SuperReference;
 import org.eclipse.jdt.internal.compiler.ast.TypeDeclaration;
+import org.eclipse.jdt.internal.compiler.ast.TypePattern;
 import org.eclipse.jdt.internal.compiler.ast.TypeReference;
 import org.eclipse.jdt.internal.compiler.classfmt.ClassFileConstants;
 import org.eclipse.jdt.internal.compiler.lookup.Binding;
+import org.eclipse.jdt.internal.compiler.lookup.BlockScope;
 import org.eclipse.jdt.internal.compiler.lookup.ExtraCompilerModifiers;
 import org.eclipse.jdt.internal.compiler.parser.Parser;
 import org.eclipse.jdt.internal.compiler.parser.RecoveredBlock;
@@ -131,12 +138,19 @@ public abstract class AssistParser extends Parser {
 	AssistParser[] snapShotStack = new AssistParser[3];
 	int[] snapShotPositions = new int[3];
 	int snapShotPtr = -1;
-	AssistParser lastResumeState;
+
+	static class ResumeState {
+		AssistParser parser;
+		int scannerCurrentPosition;
+		int currentToken;
+	}
+
+	ResumeState lastResumeState;
 	int resumeCount = 0;
 
 	public int cursorLocation = Integer.MAX_VALUE;
 
-	protected static final int[] RECOVERY_TOKENS = { TokenNameSEMICOLON, TokenNameRPAREN, TokenNameRBRACE, TokenNameRBRACKET};
+	protected static final int[] RECOVERY_TOKENS = { TokenNameSEMICOLON, TokenNameRPAREN, TokenNameRBRACE, TokenNameRBRACKET, TokenNameCOLON};
 
 
 public AssistParser(ProblemReporter problemReporter) {
@@ -355,11 +369,36 @@ public RecoveredElement buildInitialRecoveryState(){
 					element = element.add(stmt, 0);
 					this.lastCheckPoint = stmt.sourceEnd + 1;
 				} else if (stmt.containsPatternVariable()) {
-					LocalDeclaration localDeclaration = null;
 					if(stmt instanceof CaseStatement) {
-						localDeclaration = ((CaseStatement)stmt).getLocalDeclaration();
-						if(localDeclaration !=null)
-							element.add(localDeclaration, 0);
+						// Kludge, for the unfortunate case where recovery can't
+						// construct a switch expression but simply creates a case statement (with type patterns)
+						// and leaves it in the astStack
+						final List<LocalDeclaration> locals = new ArrayList<>();
+						node.traverse(new ASTVisitor() {
+							@SuppressWarnings("synthetic-access")
+							@Override
+							public boolean visit(RecordPattern pattern, BlockScope scope) {
+								LocalDeclaration local = pattern.local;
+								if (local == null)
+									return true;
+								locals.add(local);
+								AssistParser.this.lastCheckPoint = local.declarationSourceEnd + 1;
+								return true;
+							}
+							@SuppressWarnings("synthetic-access")
+							@Override
+							public boolean visit(TypePattern pattern, BlockScope scope) {
+								LocalDeclaration local = pattern.local;
+								if (local == null)
+									return true;
+								locals.add(local);
+								AssistParser.this.lastCheckPoint = local.declarationSourceEnd + 1;
+								return true;
+							}
+						}, null);
+						for (LocalDeclaration local : locals) {
+							element.add(local, 0);
+						}
 					}
 					element.add(stmt, 0);
 					this.lastCheckPoint = stmt.sourceEnd + 1;
@@ -593,7 +632,7 @@ protected boolean triggerRecoveryUponLambdaClosure(Statement statement, boolean
 							stackLength);
 				}
 				this.stack[this.stateStackTop] = this.unstackedAct;
-				commit(false);
+				commit();
 				this.stateStackTop --;
 			}
 			return false;
@@ -932,7 +971,7 @@ protected void consumeOpenBlock() {
 			}
 			this.stack[this.stateStackTop++] = this.unstackedAct; // transition to Block ::= OpenBlock  .LBRACE BlockStatementsopt RBRACE
 			this.stack[this.stateStackTop] = tAction(this.unstackedAct, this.currentToken); // transition to Block ::= OpenBlock LBRACE  .BlockStatementsopt RBRACE
-			commit(true);
+			commit();
 			this.stateStackTop -= 2;
 		}
 	}
@@ -1389,7 +1428,7 @@ protected void consumeToken(int token) {
 			case TokenNameLBRACE:
 				if (this.previousToken == TokenNameARROW) {
 					popElement(K_LAMBDA_EXPRESSION_DELIMITER);
-					if (topKnownElementKind(ASSIST_PARSER, 1) != K_SWITCH_EXPRESSION_DELIMITTER)
+					if (topKnownElementKind(ASSIST_PARSER) != K_SWITCH_EXPRESSION_DELIMITTER)
 						pushOnElementStack(K_LAMBDA_EXPRESSION_DELIMITER, BLOCK_BODY, this.previousObjectInfo);
 				}
 				break;
@@ -2308,16 +2347,11 @@ public void reset(){
 	flushAssistState();
 }
 
-void commit(boolean isStart) {
-	int newSnapShotPosition = this.scanner.startPosition;
-	if (this.snapShotPtr == -1) {
-		// first commit:
+void commit() {
+	int newSnapShotPosition = this.blockStarts[this.realBlockPtr];
+	if (this.snapShotPtr == -1 || newSnapShotPosition != this.snapShotPositions[this.snapShotPtr]) {
+		// first commit, or existing snapshot doesn't match
 		addNewSnapShot(newSnapShotPosition);
-	} else {
-		// already have a snapshot, does it match the current position and can thus be reused?
-		int currentStartPosition = isStart ? newSnapShotPosition : this.blockStarts[this.realBlockPtr];
-		if (currentStartPosition != this.snapShotPositions[this.snapShotPtr])
-			addNewSnapShot(newSnapShotPosition); // no match, create a new one
 	}
 	this.snapShotStack[this.snapShotPtr].copyState(this);
 }
@@ -2387,7 +2421,7 @@ protected int fallBackToSpringForward(Statement unused) {
 		if (nextToken == TokenNameRBRACE)
 			ignoreNextClosingBrace(); // having ungotten it, recoveryTokenCheck will see this again.
 	}
-	// OK, next token is no good to resume "in place", attempt some local repair. FIXME: need to make sure we don't get stuck keep reducing empty statements !!
+	// OK, next token is no good to resume "in place", attempt some local repair.
 	for (int i = 0, length = RECOVERY_TOKENS.length; i < length; i++) {
 		if (automatonWillShift(RECOVERY_TOKENS[i], automatonState)) {
 			this.currentToken = RECOVERY_TOKENS[i];
@@ -2520,18 +2554,33 @@ private boolean safeToResume() {
 	} else {
 		this.resumeCount = 0;
 	}
-	this.lastResumeState = createSnapShotParser();
-	this.lastResumeState.copyState(this);
+	if (this.lastResumeState == null)
+		this.lastResumeState = new ResumeState();
+	this.lastResumeState.parser = createSnapShotParser();
+	this.lastResumeState.parser.copyState(this);
+	this.lastResumeState.scannerCurrentPosition = this.scanner.currentPosition;
+	this.lastResumeState.currentToken = this.currentToken;
 	return true;
 }
-private boolean noProgressSince(AssistParser previous) {
+private boolean noProgressSince(ResumeState previous) {
 	int stateTop = this.stateStackTop;
 	int astTop = this.astPtr;
 	int exprTop = this.expressionPtr;
-	return stateTop == previous.stateStackTop && astTop == previous.astPtr && exprTop == previous.expressionPtr
-			&& Arrays.equals(this.stack, 0, stateTop, previous.stack, 0, stateTop)
-			&& (astTop == -1 || Arrays.equals(this.astStack, 0, astTop, previous.astStack, 0, astTop))
-			&& (exprTop == -1 || Arrays.equals(this.expressionStack, 0, exprTop, previous.expressionStack, 0, exprTop));
+	if (stateTop == previous.parser.stateStackTop && astTop == previous.parser.astPtr && exprTop == previous.parser.expressionPtr
+			&& Arrays.equals(this.stack, 0, stateTop, previous.parser.stack, 0, stateTop)
+			&& (astTop == -1 || Arrays.equals(this.astStack, 0, astTop, previous.parser.astStack, 0, astTop))
+			&& (exprTop == -1 || Arrays.equals(this.expressionStack, 0, exprTop, previous.parser.expressionStack, 0, exprTop)))
+		return true; // Parser didn't budge.
+
+	ASTNode node;
+	if (previous.scannerCurrentPosition == this.scanner.currentPosition &&
+			previous.currentToken == this.currentToken &&
+			astTop == previous.parser.astPtr + 1 &&
+			((node = this.astStack[this.astPtr]) instanceof EmptyStatement) &&
+			(node.bits & ASTNode.IsUsefulEmptyStatement) == 0)
+		return true; // scanner didn't advance either, attempts to nudge recovery along, merely is producing useless empty statements ...
+
+	return false;
 }
 
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=292087
