@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2022 IBM Corporation and others.
+ * Copyright (c) 2000, 2023 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -145,35 +145,6 @@ protected void attachOrphanCompletionNode(){
 			this.currentToken = 0; // given we are not on an eof, we do not want side effects caused by looked-ahead token
 		}
 	}
-	// if casestatement and not orphan, then add switch statement as assist node parent
-	if (this.expressionPtr > 0 && this.assistNodeParent == null) {
-		if (this.astPtr >= 0) {
-			if (this.astStack[this.astPtr] instanceof CaseStatement) {
-				// add switch statement as assistNodeParent
-				Expression expression = this.expressionStack[this.expressionPtr];
-				SwitchStatement switchStatement = new SwitchStatement();
-				switchStatement.expression = this.expressionStack[this.expressionPtr - 1];
-				if (this.astLengthPtr > -1 && this.astPtr > -1) {
-					int length = this.astLengthStack[this.astLengthPtr];
-					int newAstPtr = this.astPtr - length;
-					ASTNode firstNode = this.astStack[newAstPtr + 1];
-					if (length != 0 && firstNode.sourceStart > switchStatement.expression.sourceEnd) {
-						switchStatement.statements = new Statement[length + 1];
-						System.arraycopy(this.astStack, newAstPtr + 1, switchStatement.statements, 0, length);
-					}
-
-				}
-				CaseStatement caseStatement = new CaseStatement(expression, expression.sourceStart,
-						expression.sourceEnd);
-				if (switchStatement.statements == null) {
-					switchStatement.statements = new Statement[] { caseStatement };
-				} else {
-					switchStatement.statements[switchStatement.statements.length - 1] = caseStatement;
-				}
-				this.assistNodeParent = switchStatement;
-			}
-		}
-	}
 }
 private void buildMoreCompletionContext(Expression expression) {
 	ASTNode parentNode = null;
@@ -818,17 +789,6 @@ protected void consumeInsideCastExpressionWithQualifiedGenerics() {
 	pushOnElementStack(K_CAST_STATEMENT);
 }
 @Override
-protected void consumeInstanceOfExpression() {
-	if (indexOfAssistIdentifier() < 0) {
-		super.consumeInstanceOfExpression();
-	} else {
-		getTypeReference(this.intStack[this.intPtr--]);
-		this.isOrphanCompletionNode = true;
-		this.restartRecovery = true;
-		this.lastIgnoredToken = -1;
-	}
-}
-@Override
 protected Expression consumePatternInsideInstanceof(Pattern pattern) {
 	if(pattern instanceof RecordPattern) {
 		pushLocalVariableFromRecordPatternOnAstStack((RecordPattern)pattern);
@@ -852,7 +812,11 @@ protected void consumeCaseLabelElement(CaseLabelKind kind) {
 
 	}
 }
-
+@Override
+protected void consumeSwitchLabeledExpression() {
+	super.consumeSwitchLabeledExpression();
+	popElement(K_SWITCH_EXPRESSION_DELIMITTER);
+}
 private void pushLocalVariableFromRecordPatternOnAstStack(RecordPattern rp) {
 	Pattern[] patterns = rp.patterns;
 	for (Pattern pattern : patterns) {
@@ -1373,6 +1337,9 @@ protected void consumeToken(int token) {
 					popElement(K_BETWEEN_CASE_AND_COLONORARROW);
 				}
 				break;
+			case TokenNameBeginCaseExpr:
+				pushOnElementStack(K_SWITCH_EXPRESSION_DELIMITTER);
+				break;
 			case TokenNamereturn:
 				pushOnElementStack(K_INSIDE_RETURN_STATEMENT, this.bracketDepth);
 				break;
