@@ -630,6 +630,25 @@ public abstract class ASTVisitor {
 		return true;
 	}
 
+	/**
+	 * Visits the given type-specific AST node.
+	 * <p>
+	 * The default implementation does nothing and return true.
+	 * Subclasses may reimplement.
+	 * </p>
+	 *
+	 * @param node the node to visit
+	 * @return <code>true</code> if the children of this node should be
+	 * visited, and <code>false</code> if the children of this node should
+	 * be skipped
+	 *
+	 * @since 3.33
+	 * @noreference This method is not intended to be referenced by clients.
+	 */
+	public boolean visit(EnhancedForWithRecordPattern node) {
+		return true;
+	}
+
 	/**
 	 * Visits the given type-specific AST node.
 	 * <p>
@@ -2403,6 +2422,20 @@ public abstract class ASTVisitor {
 		// default implementation: do nothing
 	}
 
+	/**
+	 * End of visit the given type-specific AST node.
+	 * <p>
+	 * The default implementation does nothing. Subclasses may reimplement.
+	 * </p>
+	 *
+	 * @param node the node to visit
+	 * @since 3.33
+	 * @noreference This method is not intended to be referenced by clients.
+	 */
+	public void endVisit(EnhancedForWithRecordPattern node) {
+		// default implementation: do nothing
+	}
+
 	/**
 	 * End of visit the given type-specific AST node.
 	 * <p>
