@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -7,7 +7,7 @@
  * https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- *Contributors:
+ * Contributors:
  *     IBM Corporation - initial API and implementation
  *******************************************************************************/
 package org.eclipse.jdt.core.dom;
@@ -84,6 +84,10 @@ class DefaultASTVisitor extends ASTVisitor {
 		endVisitNode(node);
 	}
 	@Override
+	public void endVisit(CaseDefaultExpression node) {
+		endVisitNode(node);
+	}
+	@Override
 	public void endVisit(CastExpression node) {
 		endVisitNode(node);
 	}
@@ -165,6 +169,10 @@ class DefaultASTVisitor extends ASTVisitor {
 		endVisitNode(node);
 	}
 	@Override
+	public void endVisit(GuardedPattern node) {
+		endVisitNode(node);
+	}
+	@Override
 	public void endVisit(IfStatement node) {
 		endVisitNode(node);
 	}
@@ -193,6 +201,14 @@ class DefaultASTVisitor extends ASTVisitor {
 		endVisitNode(node);
 	}
 	@Override
+	public void endVisit(JavaDocRegion node) {
+		endVisitNode(node);
+	}
+	@Override
+	public void endVisit(JavaDocTextElement node) {
+		endVisitNode(node);
+	}
+	@Override
 	public void endVisit(LabeledStatement node) {
 		endVisitNode(node);
 	}
@@ -244,6 +260,10 @@ class DefaultASTVisitor extends ASTVisitor {
 		endVisitNode(node);
 	}
 	@Override
+	public void endVisit(ModuleQualifiedName node) {
+		endVisitNode(node);
+	}
+	@Override
 	public void endVisit(NameQualifiedType node) {
 		endVisitNode(node);
 	}
@@ -257,6 +277,10 @@ class DefaultASTVisitor extends ASTVisitor {
 		endVisitNode(node);
 	}
 	@Override
+	public void endVisit(NullPattern node) {
+		endVisitNode(node);
+	}
+	@Override
 	public void endVisit(NumberLiteral node) {
 		endVisitNode(node);
 	}
@@ -273,6 +297,10 @@ class DefaultASTVisitor extends ASTVisitor {
 		endVisitNode(node);
 	}
 	@Override
+	public void endVisit(PatternInstanceofExpression node) {
+		endVisitNode(node);
+	}
+	@Override
 	public void endVisit(PostfixExpression node) {
 		endVisitNode(node);
 	}
@@ -293,6 +321,14 @@ class DefaultASTVisitor extends ASTVisitor {
 		endVisitNode(node);
 	}
 	@Override
+	public void endVisit(RecordDeclaration node) {
+		endVisitNode(node);
+	}
+	@Override
+	public void endVisit(RecordPattern node) {
+		endVisitNode(node);
+	}
+	@Override
 	public void endVisit(ReturnStatement node) {
 		endVisitNode(node);
 	}
@@ -353,6 +389,14 @@ class DefaultASTVisitor extends ASTVisitor {
 		endVisitNode(node);
 	}
 	@Override
+	public void endVisit(TagProperty node) {
+		endVisitNode(node);
+	}
+	@Override
+	public void endVisit(TextBlock node) {
+		endVisitNode(node);
+	}
+	@Override
 	public void endVisit(TextElement node) {
 		endVisitNode(node);
 	}
@@ -390,6 +434,10 @@ class DefaultASTVisitor extends ASTVisitor {
 		endVisitNode(node);
 	}
 	@Override
+	public void endVisit(TypePattern node) {
+		endVisitNode(node);
+	}
+	@Override
 	public void endVisit(UnionType node) {
 		endVisitNode(node);
 	}
@@ -413,6 +461,10 @@ class DefaultASTVisitor extends ASTVisitor {
 	public void endVisit(WildcardType node) {
 		endVisitNode(node);
 	}
+	@Override
+	public void endVisit(YieldStatement node) {
+		endVisitNode(node);
+	}
 	protected void endVisitNode(ASTNode node) {
 		// do nothing
 	}
@@ -471,6 +523,10 @@ class DefaultASTVisitor extends ASTVisitor {
 		return visitNode(node);
 	}
 	@Override
+	public boolean visit(CaseDefaultExpression node) {
+		return visitNode(node);
+	}
+	@Override
 	public boolean visit(CastExpression node) {
 		return visitNode(node);
 	}
@@ -552,6 +608,10 @@ class DefaultASTVisitor extends ASTVisitor {
 		return visitNode(node);
 	}
 	@Override
+	public boolean visit(GuardedPattern node) {
+		return visitNode(node);
+	}
+	@Override
 	public boolean visit(IfStatement node) {
 		return visitNode(node);
 	}
@@ -584,6 +644,14 @@ class DefaultASTVisitor extends ASTVisitor {
 		return false;
 	}
 	@Override
+	public boolean visit(JavaDocRegion node) {
+		return visitNode(node);
+	}
+	@Override
+	public boolean visit(JavaDocTextElement node) {
+		return visitNode(node);
+	}
+	@Override
 	public boolean visit(LabeledStatement node) {
 		return visitNode(node);
 	}
@@ -631,6 +699,10 @@ class DefaultASTVisitor extends ASTVisitor {
 		return visitNode(node);
 	}
 	@Override
+	public boolean visit(ModuleQualifiedName node) {
+		return visitNode(node);
+	}
+	@Override
 	public boolean visit(MethodRefParameter node) {
 		return visitNode(node);
 	}
@@ -648,6 +720,10 @@ class DefaultASTVisitor extends ASTVisitor {
 		return visitNode(node);
 	}
 	@Override
+	public boolean visit(NullPattern node) {
+		return visitNode(node);
+	}
+	@Override
 	public boolean visit(NumberLiteral node) {
 		return visitNode(node);
 	}
@@ -664,6 +740,10 @@ class DefaultASTVisitor extends ASTVisitor {
 		return visitNode(node);
 	}
 	@Override
+	public boolean visit(PatternInstanceofExpression node) {
+		return visitNode(node);
+	}
+	@Override
 	public boolean visit(PostfixExpression node) {
 		return visitNode(node);
 	}
@@ -685,6 +765,14 @@ class DefaultASTVisitor extends ASTVisitor {
 		return visitNode(node);
 	}
 	@Override
+	public boolean visit(RecordDeclaration node) {
+		return visitNode(node);
+	}
+	@Override
+	public boolean visit(RecordPattern node) {
+		return visitNode(node);
+	}
+	@Override
 	public boolean visit(ReturnStatement node) {
 		return visitNode(node);
 	}
@@ -734,7 +822,7 @@ class DefaultASTVisitor extends ASTVisitor {
 	public boolean visit(SwitchCase node) {
 		return visitNode(node);
 	}
-	
+
 	@Override
 	public boolean visit(SwitchExpression node) {
 		return visitNode(node);
@@ -755,6 +843,16 @@ class DefaultASTVisitor extends ASTVisitor {
 		return visitNode(node);
 	}
 
+	@Override
+	public boolean visit(TagProperty node) {
+		return visitNode(node);
+	}
+
+	@Override
+	public boolean visit(TextBlock node) {
+		return visitNode(node);
+	}
+
 	@Override
 	public boolean visit(TextElement node) {
 		return visitNode(node);
@@ -800,11 +898,16 @@ class DefaultASTVisitor extends ASTVisitor {
 		return visitNode(node);
 	}
 
+	@Override
+	public boolean visit(TypePattern node) {
+		return visitNode(node);
+	}
+
 	@Override
 	public boolean visit(UnionType node) {
 		return visitNode(node);
 	}
-	
+
 	@Override
 	public boolean visit(VariableDeclarationExpression node) {
 		return visitNode(node);
@@ -830,6 +933,11 @@ class DefaultASTVisitor extends ASTVisitor {
 		return visitNode(node);
 	}
 
+	@Override
+	public boolean visit(YieldStatement node) {
+		return visitNode(node);
+	}
+
 	protected boolean visitNode(ASTNode node) {
 		return true;
 	}
