@@ -18,6 +18,7 @@ package org.eclipse.jdt.core.dom;
 
 import org.eclipse.jdt.core.IJavaElement;
 import org.eclipse.jdt.core.JavaCore;
+import org.eclipse.jdt.core.compiler.CharOperation;
 import org.eclipse.jdt.internal.compiler.classfmt.ClassFileConstants;
 import org.eclipse.jdt.internal.compiler.lookup.ExtraCompilerModifiers;
 import org.eclipse.jdt.internal.compiler.lookup.LookupEnvironment;
@@ -86,7 +87,7 @@ class MethodBinding implements IMethodBinding {
 	 */
 	@Override
 	public boolean isCanonicalConstructor() {
-		return ((this.binding.tagBits & TagBits.IsCanonicalConstructor) != 0);
+		return this.binding.isCanonicalConstructor();
 	}
 
 	/**
@@ -614,4 +615,9 @@ class MethodBinding implements IMethodBinding {
 		return ((getDeclaringClass().isRecord()) &&
 				(this.binding instanceof SyntheticMethodBinding));
 	}
+
+	@Override
+	public String[] getParameterNames() {
+		return CharOperation.toStrings(this.binding.parameterNames);
+	}
 }
\ No newline at end of file
