@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2022 IBM Corporation and others.
+ * Copyright (c) 2000, 2023 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -653,11 +653,16 @@ public class ASTRewriteFlattener extends ASTVisitor {
 		return false;
 	}
 
+	@SuppressWarnings("deprecation")
 	@Override
 	public boolean visit(PatternInstanceofExpression node) {
 		getChildNode(node, PatternInstanceofExpression.LEFT_OPERAND_PROPERTY).accept(this);
 		this.result.append(" instanceof "); //$NON-NLS-1$
-		getChildNode(node, PatternInstanceofExpression.RIGHT_OPERAND_PROPERTY).accept(this);
+		if (node.getAST().apiLevel() >= AST.JLS20 && node.getAST().isPreviewEnabled()) {
+			getChildNode(node, PatternInstanceofExpression.PATTERN_PROPERTY).accept(this);
+		} else {
+			getChildNode(node, PatternInstanceofExpression.RIGHT_OPERAND_PROPERTY).accept(this);
+		}
 		return false;
 	}
 
@@ -914,7 +919,7 @@ public class ASTRewriteFlattener extends ASTVisitor {
 		visitList(node, RecordDeclaration.SUPER_INTERFACE_TYPES_PROPERTY, String.valueOf(','), "implements ", Util.EMPTY_STRING); //$NON-NLS-1$
 
 		this.result.append('{');
-		visitList(node, RecordDeclaration.BODY_DECLARATIONS_PROPERTY, Util.EMPTY_STRING, String.valueOf(';'), Util.EMPTY_STRING);
+		visitList(node, RecordDeclaration.BODY_DECLARATIONS_PROPERTY, Util.EMPTY_STRING);
 		this.result.append('}');
 		return false;
 	}
@@ -1630,15 +1635,14 @@ public class ASTRewriteFlattener extends ASTVisitor {
 
 	@Override
 	public boolean visit(YieldStatement node) {
-		if (node.getAST().apiLevel() >= JLS14_INTERNAL && node.isImplicit()  && node.getExpression() == null) {
-			return false;
+		if (!node.isImplicit()) {
+			this.result.append("yield"); //$NON-NLS-1$
 		}
-
-		this.result.append("yield"); //$NON-NLS-1$
-
 		ASTNode expression = getChildNode(node, YieldStatement.EXPRESSION_PROPERTY);
-		if (expression != null ) {
-			this.result.append(' ');
+		if (expression != null) {
+			if (!node.isImplicit()) {
+				this.result.append(' ');
+			}
 			expression.accept(this);
 		}
 		this.result.append(';');
