@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2019, 2021 IBM Corporation and others.
+ * Copyright (c) 2019, 2023 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -19,6 +19,7 @@ import org.eclipse.jdt.core.dom.AST;
 import org.eclipse.jdt.core.dom.ASTNode;
 import org.eclipse.jdt.core.dom.Modifier;
 
+@SuppressWarnings("deprecation")
 public class DOMASTUtil {
 
 	/**
@@ -54,7 +55,6 @@ public class DOMASTUtil {
 	 * @see ASTNode#getNodeType()
 	 * @since 3.22
 	 */
-	@SuppressWarnings("deprecation")
 	private static boolean isNodeTypeSupportedinAST(int apiLevel, boolean previewEnabled, int nodeType) {
 		switch (nodeType) {
 			case ASTNode.SWITCH_EXPRESSION:
@@ -65,6 +65,10 @@ public class DOMASTUtil {
 			case ASTNode.RECORD_DECLARATION:
 			case ASTNode.PATTERN_INSTANCEOF_EXPRESSION:
 				return apiLevel >= AST.JLS16;
+			case ASTNode.TYPE_PATTERN:
+				return apiLevel == AST.getJLSLatest() && previewEnabled;
+			case ASTNode.TAG_PROPERTY:
+				return apiLevel >= AST.JLS18;
 		}
 		return false;
 	}
@@ -86,9 +90,9 @@ public class DOMASTUtil {
 	public static boolean isFeatureSupportedinAST(AST ast, int featureName) {
 		switch (featureName) {
 			case Modifier.SEALED:
-				return isPreviewEnabled(ast.apiLevel(), ast.isPreviewEnabledSet());
+				return ast.apiLevel() >= AST.JLS17;
 			case Modifier.NON_SEALED:
-				return isPreviewEnabled(ast.apiLevel(), ast.isPreviewEnabledSet());
+				return ast.apiLevel() >= AST.JLS17;
 		}
 		return false;
 	}
@@ -112,15 +116,39 @@ public class DOMASTUtil {
 	public static boolean isFeatureSupportedinAST(int apiLevel, boolean previewEnabled, int featureName) {
 		switch (featureName) {
 			case Modifier.SEALED:
-				return isPreviewEnabled(apiLevel, previewEnabled);
+				return apiLevel >= AST.JLS17;
 			case Modifier.NON_SEALED:
-				return isPreviewEnabled(apiLevel, previewEnabled);
+				return apiLevel >= AST.JLS17;
 		}
 		return false;
 	}
 
-	private static boolean isPreviewEnabled(int apiLevel, boolean previewEnabled) {
-		return (apiLevel == AST.JLS16 && previewEnabled);
+	/**
+	 * Validates if the given <code>apiLevel</code> and <code>previewEnabled</code> supports the provided
+	 * <code>nodeType</code>. This API checks for node types supported from JLS 14 onwards and will return
+	 * <code>true></code> for nodes added before JLS14.
+	 *
+	 * @param apiLevel
+	 *            the level to be checked
+	 * @param featureName
+	 *            the feature name constant indicating the feature to be evaluated
+	 * @return <code>true</code> if the given <code>AST</code> supports the provided <code>nodeType</code> else
+	 *         <code>false</code>
+	 * @see ASTNode#getNodeType()
+	 * @since 3.27
+	 */
+	public static boolean isFeatureSupportedinAST(int apiLevel, int featureName) {
+		switch (featureName) {
+			case Modifier.SEALED:
+				return apiLevel >= AST.JLS17;
+			case Modifier.NON_SEALED:
+				return apiLevel >= AST.JLS17;
+		}
+		return false;
+	}
+
+	public static boolean isPreviewEnabled(int apiLevel, boolean previewEnabled) {
+		return (apiLevel == AST.JLS17 && previewEnabled);
 	}
 
 	public static boolean isSwitchExpressionSupported(AST ast) {
@@ -147,7 +175,19 @@ public class DOMASTUtil {
 		return isNodeTypeSupportedinAST(ast, ASTNode.PATTERN_INSTANCEOF_EXPRESSION);
 	}
 
-	@SuppressWarnings("deprecation")
+	public static boolean isPatternSupported(AST ast) {
+		return isNodeTypeSupportedinAST(ast, ASTNode.TYPE_PATTERN);
+	}
+
+	public static boolean isPatternSupported(int apiLevel, boolean previewEnabled) {
+		return isNodeTypeSupportedinAST(apiLevel, previewEnabled, ASTNode.TYPE_PATTERN);
+	}
+
+	public static boolean isJavaDocCodeSnippetSupported(int apiLevel) {
+		return isNodeTypeSupportedinAST(apiLevel, true, ASTNode.TAG_PROPERTY);
+	}
+
+
 	public static void checkASTLevel(int level) {
 		// Clients can use AST.getJLSLatest()
 		if(level >=AST.JLS8 && level <= AST.getJLSLatest() )
@@ -163,7 +203,8 @@ public class DOMASTUtil {
 
 	private static final String[] AST_COMPLIANCE_MAP = {"-1","-1",JavaCore.VERSION_1_2, JavaCore.VERSION_1_3, JavaCore.VERSION_1_7, //$NON-NLS-1$ //$NON-NLS-2$
 			JavaCore.VERSION_1_7, JavaCore.VERSION_1_7, JavaCore.VERSION_1_7, JavaCore.VERSION_1_8, JavaCore.VERSION_9, JavaCore.VERSION_10,
-			JavaCore.VERSION_11, JavaCore.VERSION_12, JavaCore.VERSION_13, JavaCore.VERSION_14, JavaCore.VERSION_15, JavaCore.VERSION_16};
+			JavaCore.VERSION_11, JavaCore.VERSION_12, JavaCore.VERSION_13, JavaCore.VERSION_14, JavaCore.VERSION_15, JavaCore.VERSION_16, JavaCore.VERSION_17, JavaCore.VERSION_18,
+			JavaCore.VERSION_19, JavaCore.VERSION_20};
 
 	/**
 	 * Calculates the JavaCore Option value string corresponding to the input ast level.
@@ -172,7 +213,6 @@ public class DOMASTUtil {
 	 * @param astLevel
 	 * @return JavaCore Option value string corresponding to the ast level
 	 */
-	@SuppressWarnings("deprecation")
 	public static String getCompliance(int astLevel) {
 		if (astLevel < AST.JLS2 && astLevel > AST.getJLSLatest()) return JavaCore.latestSupportedJavaVersion();
 		return AST_COMPLIANCE_MAP[astLevel];
