@@ -17,6 +17,9 @@
 
 package org.eclipse.jdt.core.compiler;
 
+import java.io.ByteArrayInputStream;
+import java.util.Optional;
+
 import org.eclipse.jdt.core.IJavaProject;
 
 /**
@@ -30,11 +33,17 @@ import org.eclipse.jdt.core.IJavaProject;
  * rather than a CompilationParticipant. It is only necessary to use a CompilationParticipant if
  * the build step needs to interact with the Java build, for instance by creating additional
  * Java source files that must themselves in turn be compiled.
- * <p>
+ * </p><p>
  * Clients wishing to participate in the compilation process must subclass this class, and implement
  * {@link #isActive(IJavaProject)}, {@link #aboutToBuild(IJavaProject)},
  * {@link #reconcile(ReconcileContext)}, etc.
-* </p><p>
+ * </p>
+ * <p>
+ * If the "requires" attribute is not used for participant definition, there will be no specific order in which
+ * potential multiple compilation participants are called. If they have to be called in a specific order, the attribute
+ * "requires" can be set on the extension point entries.
+ * </p>
+ * <p>
  * This class is intended to be subclassed by clients.
  * </p>
  * @since 3.2
@@ -102,7 +111,7 @@ public void cleanStarting(IJavaProject project) {
  * </p><p>
  * For efficiency, participants that are not interested in the
  * given project should return <code>false</code> for that project.
- * </p><p>
+ * </p>
  * Note: In {@link org.eclipse.jdt.core.WorkingCopyOwner#newWorkingCopy(String, org.eclipse.jdt.core.IClasspathEntry[], org.eclipse.core.runtime.IProgressMonitor)
  * special cases}, the project may be closed and not exist. Participants typically return false when the
  * underlying project is closed. I.e. when the following check returns false:
@@ -143,6 +152,52 @@ public void processAnnotations(BuildContext[] files) {
 	// do nothing by default
 }
 
+/**
+ * Returns whether this participant is interested in post processing of generated bytecode.
+ * <p>
+ * Returning <code>true</code> enables the callback {@link #postProcess(BuildContext,ByteArrayInputStream)}, where this
+ * participant can influence produced class file bytes.
+ * </p>
+ * <p>
+ * Default is to return <code>false</code>.
+ * </p>
+ *
+ * @return whether this participant is interested in post processing
+ * @since 3.34
+ */
+public boolean isPostProcessor() {
+	return false;
+}
+
+/**
+ * Notifies this participant about a finished class compilation. This notification occurs right before the compiled
+ * class is written out to disk. This allows to perform arbitrary byte code manipulation on the generated class.
+ * <p>
+ * Only sent to participants that answer true to {@link #isPostProcessor()}.
+ * </p>
+ * <ul>
+ * <li>If additional dependencies to other classes are introduced by the modified class, these dependencies have to be
+ * recorded by calling {@link BuildContext#recordDependencies(String[])}.</li>
+ * <li>In case problems occur, they can be reported using {@link BuildContext#recordNewProblems(CategorizedProblem[])}.
+ * </li>
+ * <li>No other API's to record build state changes are supported during post-processing.</li>
+ * </ul>
+ * <b>Note</b>: the received class data could have already been transformed by another compilation participant. If the
+ * compilation participants have to be called in a specific order, the attribute &quot;requires&quot; can be used in the
+ * participant contribution entry.
+ *
+ * @param file
+ *            context of the generated class
+ * @param bytes
+ *            byte representation of the generated class
+ * @return Optional containing byte array representing the modified class or empty Optional if no modification was
+ *         applied. Default implementation returns empty Optional.
+ * @since 3.34
+ */
+public Optional<byte[]> postProcess(BuildContext file, ByteArrayInputStream bytes) {
+	return Optional.empty();
+}
+
 /**
  * Notifies this participant that a reconcile operation is happening. The participant can act on this reconcile
  * operation by using the given context. Other participant can then see the result of this participation
