@@ -207,7 +207,7 @@ public int getElementType() {
 public int getFlags() throws JavaModelException {
 	IBinaryMethod info = (IBinaryMethod) getElementInfo();
 	int modifiers = info.getModifiers();
-	if (((IType) this.parent).isInterface() && (modifiers & (ClassFileConstants.AccAbstract | ClassFileConstants.AccStatic)) == 0)
+	if (((IType) this.getParent()).isInterface() && (modifiers & (ClassFileConstants.AccAbstract | ClassFileConstants.AccStatic)) == 0)
 		modifiers |= ExtraCompilerModifiers.AccDefaultMethod;
 	return modifiers;
 }
@@ -216,7 +216,7 @@ public int getFlags() throws JavaModelException {
  */
 @Override
 protected void getHandleMemento(StringBuffer buff) {
-	((JavaElement) getParent()).getHandleMemento(buff);
+	getParent().getHandleMemento(buff);
 	char delimiter = getHandleMementoDelimiter();
 	buff.append(delimiter);
 	escapeMementoName(buff, getElementName());
@@ -622,7 +622,7 @@ public int hashCode() {
  */
 @Override
 public boolean isConstructor() throws JavaModelException {
-	if (!getElementName().equals(this.parent.getElementName())) {
+	if (!getElementName().equals(this.getParent().getElementName())) {
 		// faster than reaching the info
 		return false;
 	}
@@ -663,7 +663,7 @@ public boolean isSimilar(IMethod method) {
 @Override
 public String readableName() {
 
-	StringBuffer buffer = new StringBuffer(super.readableName());
+	StringBuilder buffer = new StringBuilder(super.readableName());
 	buffer.append("("); //$NON-NLS-1$
 	String[] paramTypes = this.parameterTypes;
 	int length;
@@ -680,7 +680,7 @@ public String readableName() {
 }
 @Override
 public JavaElement resolved(Binding binding) {
-	SourceRefElement resolvedHandle = new ResolvedBinaryMethod(this.parent, this.name, this.parameterTypes, new String(binding.computeUniqueKey()));
+	SourceRefElement resolvedHandle = new ResolvedBinaryMethod(this.getParent(), this.name, this.parameterTypes, new String(binding.computeUniqueKey()));
 	resolvedHandle.occurrenceCount = this.occurrenceCount;
 	return resolvedHandle;
 }/*
