@@ -21,6 +21,7 @@ import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
+import java.util.List;
 import java.util.Map;
 import java.util.Objects;
 
@@ -30,6 +31,7 @@ import org.eclipse.core.resources.IWorkspace;
 import org.eclipse.core.resources.ResourcesPlugin;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IPath;
+import org.eclipse.jdt.core.IClasspathAttributeDelta;
 import org.eclipse.jdt.core.IClasspathEntry;
 import org.eclipse.jdt.core.IJavaElementDelta;
 import org.eclipse.jdt.core.IPackageFragment;
@@ -416,6 +418,7 @@ public class ClasspathChange {
 						}
 					}
 				}
+				addAttributeDeltas(delta, this.oldResolvedClasspath[i], newResolvedClasspath[index]);
 			}
 		}
 
@@ -593,4 +596,19 @@ public class ClasspathChange {
 	public String toString() {
 		return "ClasspathChange: " + this.project.getElementName(); //$NON-NLS-1$
 	}
+
+	// Include changes to the delta attributes, see: https://github.com/eclipse-jdt/eclipse.jdt.core/issues/486
+	private void addAttributeDeltas(JavaElementDelta delta, IClasspathEntry oldClasspathEntry, IClasspathEntry newClasspathEntry) {
+		List<IClasspathAttributeDelta> attributeDeltas = ClasspathAttributeDelta.getAttributeDeltas(oldClasspathEntry, newClasspathEntry);
+		if (!attributeDeltas.isEmpty()) {
+			IPackageFragmentRoot[] roots = this.project.computePackageFragmentRoots(oldClasspathEntry);
+			for (int i = 0; i < roots.length; ++i) {
+				IPackageFragmentRoot root = roots[i];
+				JavaElementDelta childDelta = delta.changed(root, IJavaElementDelta.F_CLASSPATH_ATTRIBUTES);
+				for (IClasspathAttributeDelta attributeDelta : attributeDeltas) {
+					childDelta.addAttributeDelta(attributeDelta);
+				}
+			}
+		}
+	}
 }
