@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -113,7 +113,7 @@ public class NameLookup implements SuffixConstants {
 		}
 	}
 
-	private class Selector implements IJavaElementRequestor {
+	private static class Selector implements IJavaElementRequestor {
 		public List<IPackageFragment> pkgFragments;
 
 		public Selector(String moduleName) {
@@ -180,8 +180,6 @@ public class NameLookup implements SuffixConstants {
 
 	/**
 	 * Accept flag for specifying records.
-	 * @noreference This field is not intended to be referenced by clients.
-	 * TODO Clients should add code if any special treatment is needed.
 	 */
 	public static final int ACCEPT_RECORDS = ASTNode.Bit25;
 
