@@ -11,6 +11,7 @@
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *     Stephan Herrmann - contribution for bug 337868 - [compiler][model] incomplete support for package-info.java when using SearchableEnvironment
+ *     Microsoft Corporation - contribution for bug 575562 - improve completion search performance
  *******************************************************************************/
 package org.eclipse.jdt.internal.core;
 
@@ -86,6 +87,8 @@ public class SearchableEnvironment
 	private long timeSpentInGetModulesDeclaringPackage;
 	private long timeSpentInFindTypes;
 
+	private List<IPackageFragmentRoot> unnamedModulePackageFragmentRoots;
+
 	@Deprecated
 	public SearchableEnvironment(JavaProject project, org.eclipse.jdt.core.ICompilationUnit[] workingCopies) throws JavaModelException {
 		this(project, workingCopies, false);
@@ -101,10 +104,10 @@ public class SearchableEnvironment
 			|| !JavaCore.IGNORE.equals(project.getOption(JavaCore.COMPILER_PB_DISCOURAGED_REFERENCE, true));
 		this.workingCopies = workingCopies;
 		this.nameLookup = project.newNameLookup(workingCopies, excludeTestCode);
-		if (CompilerOptions.versionToJdkLevel(project.getOption(JavaCore.COMPILER_COMPLIANCE, true)) >= ClassFileConstants.JDK9) {
+		boolean java9plus = CompilerOptions.versionToJdkLevel(project.getOption(JavaCore.COMPILER_COMPLIANCE, true)) >= ClassFileConstants.JDK9;
+		if (java9plus) {
 			this.knownModuleLocations = new HashMap<>();
-		}
-		if (CompilerOptions.versionToJdkLevel(project.getOption(JavaCore.COMPILER_COMPLIANCE, true)) >= ClassFileConstants.JDK9) {
+
 			this.moduleUpdater = new ModuleUpdater(project);
 			if (!excludeTestCode) {
 				IClasspathEntry[] expandedClasspath = project.getExpandedClasspath();
@@ -113,8 +116,18 @@ public class SearchableEnvironment
 				}
 			}
 			for (IClasspathEntry entry : project.getRawClasspath())
-				if(!excludeTestCode || !entry.isTest())
+				if(!excludeTestCode || !entry.isTest()) {
 					this.moduleUpdater.computeModuleUpdates(entry);
+				}
+
+			this.unnamedModulePackageFragmentRoots = new ArrayList<>();
+			IPackageFragmentRoot[] packageFragmentRoots = project.getAllPackageFragmentRoots();
+			for (IPackageFragmentRoot packageFragmentRoot : packageFragmentRoots) {
+				IModuleDescription moduleDescription = packageFragmentRoot.getModuleDescription();
+				if (moduleDescription == null) {
+					this.unnamedModulePackageFragmentRoots.add(packageFragmentRoot);
+				}
+			}
 		}
 	}
 
@@ -222,7 +235,7 @@ public class SearchableEnvironment
 	private String getExternalAnnotationPath(IClasspathEntry entry) {
 		if (entry == null)
 			return null;
-		IPath path = ClasspathEntry.getExternalAnnotationPath(entry, this.project.getProject(), true);
+		IPath path = entry.getExternalAnnotationPath(this.project.getProject(), true);
 		if (path == null)
 			return null;
 		return path.toOSString();
@@ -239,6 +252,7 @@ public class SearchableEnvironment
 				boolean isAnnotated = false;
 				IPackageFragment[] packageFragments = this.nameLookup.findPackageFragments(packageName, false);
 				if (packageFragments != null) {
+					String packageNameSlash = packageName.replace('.', '/');
 					for (IPackageFragment fragment : packageFragments) {
 						if (fragment.exists()) {
 							for (Object rc : fragment.getNonJavaResources()) {
@@ -250,7 +264,7 @@ public class SearchableEnvironment
 									}
 									try {
 										iBinaryType = new ExternalAnnotationDecorator(iBinaryType,
-												new ExternalAnnotationProvider(((IStorage) rc).getContents(), packageName+'/'+typeName));
+												new ExternalAnnotationProvider(((IStorage) rc).getContents(), packageNameSlash+'/'+typeName));
 										isAnnotated = true;
 										break;
 									} catch (IOException | CoreException e) {
@@ -568,6 +582,28 @@ private void findPackagesFromRequires(char[] prefix, boolean isMatchAllPrefix, I
 	 * types are found relative to their enclosing type.
 	 */
 	public void findTypes(char[] prefix, final boolean findMembers, int matchRule, int searchFor, final ISearchRequestor storage, IProgressMonitor monitor) {
+		findTypes(prefix, findMembers, matchRule, searchFor, true, storage, monitor);
+	}
+
+	/**
+	 * Must be used only by CompletionEngine.
+	 * The progress monitor is used to be able to cancel completion operations
+	 *
+	 * Find the top-level types that are defined
+	 * in the current environment and whose name starts with the
+	 * given prefix. The prefix is a qualified name separated by periods
+	 * or a simple name (ex. java.util.V or V).
+	 *
+	 * The types found are passed to one of the following methods (if additional
+	 * information is known about the types):
+	 *    ISearchRequestor.acceptType(char[][] packageName, char[] typeName)
+	 *    ISearchRequestor.acceptClass(char[][] packageName, char[] typeName, int modifiers)
+	 *    ISearchRequestor.acceptInterface(char[][] packageName, char[] typeName, int modifiers)
+	 *
+	 * This method can not be used to find member types... member
+	 * types are found relative to their enclosing type.
+	 */
+	public void findTypes(char[] prefix, final boolean findMembers, int matchRule, int searchFor, final boolean resolveDocumentName, final ISearchRequestor storage, IProgressMonitor monitor) {
 		long start = -1;
 		if (NameLookup.VERBOSE)
 			start = System.currentTimeMillis();
@@ -671,6 +707,7 @@ private void findPackagesFromRequires(char[] prefix, boolean isMatchAllPrefix, I
 						matchRule, // not case sensitive
 						searchFor,
 						getSearchScope(),
+						resolveDocumentName,
 						typeRequestor,
 						FORCE_IMMEDIATE_SEARCH,
 						progressMonitor);
@@ -693,6 +730,7 @@ private void findPackagesFromRequires(char[] prefix, boolean isMatchAllPrefix, I
 							matchRule,
 							searchFor,
 							getSearchScope(),
+							resolveDocumentName,
 							typeRequestor,
 							FORCE_IMMEDIATE_SEARCH,
 							progressMonitor);
@@ -713,6 +751,7 @@ private void findPackagesFromRequires(char[] prefix, boolean isMatchAllPrefix, I
 						matchRule, // not case sensitive
 						searchFor,
 						getSearchScope(),
+						resolveDocumentName,
 						typeRequestor,
 						CANCEL_IF_NOT_READY_TO_SEARCH,
 						progressMonitor);
@@ -746,7 +785,7 @@ private void findPackagesFromRequires(char[] prefix, boolean isMatchAllPrefix, I
 	 * The constructors found are passed to one of the following methods:
 	 *    ISearchRequestor.acceptConstructor(...)
 	 */
-	public void findConstructorDeclarations(char[] prefix, int matchRule, final ISearchRequestor storage, IProgressMonitor monitor) {
+	public void findConstructorDeclarations(char[] prefix, int matchRule, final boolean resolveDocumentName, final ISearchRequestor storage, IProgressMonitor monitor) {
 		try {
 			final String excludePath;
 			if (this.unitToSkip != null && this.unitToSkip instanceof IJavaElement) {
@@ -879,6 +918,7 @@ private void findPackagesFromRequires(char[] prefix, boolean isMatchAllPrefix, I
 						simpleName,
 						matchRule,
 						getSearchScope(),
+						resolveDocumentName,
 						constructorRequestor,
 						FORCE_IMMEDIATE_SEARCH,
 						progressMonitor);
@@ -889,6 +929,7 @@ private void findPackagesFromRequires(char[] prefix, boolean isMatchAllPrefix, I
 							simpleName,
 							matchRule,
 							getSearchScope(),
+							resolveDocumentName,
 							constructorRequestor,
 							CANCEL_IF_NOT_READY_TO_SEARCH,
 							progressMonitor);
@@ -997,6 +1038,16 @@ private void findPackagesFromRequires(char[] prefix, boolean isMatchAllPrefix, I
 								}
 							}
 						}
+						/*
+						 * Check if we have a sub-package in the unnamed module,
+						 * since classpath filters can result in top level packages
+						 * not listed by nameLookup.findPackageFragementRoots().
+						 * See: https://github.com/eclipse-jdt/eclipse.jdt.core/issues/485
+						 * and https://github.com/eclipse-jdt/eclipse.jdt.core/issues/646
+						 */
+						if (!containsUnnamed && hasSubPackageInUnnamedModule(pkgName)) {
+							names = CharOperation.arrayConcat(names, ModuleBinding.UNNAMED);
+						}
 					}
 					return names == CharOperation.NO_CHAR_CHAR ? null : names;
 				default:
@@ -1240,4 +1291,25 @@ private void findPackagesFromRequires(char[] prefix, boolean isMatchAllPrefix, I
 
 		this.nameLookup.printTimeSpent();
 	}
+
+	private boolean hasSubPackageInUnnamedModule(String[] pkgName) {
+		List<IPackageFragmentRoot> packageFragmentRoots = this.unnamedModulePackageFragmentRoots;
+		if (packageFragmentRoots != null) {
+			String name = String.join(".", pkgName); //$NON-NLS-1$
+			for (IPackageFragmentRoot packageFragmentRoot : packageFragmentRoots) {
+				try {
+					IJavaElement[] children = packageFragmentRoot.getChildren();
+					for (IJavaElement child : children) {
+						String childName = child.getElementName();
+						if (childName.startsWith(name)) {
+							return true;
+						}
+					}
+				} catch (JavaModelException e) {
+					Util.log(e, "Failed to retrieve children for " + packageFragmentRoot); //$NON-NLS-1$
+				}
+			}
+		}
+		return false;
+	}
 }
