@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2021 IBM Corporation and others.
+ * Copyright (c) 2000, 2023 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -10,6 +10,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     Christoph Läubrich -  Enhance the BuildContext with the discovered annotations #674
  *******************************************************************************/
 package org.eclipse.jdt.internal.core.builder;
 
@@ -23,6 +24,7 @@ import org.eclipse.jdt.internal.compiler.Compiler;
 import org.eclipse.jdt.internal.compiler.classfmt.ClassFileConstants;
 import org.eclipse.jdt.internal.compiler.env.ICompilationUnit;
 import org.eclipse.jdt.internal.compiler.impl.CompilerOptions;
+import org.eclipse.jdt.internal.compiler.lookup.AnnotationBinding;
 import org.eclipse.jdt.internal.compiler.lookup.TypeConstants;
 import org.eclipse.jdt.internal.compiler.problem.*;
 import org.eclipse.jdt.internal.compiler.util.SimpleSet;
@@ -60,7 +62,7 @@ protected boolean compiledAllAtOnce;
 private boolean inCompiler;
 
 protected boolean keepStoringProblemMarkers;
-protected Set<SourceFile> filesWithAnnotations = null;
+protected Map<SourceFile, AnnotationBinding[]> filesWithAnnotations = null;
 
 //2000 is best compromise between space used and speed
 public static int MAX_AT_ONCE = Integer.getInteger(JavaModelManager.MAX_COMPILED_UNITS_AT_ONCE, 2000).intValue();
@@ -104,7 +106,7 @@ protected AbstractImageBuilder(JavaBuilder javaBuilder, boolean buildStarting, S
 					// initialize this set so the builder knows to gather CUs that define Annotation types
 					// each Annotation processor participant is then asked to process these files AFTER
 					// the compile loop. The normal dependency loop will then recompile all affected types
-					this.filesWithAnnotations = new HashSet<>(1);
+					this.filesWithAnnotations = new HashMap<>(1);
 					break;
 				}
 			}
@@ -150,6 +152,7 @@ public void acceptResult(CompilationResult result) {
 		int length = classFiles.length;
 		ArrayList duplicateTypeNames = null;
 		ArrayList definedTypeNames = new ArrayList(length);
+		ArrayList<CompilationParticipantResult> postProcessingResults = new ArrayList<>();
 		for (int i = 0; i < length; i++) {
 			ClassFile classFile = classFiles[i];
 
@@ -183,13 +186,31 @@ public void acceptResult(CompilationResult result) {
 						String simpleName = qualifiedTypeName.substring(qualifiedTypeName.lastIndexOf('/')+1);
 						type = mainType == null ? null : mainType.getCompilationUnit().getType(simpleName);
 					}
-					createProblemFor(compilationUnit.resource, type, Messages.bind(Messages.build_duplicateClassFile, new String(typeName)), JavaCore.ERROR);
+					if(TypeConstants.MODULE_INFO_NAME_STRING.equals(qualifiedTypeName)) {
+						createProblemFor(compilationUnit.resource, type, Messages.build_duplicateModuleInfo, JavaCore.ERROR);
+					} else {
+						createProblemFor(compilationUnit.resource, type, Messages.bind(Messages.build_duplicateClassFile, new String(typeName)), JavaCore.ERROR);
+					}
 					continue;
 				}
 				this.newState.recordLocatorForType(qualifiedTypeName, typeLocator);
 				if (result.checkSecondaryTypes && !qualifiedTypeName.equals(compilationUnit.initialTypeName))
 					acceptSecondaryType(classFile);
 			}
+			for (int j = 0, l = this.javaBuilder.participants == null ? 0 : this.javaBuilder.participants.length; j < l; j++) {
+				CompilationParticipant compilationParticipant = this.javaBuilder.participants[j];
+				if (!compilationParticipant.isPostProcessor()) {
+					continue;
+				}
+				CompilationParticipantResult buildContext = new CompilationParticipantResult(compilationUnit,
+						this.compilationGroup == CompilationGroup.TEST);
+				Optional<byte[]> postProcessingResult = compilationParticipant.postProcess(buildContext,
+						new ByteArrayInputStream(classFile.getBytes()));
+				postProcessingResults.add(buildContext);
+				if (postProcessingResult.isPresent()) {
+					classFile.internalSetBytes(postProcessingResult.get());
+				}
+			}
 			try {
 				definedTypeNames.add(writeClassFile(classFile, compilationUnit, !isNestedType));
 			} catch (CoreException e) {
@@ -200,11 +221,17 @@ public void acceptResult(CompilationResult result) {
 					createProblemFor(compilationUnit.resource, null, Messages.build_inconsistentClassFile, JavaCore.ERROR);
 			}
 		}
-		if (result.hasAnnotations && this.filesWithAnnotations != null) // only initialized if an annotation processor is attached
-			this.filesWithAnnotations.add(compilationUnit);
+		if (result.hasAnnotations && this.filesWithAnnotations != null) {
+			// only initialized if an annotation processor is attached
+			AnnotationBinding[] bindings = result.annotations.stream().flatMap(Arrays::stream).filter(Objects::nonNull).toArray(AnnotationBinding[]::new);
+			this.filesWithAnnotations.put(compilationUnit, bindings);
+		}
 
 		this.compiler.lookupEnvironment.releaseClassFiles(classFiles);
 		finishedWith(typeLocator, result, compilationUnit.getMainTypeName(), definedTypeNames, duplicateTypeNames);
+		for (CompilationParticipantResult postProcessingResult : postProcessingResults) {
+			recordParticipantResult(postProcessingResult); // depends on new compiler state which was just recorded
+		}
 		this.notifier.compiled(compilationUnit);
 	}
 }
@@ -414,7 +441,9 @@ protected void createProblemFor(IResource resource, IMember javaElement, String
 				if (e.getJavaModelStatus().getCode() != IJavaModelStatusConstants.ELEMENT_DOES_NOT_EXIST) {
 					throw e;
 				}
-				if (!CharOperation.equals(javaElement.getElementName().toCharArray(), TypeConstants.PACKAGE_INFO_NAME)) {
+				char[] elementName = javaElement.getElementName().toCharArray();
+				if (!CharOperation.equals(elementName, TypeConstants.PACKAGE_INFO_NAME)
+						&& !CharOperation.equals(elementName, TypeConstants.MODULE_INFO_NAME)) {
 					throw e;
 				}
 				// else silently swallow the exception as the synthetic interface type package-info has no
@@ -629,8 +658,9 @@ protected void processAnnotations(CompilationParticipantResult[] results) {
 	if (!hasAnnotationProcessor) return;
 
 	boolean foundAnnotations = this.filesWithAnnotations != null && this.filesWithAnnotations.size() > 0;
-	for (int i = results.length; --i >= 0;)
-		results[i].reset(foundAnnotations && this.filesWithAnnotations.contains(results[i].sourceFile));
+	for (int i = results.length; --i >= 0;) {
+		results[i].reset(foundAnnotations ? this.filesWithAnnotations.get(results[i].sourceFile) : null);
+	}
 
 	// even if no files have annotations, must still tell every annotation processor in case the file used to have them
 	for (int i = 0, l = this.javaBuilder.participants.length; i < l; i++)
