@@ -18,6 +18,7 @@ package org.eclipse.jdt.internal.core.builder;
 import java.io.IOException;
 import java.util.Collection;
 import java.util.HashSet;
+import java.io.File;
 import java.util.List;
 import java.util.Objects;
 import java.util.Set;
@@ -29,6 +30,9 @@ import org.eclipse.core.resources.IContainer;
 import org.eclipse.core.resources.IFile;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IPath;
+import org.eclipse.core.runtime.IStatus;
+import org.eclipse.core.runtime.Status;
+import org.eclipse.jdt.core.JavaCore;
 import org.eclipse.jdt.core.compiler.CharOperation;
 import org.eclipse.jdt.internal.compiler.classfmt.ClassFileConstants;
 import org.eclipse.jdt.internal.compiler.classfmt.ExternalAnnotationDecorator;
@@ -41,6 +45,7 @@ import org.eclipse.jdt.internal.compiler.env.IUpdatableModule.UpdateKind;
 import org.eclipse.jdt.internal.compiler.impl.CompilerOptions;
 import org.eclipse.jdt.internal.compiler.lookup.ModuleBinding;
 import org.eclipse.jdt.internal.compiler.lookup.BinaryTypeBinding.ExternalAnnotationStatus;
+import org.eclipse.jdt.internal.compiler.util.JRTUtil;
 import org.eclipse.jdt.internal.compiler.util.Util;
 
 public abstract class ClasspathLocation {
@@ -50,9 +55,10 @@ public abstract class ClasspathLocation {
 	protected Set<String> limitModuleNames = null;
 	protected String patchModuleName = null;
 	protected String externalAnnotationPath;
-	protected Collection<ClasspathLocation> allLocationsForEEA; // when configured to search all classpath locations for external annotations (eea) this is where to look
+	private Collection<ClasspathLocation> allLocationsForEEA; // when configured to search all classpath locations for external annotations (eea) this is where to look
 	protected ZipFile annotationZipFile;
 	protected AccessRuleSet accessRuleSet;
+
 	// In the following signatures, passing a null moduleName signals "don't care":
 	abstract public NameEnvironmentAnswer findClass(String typeName, String qualifiedPackageName, String moduleName, String qualifiedBinaryFileName);
 	abstract public NameEnvironmentAnswer findClass(String typeName, String qualifiedPackageName, String moduleName, String qualifiedBinaryFileName,
@@ -132,13 +138,11 @@ public abstract class ClasspathLocation {
 		return true;
 	}
 	static ClasspathLocation forSourceFolder(IContainer sourceFolder, IContainer outputFolder,
-			char[][] inclusionPatterns, char[][] exclusionPatterns, boolean ignoreOptionalProblems, IPath externalAnnotationPath, List<ClasspathLocation> allExternalAnnotationPaths) {
-		return new ClasspathMultiDirectory(sourceFolder, outputFolder, inclusionPatterns, exclusionPatterns, ignoreOptionalProblems,
-				externalAnnotationPath, allExternalAnnotationPaths);
+			char[][] inclusionPatterns, char[][] exclusionPatterns, boolean ignoreOptionalProblems, IPath externalAnnotationPath) {
+		return new ClasspathMultiDirectory(sourceFolder, outputFolder, inclusionPatterns, exclusionPatterns, ignoreOptionalProblems, externalAnnotationPath);
 	}
-public static ClasspathLocation forBinaryFolder(IContainer binaryFolder, boolean isOutputFolder, AccessRuleSet accessRuleSet,
-		IPath externalAnnotationPath, Collection<ClasspathLocation> allExternalAnnotationPaths, boolean autoModule) {
-	return new ClasspathDirectory(binaryFolder, isOutputFolder, accessRuleSet, externalAnnotationPath, allExternalAnnotationPaths, autoModule);
+public static ClasspathLocation forBinaryFolder(IContainer binaryFolder, boolean isOutputFolder, AccessRuleSet accessRuleSet, IPath externalAnnotationPath, boolean autoModule) {
+	return new ClasspathDirectory(binaryFolder, isOutputFolder, accessRuleSet, externalAnnotationPath, autoModule);
 }
 
 static ClasspathLocation forLibrary(String libraryPathname,
@@ -154,13 +158,23 @@ static ClasspathLocation forLibrary(String libraryPathname,
 				new ClasspathMultiReleaseJar(libraryPathname, lastModified, accessRuleSet, annotationsPath, isOnModulePath, compliance));
 
 }
+
 public static ClasspathJrt forJrtSystem(String jrtPath, AccessRuleSet accessRuleSet, IPath annotationsPath, String release) throws CoreException {
-	return forJrtSystem(jrtPath, accessRuleSet, annotationsPath, null, release);
-}
-public static ClasspathJrt forJrtSystem(String jrtPath, AccessRuleSet accessRuleSet,
-		IPath annotationsPath, Collection<ClasspathLocation> allLocationsForEEA, String release) throws CoreException {
-	return (release == null || release.equals("")) ? new ClasspathJrt(jrtPath, accessRuleSet, annotationsPath, allLocationsForEEA) : //$NON-NLS-1$
-						new ClasspathJrtWithReleaseOption(jrtPath, accessRuleSet, annotationsPath, allLocationsForEEA, release);
+	boolean useRelease = release != null && !release.isEmpty();
+	if(useRelease) {
+		String jrtVersion;
+		try {
+			jrtVersion = JRTUtil.getJdkRelease(new File(jrtPath));
+		} catch (IOException e) {
+			throw new CoreException(new Status(IStatus.ERROR, ClasspathLocation.class, "Failed to detect JDK release for: " + jrtPath, e)); //$NON-NLS-1$
+		}
+		boolean sameRelease = JavaCore.compareJavaVersions(jrtVersion, release) == 0;
+		if(sameRelease) {
+			useRelease = false;
+		}
+	}
+	return useRelease ? new ClasspathJrtWithReleaseOption(jrtPath, accessRuleSet, annotationsPath, release)
+			: new ClasspathJrt(jrtPath, accessRuleSet, annotationsPath);
 }
 
 public static ClasspathLocation forLibrary(String libraryPathname, AccessRuleSet accessRuleSet, IPath annotationsPath,
@@ -168,17 +182,16 @@ public static ClasspathLocation forLibrary(String libraryPathname, AccessRuleSet
 	return forLibrary(libraryPathname, 0, accessRuleSet, annotationsPath, isOnModulePath, compliance);
 }
 
-public static ClasspathLocation forLibrary(IFile library, AccessRuleSet accessRuleSet, IPath annotationsPath, Collection<ClasspathLocation> allLocationsForEEA,
+public static ClasspathLocation forLibrary(IFile library, AccessRuleSet accessRuleSet, IPath annotationsPath,
 										boolean isOnModulePath, String compliance) {
 	return (CompilerOptions.versionToJdkLevel(compliance) < ClassFileConstants.JDK9) ?
-			new ClasspathJar(library, accessRuleSet, annotationsPath, allLocationsForEEA, isOnModulePath) :
-				new ClasspathMultiReleaseJar(library, accessRuleSet, annotationsPath, allLocationsForEEA, isOnModulePath, compliance);
+			new ClasspathJar(library, accessRuleSet, annotationsPath, isOnModulePath) :
+				new ClasspathMultiReleaseJar(library, accessRuleSet, annotationsPath, isOnModulePath, compliance);
 }
-public static ClasspathLocation forLibrary(ZipFile zipFile, AccessRuleSet accessRuleSet, IPath externalAnnotationPath, Collection<ClasspathLocation> allLocationsForEEA,
-										boolean isOnModulePath, String compliance) {
+public static ClasspathLocation forLibrary(ZipFile zipFile, AccessRuleSet accessRuleSet, boolean isOnModulePath, String compliance) {
 	return (CompilerOptions.versionToJdkLevel(compliance) < ClassFileConstants.JDK9) ?
-			new ClasspathJar(zipFile, accessRuleSet, externalAnnotationPath, isOnModulePath) :
-				new ClasspathMultiReleaseJar(zipFile, accessRuleSet, externalAnnotationPath, isOnModulePath, compliance);
+			new ClasspathJar(zipFile, accessRuleSet, isOnModulePath) :
+				new ClasspathMultiReleaseJar(zipFile, accessRuleSet, isOnModulePath, compliance);
 }
 
 public abstract IPath getProjectRelativePath();
@@ -250,6 +263,11 @@ protected NameEnvironmentAnswer createAnswer(String fileNameWithoutExtension, IB
 			this.accessRuleSet.getViolatedRestriction(fileNameWithoutExtension.toCharArray()),
 			moduleName);
 }
+public void connectAllLocationsForEEA(Collection<ClasspathLocation> allLocations, boolean add) {
+	this.allLocationsForEEA = allLocations; // shared within the project, may be updated after setting
+	if (add)
+		allLocations.add(this);
+}
 /** NOTE: this method is intended for TESTS only */
 public boolean externalAnnotationsEquals(ClasspathLocation other) {
 	String path1 = this.externalAnnotationPath;
