@@ -107,6 +107,7 @@ public final class Messages extends NLS {
 	public static String build_serializationError;
 	public static String build_classFileCollision;
 	public static String build_duplicateClassFile;
+	public static String build_duplicateModuleInfo;
 	public static String build_duplicateResource;
 	public static String build_inconsistentClassFile;
 	public static String build_inconsistentProject;
@@ -194,6 +195,7 @@ public final class Messages extends NLS {
 	public static String classpath_testSourceRequiresSeparateOutputFolder;
 	public static String classpath_testOutputFolderMustBeSeparateFromMainOutputFolders;
 	public static String classpath_main_only_project_depends_on_test_only_project;
+	public static String classpath_illegalAddExportsSystemModule;
 	public static String file_notFound;
 	public static String file_badFormat;
 	public static String path_nullPath;
