@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -11,6 +11,7 @@
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *     Stephan Herrmann - Contributions for bug 215139 and bug 295894
+ *     Microsoft Corporation - Contribution for bug 575562 - improve completion search performance
  *******************************************************************************/
 package org.eclipse.jdt.internal.core.search;
 
@@ -601,11 +602,38 @@ public class BasicSearchEngine {
 		findMatches(pattern, participants, scope, requestor, monitor);
 	}
 
+	public void searchAllConstructorDeclarations(
+			final char[] packageName,
+			final char[] typeName,
+			final int typeMatchRule,
+			IJavaSearchScope scope,
+			final IRestrictedAccessConstructorRequestor nameRequestor,
+			int waitingPolicy,
+			IProgressMonitor progressMonitor)  throws JavaModelException {
+		searchAllConstructorDeclarations(
+				packageName,
+				typeName,
+				typeMatchRule,
+				scope,
+				true,
+				nameRequestor,
+				waitingPolicy,
+				progressMonitor);
+	}
+
+	/**
+	 *
+	 * Searches for constructor declarations in the given scope.
+	 *
+	 * @param resolveDocumentName used to tell SearchEngine whether to resolve
+	 *                            the document name for each result entry.
+	 */
 	public void searchAllConstructorDeclarations(
 		final char[] packageName,
 		final char[] typeName,
 		final int typeMatchRule,
 		IJavaSearchScope scope,
+		final boolean resolveDocumentName,
 		final IRestrictedAccessConstructorRequestor nameRequestor,
 		int waitingPolicy,
 		IProgressMonitor progressMonitor)  throws JavaModelException {
@@ -728,6 +756,8 @@ public class BasicSearchEngine {
 					pattern,
 					getDefaultSearchParticipant(), // Java search only
 					scope,
+					resolveDocumentName,
+					true,
 					searchRequestor),
 				waitingPolicy,
 				subMonitor.split(Math.max(1000-copiesLength, 0)));
@@ -1708,6 +1738,40 @@ public class BasicSearchEngine {
 	 * @see SearchEngine#searchAllTypeNames(char[], int, char[], int, int, IJavaSearchScope, TypeNameRequestor, int, IProgressMonitor)
 	 * 	for detailed comment
 	 */
+	public void searchAllTypeNames(
+			final char[] packageName,
+			final int packageMatchRule,
+			final char[] typeName,
+			final int typeMatchRule,
+			int searchFor,
+			IJavaSearchScope scope,
+			final IRestrictedAccessTypeRequestor nameRequestor,
+			int waitingPolicy,
+			IProgressMonitor progressMonitor)  throws JavaModelException {
+		searchAllTypeNames(
+				packageName,
+				packageMatchRule,
+				typeName,
+				typeMatchRule,
+				searchFor,
+				scope,
+				true,
+				nameRequestor,
+				waitingPolicy,
+				progressMonitor);
+	}
+
+	/**
+	 * Searches for all top-level types and member types in the given scope.
+	 * The search can be selecting specific types (given a package or a type name
+	 * prefix and match modes).
+	 *
+	 * @param resolveDocumentName used to tell SearchEngine whether to resolve
+	 *                            the document name for each result entry.
+	 *
+	 * @see SearchEngine#searchAllTypeNames(char[], int, char[], int, int, IJavaSearchScope, TypeNameRequestor, int, IProgressMonitor)
+	 * 	for detailed comment
+	 */
 	public void searchAllTypeNames(
 		final char[] packageName,
 		final int packageMatchRule,
@@ -1715,6 +1779,7 @@ public class BasicSearchEngine {
 		final int typeMatchRule,
 		int searchFor,
 		IJavaSearchScope scope,
+		final boolean resolveDocumentName,
 		final IRestrictedAccessTypeRequestor nameRequestor,
 		int waitingPolicy,
 		IProgressMonitor progressMonitor)  throws JavaModelException {
@@ -1853,12 +1918,15 @@ public class BasicSearchEngine {
 			};
 
 			SubMonitor subMonitor = SubMonitor.convert(progressMonitor, Messages.engine_searching, 1000);
+
 			// add type names from indexes
 			indexManager.performConcurrentJob(
 				new PatternSearchJob(
 					pattern,
 					getDefaultSearchParticipant(), // Java search only
 					scope,
+					resolveDocumentName,
+					true,
 					searchRequestor),
 				waitingPolicy,
 				subMonitor.split(Math.max(1000-copiesLength, 0)));
