@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,8 +13,11 @@
  *******************************************************************************/
 package org.eclipse.jdt.internal.core.search.indexing;
 
+import java.io.File;
+
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.Status;
+import org.eclipse.jdt.core.Flags;
 import org.eclipse.jdt.core.JavaCore;
 import org.eclipse.jdt.core.Signature;
 import org.eclipse.jdt.core.compiler.CharOperation;
@@ -161,6 +164,13 @@ public class BinaryIndexer extends AbstractIndexer implements SuffixConstants {
 			}
 			addFieldReference(TypeConstants.UPPER_MODULE);
 		}
+		if ((bits & TagBits.AnnotationForRecordComponent) != 0) {
+			if (compoundName == null) {
+				compoundName = TypeConstants.JAVA_LANG_ANNOTATION_ELEMENTTYPE;
+				addTypeReference(compoundName[compoundName.length-1]);
+			}
+			addFieldReference(TypeConstants.UPPER_RECORD_COMPONENT);
+		}
 	}
 	private void addBinaryRetentionAnnotation(long bits) {
 		char[][] compoundName = TypeConstants.JAVA_LANG_ANNOTATION_RETENTIONPOLICY;
@@ -500,6 +510,9 @@ public class BinaryIndexer extends AbstractIndexer implements SuffixConstants {
 		return null;
 	}
 	private int extractArgCount(char[] signature, char[] className) throws ClassFormatException {
+		return extractArgCount(signature, className, false);
+	}
+	private int extractArgCount(char[] signature, char[] className, boolean isStaticTypeConstructor) throws ClassFormatException {
 		int indexOfClosingParen = CharOperation.lastIndexOf(')', signature);
 		if (indexOfClosingParen == 1) {
 			// there is no parameter
@@ -525,7 +538,7 @@ public class BinaryIndexer extends AbstractIndexer implements SuffixConstants {
 					int indexOfSemiColon = CharOperation.indexOf(';', signature, i+1);
 					if (indexOfSemiColon == -1) throw new ClassFormatException(ClassFormatException.ErrInvalidMethodSignature);
 					// verify if first parameter is synthetic
-					if (className != null && parameterTypesCounter == 0) {
+					if (className != null && parameterTypesCounter == 0 && !isStaticTypeConstructor) {
 						char[] classSignature = Signature.createCharArrayTypeSignature(className, true);
 						int length = indexOfSemiColon-i+1;
 						if (classSignature.length > (length+1)) {
@@ -599,6 +612,7 @@ public class BinaryIndexer extends AbstractIndexer implements SuffixConstants {
 					if (CharOperation.equals(INIT, name)) {
 						// get class name and see if it's a local type or not
 						char[] className = extractClassName(constantPoolOffsets, reader, i);
+						boolean isStaticType = reader.isStaticInner(className);
 						boolean localType = false;
 						if (className !=  null) {
 							for (int c = 0, max = className.length; c < max; c++) {
@@ -613,7 +627,7 @@ public class BinaryIndexer extends AbstractIndexer implements SuffixConstants {
 							}
 						}
 						// add a constructor reference, use class name to extract arg count if it's a local type to remove synthetic parameter
-						addConstructorReference(className, extractArgCount(type, localType?className:null));
+						addConstructorReference(className, extractArgCount(type, localType?className:null, isStaticType));
 					} else {
 						// add a method reference
 						addMethodReference(name, extractArgCount(type, null));
@@ -649,8 +663,8 @@ public class BinaryIndexer extends AbstractIndexer implements SuffixConstants {
 			// contents can potentially be null if a IOException occurs while retrieving the contents
 			if (contents == null) return;
 			final String path = this.document.getPath();
-			ClassFileReader reader = new ClassFileReader(contents, path == null ? null : path.toCharArray());
-			
+			ClassFileReader reader = new ClassFileReader((new File(path)).toURI(), contents, path == null ? null : path.toCharArray());
+
 			IModule module = reader.getModuleDeclaration();
 			if (module != null) {
 				indexModule(module);
@@ -721,6 +735,10 @@ public class BinaryIndexer extends AbstractIndexer implements SuffixConstants {
 				case TypeDeclaration.ANNOTATION_TYPE_DECL :
 					addAnnotationTypeDeclaration(modifiers, packageName, name, enclosingTypeNames, false);
 					break;
+				case TypeDeclaration.RECORD_DECL :
+					superclass = replace('/', '.', reader.getSuperclassName());
+					addClassDeclaration(modifiers, packageName, name, enclosingTypeNames, superclass, superinterfaces, typeParameterSignatures, false);
+					break;
 			}
 
 			// Look for references in class annotations
@@ -735,7 +753,7 @@ public class BinaryIndexer extends AbstractIndexer implements SuffixConstants {
 			if (tagBits != 0) {
 				addBinaryStandardAnnotations(tagBits);
 			}
-			
+
 			int extraFlags = ExtraFlags.getExtraFlags(reader);
 
 			// first reference all methods declarations and field declarations
@@ -746,14 +764,15 @@ public class BinaryIndexer extends AbstractIndexer implements SuffixConstants {
 					MethodInfo method = methods[i];
 					boolean isConstructor = method.isConstructor();
 					char[] descriptor = method.getMethodDescriptor();
-					char[][] parameterTypes = decodeParameterTypes(descriptor, isConstructor && isNestedType);
+					boolean isStatic = Flags.isStatic(reader.getModifiers());
+					char[][] parameterTypes = decodeParameterTypes(descriptor, isConstructor && isNestedType && !isStatic);
 					char[] returnType = decodeReturnType(descriptor);
 					char[][] exceptionTypes = replace('/', '.', method.getExceptionTypeNames());
 					if (isConstructor) {
 						noConstructor = false;
 						char[] signature = method.getGenericSignature();
 						if (signature == null) {
-							if (reader.isNestedType() && ((modifiers & ClassFileConstants.AccStatic) == 0)) {
+							if (reader.isNestedType() && !isStatic) {
 								signature = removeFirstSyntheticParameter(descriptor);
 							} else {
 								signature = descriptor;
@@ -762,7 +781,7 @@ public class BinaryIndexer extends AbstractIndexer implements SuffixConstants {
 						addConstructorDeclaration(
 								name,
 								parameterTypes == null ? 0 : parameterTypes.length,
-								signature,	
+								signature,
 								parameterTypes,
 								method.getArgumentNames(),
 								method.getModifiers(),
@@ -784,7 +803,7 @@ public class BinaryIndexer extends AbstractIndexer implements SuffixConstants {
 										null,
 										selector,
 										parameterTypes == null ? 0 : parameterTypes.length,
-												signature,	
+												signature,
 												parameterTypes,
 												method.getArgumentNames(),
 												returnType,
@@ -836,14 +855,7 @@ public class BinaryIndexer extends AbstractIndexer implements SuffixConstants {
 			}
 			// record all references found inside the .class file
 			extractReferenceFromConstantPool(contents, reader);
-		} catch (ClassFormatException e) {
-			// ignore
-			this.document.removeAllIndexEntries();
-			Util.log(new Status(IStatus.WARNING,
-					JavaCore.PLUGIN_ID,
-					"The Java indexing could not index " + this.document.getPath() + ". This .class file doesn't follow the class file format specification. Please report this issue against the .class file vendor", //$NON-NLS-1$ //$NON-NLS-2$
-					e));
-		} catch (RuntimeException e) {
+		} catch (ClassFormatException | RuntimeException e) {
 			// https://bugs.eclipse.org/bugs/show_bug.cgi?id=182154
 			// logging the entry that could not be indexed and continue with the next one
 			// we remove all entries relative to the boggus document
@@ -854,7 +866,7 @@ public class BinaryIndexer extends AbstractIndexer implements SuffixConstants {
 					e));
 		}
 	}
-	
+
 	private void indexModule(IModule module) {
 		addModuleDeclaration(module.name());
 		IModuleReference[] requiredModules = module.requires();
@@ -904,7 +916,7 @@ public class BinaryIndexer extends AbstractIndexer implements SuffixConstants {
 			return;
 		addTypeReference(ref);
 	}
-	
+
 	private char[] removeFirstSyntheticParameter(char[] descriptor) {
 		if (descriptor == null) return null;
 		if (descriptor.length < 3) return descriptor;
