@@ -149,6 +149,7 @@ public void acceptUnknownReference(char[][] name, int sourceStart, int sourceEnd
 @Override
 public void acceptUnknownReference(char[] name, int sourcePosition) {
 	this.indexer.addNameReference(name);
+	this.indexer.addIndexMetaQualification(name, false);
 }
 
 private void addDefaultConstructorIfNecessary(TypeInfo typeInfo) {
@@ -456,13 +457,7 @@ public void exitConstructor(int declarationEnd) {
 public void exitField(int initializationStart, int declarationEnd, int declarationSourceEnd) {
 	this.methodDepth--;
 }
-/**
- * @see ISourceElementRequestor#exitRecordComponent(int, int)
- */
-@Override
-public void exitRecordComponent(int declarationEnd, int declarationSourceEnd) {
-	//Nothing by default
-}
+
 /**
  * @see ISourceElementRequestor#exitInitializer(int)
  */
