@@ -17,7 +17,9 @@ import static java.util.stream.Collectors.joining;
 
 import java.util.Collections;
 import java.util.HashMap;
+import java.util.Iterator;
 import java.util.LinkedHashSet;
+import java.util.List;
 import java.util.Map;
 import java.util.Optional;
 import java.util.Set;
@@ -26,6 +28,7 @@ import java.util.stream.Collectors;
 import org.eclipse.core.resources.IContainer;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IPath;
+import org.eclipse.jdt.core.IClasspathEntry;
 import org.eclipse.jdt.core.IJavaElement;
 import org.eclipse.jdt.core.IJavaProject;
 import org.eclipse.jdt.core.IModuleDescription;
@@ -39,6 +42,7 @@ import org.eclipse.jdt.internal.compiler.classfmt.ClassFileConstants;
 import org.eclipse.jdt.internal.compiler.env.ICompilationUnit;
 import org.eclipse.jdt.internal.compiler.env.IModule;
 import org.eclipse.jdt.internal.compiler.env.IModuleAwareNameEnvironment;
+import org.eclipse.jdt.internal.compiler.env.INameEnvironment;
 import org.eclipse.jdt.internal.compiler.env.NameEnvironmentAnswer;
 import org.eclipse.jdt.internal.compiler.impl.CompilerOptions;
 import org.eclipse.jdt.internal.compiler.util.SuffixConstants;
@@ -158,6 +162,10 @@ public void cleanup() {
 }
 
 protected /* visible for testing only */ void addProjectClassPath(JavaProject javaProject) {
+	addProjectClassPath(javaProject, false);
+}
+
+void addProjectClassPath(JavaProject javaProject, boolean onlyExported) {
 	long start = 0;
 	if (NameLookup.VERBOSE) {
 		Util.verbose(" EXTENDING JavaSearchNameEnvironment");  //$NON-NLS-1$
@@ -165,7 +173,7 @@ protected /* visible for testing only */ void addProjectClassPath(JavaProject ja
 		start = System.currentTimeMillis();
 	}
 
-	LinkedHashSet<ClasspathLocation> locations = computeClasspathLocations(javaProject);
+	LinkedHashSet<ClasspathLocation> locations = computeClasspathLocations(javaProject, onlyExported);
 	if (locations != null) this.locationSet.addAll(locations);
 
     if (NameLookup.VERBOSE) {
@@ -176,6 +184,10 @@ protected /* visible for testing only */ void addProjectClassPath(JavaProject ja
 }
 
 private LinkedHashSet<ClasspathLocation> computeClasspathLocations(JavaProject javaProject) {
+	return computeClasspathLocations(javaProject, false);
+}
+
+private LinkedHashSet<ClasspathLocation> computeClasspathLocations(JavaProject javaProject, boolean onlyExported) {
 
 	IPackageFragmentRoot[] roots = null;
 	try {
@@ -183,9 +195,9 @@ private LinkedHashSet<ClasspathLocation> computeClasspathLocations(JavaProject j
 	} catch (JavaModelException e) {
 		return null;// project doesn't exist
 	}
-	IModuleDescription imd = null;
+	IModuleDescription projectModule = null;
 	try {
-		imd = javaProject.getModuleDescription();
+		projectModule = javaProject.getModuleDescription();
 	} catch (JavaModelException e) {
 		// e.printStackTrace(); // ignore
 	}
@@ -194,7 +206,11 @@ private LinkedHashSet<ClasspathLocation> computeClasspathLocations(JavaProject j
 	int length = roots.length;
 	JavaModelManager manager = JavaModelManager.getJavaModelManager();
 	for (int i = 0; i < length; i++) {
-		ClasspathLocation cp = mapToClassPathLocation(manager, (PackageFragmentRoot) roots[i], imd);
+		PackageFragmentRoot root = (PackageFragmentRoot) roots[i];
+		if (onlyExported && !isSourceOrExported(root)) {
+			continue;
+		}
+		ClasspathLocation cp = mapToClassPathLocation(manager, root, projectModule);
 		if (cp != null) {
 			try {
 				indexPackageNames(cp, roots[i]);
@@ -281,21 +297,21 @@ private ClasspathLocation mapToClassPathLocation(JavaModelManager manager, Packa
 	}
 	JavaProject javaProject = root.getJavaProject();
 	if (isComplianceJava9OrHigher(javaProject)) {
-		addModuleClassPathInfo(root, defaultModule, cp);
+		IModuleDescription module = computeModuleFor(root, defaultModule);
+		if (module != null) {
+			addModuleClassPathInfo(module, cp);
+		}
 	}
 	return cp;
 }
 
-private void addModuleClassPathInfo(PackageFragmentRoot root, IModuleDescription defaultModule, ClasspathLocation cp) {
-	IModuleDescription imd = root.getModuleDescription();
-	if (imd != null) {
-		String moduleName = addModuleClassPathInfo(cp, imd);
-		if (moduleName != null)
-			this.modules.put(moduleName, imd);
-		if (this.moduleLocations != null)
-			this.moduleLocations.put(moduleName, cp);
-	} else if (defaultModule != null) {
-		addModuleClassPathInfo(cp, defaultModule);
+private void addModuleClassPathInfo(IModuleDescription module, ClasspathLocation cp) {
+	String moduleName = addModuleClassPathInfo(cp, module);
+	if (moduleName != null) {
+		this.modules.put(moduleName, module);
+	}
+	if (this.moduleLocations != null) {
+		this.moduleLocations.put(moduleName, cp);
 	}
 }
 private String addModuleClassPathInfo(ClasspathLocation cp, IModuleDescription imd) {
@@ -557,10 +573,80 @@ public char[][] getAllAutomaticModules() {
 	return set.toArray(new char[set.size()][]);
 }
 
+public static INameEnvironment createWithReferencedProjects(IJavaProject javaProject, List<IJavaProject> referencedProjects, org.eclipse.jdt.core.ICompilationUnit[] copies) {
+	JavaSearchNameEnvironment result = new JavaSearchNameEnvironment(javaProject, copies);
+
+	Iterator<IJavaProject> next = referencedProjects.iterator();
+	while (next.hasNext()) {
+		result.addProjectClassPath((JavaProject)next.next(), true);
+	}
+	return result;
+}
+
 private static boolean isComplianceJava9OrHigher(IJavaProject javaProject) {
 	if (javaProject == null) {
 		return false;
 	}
 	return CompilerOptions.versionToJdkLevel(javaProject.getOption(JavaCore.COMPILER_COMPLIANCE, true)) >= ClassFileConstants.JDK9;
 }
+
+/**
+ * Computes matching module for given {@link PackageFragmentRoot}
+ * @param root
+ * @param defaultModule project module or {@code null}
+ * @return may return {@code null}
+ */
+private static IModuleDescription computeModuleFor(PackageFragmentRoot root, IModuleDescription defaultModule) {
+	/*
+	 * The JRE 9+ container is on the module path without the 'module' classpath attribute being set.
+	 * We detected the JRE container by checking the container for system modules.
+	 */
+	IModuleDescription rootModule = root.getModuleDescription();
+	if (rootModule != null && rootModule.isSystemModule()) {
+		return rootModule;
+	}
+
+	try {
+		IClasspathEntry classpathEntry = root.getRawClasspathEntry();
+		if (ClasspathEntry.isModular(classpathEntry)) {
+			return rootModule != null? rootModule : defaultModule;
+		}
+		/*
+		 * Source/container classpath entries of a project don't always have the module attribute set,
+		 * so we cannot rely on the attribute.
+		 */
+		int entryKind = classpathEntry.getEntryKind();
+		if (entryKind == IClasspathEntry.CPE_SOURCE || entryKind == IClasspathEntry.CPE_CONTAINER) {
+			return rootModule != null? rootModule : defaultModule;
+		}
+	} catch (JavaModelException e) {
+		Util.log(e, "Error checking whether PackageFragmentRoot is on module path!"); //$NON-NLS-1$
+	}
+	return defaultModule;
+}
+
+private static boolean isSourceOrExported(PackageFragmentRoot root) {
+	boolean isExported = true; // if we run into exceptions, assume exported
+	try {
+		IClasspathEntry entry = root.getRawClasspathEntry();
+		isExported = entry.getEntryKind() == IClasspathEntry.CPE_SOURCE || entry.isExported();
+	} catch (JavaModelException e) {
+		Util.log(e, "Error checking whether package fragment root is exported!"); //$NON-NLS-1$
+	}
+	return isExported;
+}
+
+static boolean isOnModulePath(PackageFragmentRoot root) {
+	boolean isOnModulePath;
+	try {
+		IJavaProject javaProject = root.getJavaProject();
+		IModuleDescription defaultModule = javaProject.getModuleDescription();
+		IModuleDescription moduleForRoot = computeModuleFor(root, defaultModule);
+		isOnModulePath = moduleForRoot != null;
+	} catch (JavaModelException e) {
+		isOnModulePath = true; // if an exception occurs, assume yes
+		Util.log(e, "Error checking whether PackageFragmentRoot is on module path!"); //$NON-NLS-1$
+	}
+	return isOnModulePath;
+}
 }
