@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2008 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -10,6 +10,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     Microsoft Corporation - adapt to the new index match API
  *******************************************************************************/
 package org.eclipse.jdt.internal.core.search.matching;
 
@@ -70,6 +71,12 @@ public void findIndexMatches(Index index, IndexQueryRequestor requestor, SearchP
 			throw new OperationCanceledException();
 	}
 }
+
+@Override
+public void findIndexMatches(Index index, IndexQueryRequestor requestor, SearchParticipant participant, IJavaSearchScope scope, boolean resolveDocumentName, IProgressMonitor progressMonitor) {
+	findIndexMatches(index, requestor, participant, scope, progressMonitor);
+}
+
 @Override
 protected StringBuffer print(StringBuffer output) {
 	if (this.findDeclarations) {
