@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2005 IBM Corporation and others.
+ * Copyright (c) 2000, 2004 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -10,7 +10,7 @@
  *******************************************************************************/
 package java.util;
 
-public class Vector<E> {
+public class Vector {
 
 	public Vector() {
 	}
@@ -22,11 +22,7 @@ public class Vector<E> {
 		return 0;
 	}
 	
-	public E get(int i) {
+	public Object get(int i) {
 		return null;
 	}
-	
-	public boolean add(E o) {
-		return true;
-	}
 }
